@@ -11,13 +11,11 @@ int gribapiScanTimestep1(stream_t *streamptr);
 int gribapiScanTimestep2(stream_t *streamptr);
 int gribapiScanTimestep(stream_t *streamptr);
 
-int gribapiDecode(void *gribbuffer, size_t gribsize, void *data, size_t datasize,
-		  int unreduced, size_t *nmiss, double missval);
+int gribapiDecode(void *gribbuffer, size_t gribsize, void *data, size_t datasize, int unreduced, size_t *nmiss, double missval);
 
-size_t gribapiEncode(int varID, int levelID, int vlistID, int gridID, int zaxisID,
-		     int64_t vdate, int vtime, int tsteptype, int numavg,
-		     size_t datasize, const void *data, size_t nmiss, void **gribbuffer, size_t *gribbuffersize,
-		     int ljpeg, void *gribContainer);
+size_t gribapiEncode(int varID, int levelID, int vlistID, int gridID, int zaxisID, int vdate, int vtime, int tsteptype, int numavg,
+                     size_t datasize, const void *data, size_t nmiss, void **gribbuffer, size_t *gribbuffersize, int ljpeg,
+                     void *gribContainer);
 
 int gribapiGetScanningMode(grib_handle *gh);
 void gribapiSetScanningMode(grib_handle *gh, int scanningMode);
@@ -26,7 +24,7 @@ void gribapiChangeParameterIdentification(grib_handle *gh, int code, int ltype,
 
 #endif
 
-#endif  /* STREAM_GRIBAPI_H */
+#endif /* STREAM_GRIBAPI_H */
 /*
  * Local Variables:
  * c-file-style: "Java"
