@@ -26,6 +26,7 @@
 #include "cdo_vlist.h"
 #include "cdo_options.h"
 #include "cdo_fill.h"
+#include "field_functions.h"
 
 static void
 addOperators(void)
@@ -41,43 +42,6 @@ addOperators(void)
   cdo_operator_add("setmiss", FieldFunc_Setmiss, 0, nullptr);
   // clang-format on
 }
-static const char *ArithHelp[] = {
-    "NAME",
-    "    add, sub, mul, div, min, max, atan2 - Arithmetic on two datasets",
-    "",
-    "SYNOPSIS",
-    "    <operator>  infile1 infile2 outfile",
-    "",
-    "DESCRIPTION",
-    "    This module performs simple arithmetic of two datasets.",
-    "    The number of fields in infile1 should be the same as in infile2.",
-    "    The fields in outfile inherit the meta data from infile1.",
-    "    One of the input files can contain only one timestep or one variable.",
-    "",
-    "OPERATORS",
-    "    add    Add two fields",
-    "           o(t,x) = i_1(t,x) + i_2(t,x)",
-    "    sub    Subtract two fields",
-    "           o(t,x) = i_1(t,x) - i_2(t,x)",
-    "    mul    Multiply two fields",
-    "           o(t,x) = i_1(t,x) * i_2(t,x)",
-    "    div    Divide two fields",
-    "           o(t,x) = i_1(t,x) / i_2(t,x)",
-    "    min    Minimum of two fields",
-    "           o(t,x) = min(i_1(t,x), i_2(t,x))",
-    "    max    Maximum of two fields",
-    "           o(t,x) = max(i_1(t,x), i_2(t,x))",
-    "    atan2  Arc tangent of two fields",
-    "           The atan2 operator calculates the arc tangent of two fields. The result is",
-    "           in radians, which is between -PI and PI (inclusive).",
-    "           ",
-    "           o(t,x) = atan2(i_1(t,x), i_2(t,x))",
-    nullptr
-};
-void *
-Arith(void *process);
-#define ArithOperators                    {"add", "sub", "mul", "div", "min", "max", "atan2", "setmiss"}
-static const module_t module_Arith          = {"Arith",Arith          , ArithHelp         , ArithOperators          , EXPOSED  , CDI_BOTH , 2  , 1     , NoRestriction };
 
 void *
 Arith(void *process)
@@ -338,7 +302,7 @@ Arith(void *process)
 
           if (tsID == 0 || fillType == FILL_NONE || fillType == FILL_FILE || fillType == FILL_VARTS)
             {
-              const auto lstatus = (nlevels2 > 1) ? varID == 0 : recID == 0;
+              const auto lstatus = (nlevels2 > 1) ? (varID == 0) : (recID == 0);
               if (lstatus || (fillType != FILL_VAR && fillType != FILL_VARTS))
                 {
                   cdo_inq_record(streamID2, &varID2, &levelID2);
