@@ -314,7 +314,7 @@ parseParamInit(parseParamType &parse_arg, int vlistID, int pointID, int zonalID,
   parse_arg.cnparams = nvars;
   parse_arg.nvars1 = nvars;
   parse_arg.init = true;
-  parse_arg.debug = Options::cdoVerbose != 0;
+  parse_arg.debug = (Options::cdoVerbose != 0);
   parse_arg.pointID = pointID;
   parse_arg.zonalID = zonalID;
   parse_arg.surfaceID = surfaceID;
@@ -405,7 +405,7 @@ Expr(void *process)
 
   operator_input_arg(cdo_operator_enter(operatorID));
 
-  auto exprArgv = cdo_get_oper_argv();
+  const auto &exprArgv = cdo_get_oper_argv();
 
   auto exprString = readsCommandLine ? exprs_from_argument(exprArgv) : exprs_from_file(exprArgv);
 
