@@ -85,7 +85,7 @@ gabswp(void *r, int cnt)
   char *ch2 = ch1 + 1;
   char *ch3 = ch2 + 1;
   char *ch4 = ch3 + 1;
-  for (int i = 0; i < cnt; i++)
+  for (int i = 0; i < cnt; ++i)
     {
       char cc1 = *ch1;
       char cc2 = *ch2;
@@ -108,10 +108,10 @@ gabswp(void *r, int cnt)
 static float
 ibm2flt(unsigned char *ibm)
 {
-  int positive = (ibm[0] & 0x80) == 0;
+  int positive = ((ibm[0] & 0x80) == 0);
   long mant = (ibm[1] << 16) + (ibm[2] << 8) + ibm[3];
   int power = (int) (ibm[0] & 0x7f) - 64;
-  unsigned int abspower = power > 0 ? power : -power;
+  unsigned int abspower = (power > 0) ? power : -power;
 
   /* calc exp */
   double exp = 16.0;
@@ -214,7 +214,7 @@ flt2ibm(float x, unsigned char *ibm)
 #define Put4Byte(buf, cnt, ival) \
   ((buf[cnt++] = (ival) >> 24), (buf[cnt++] = (ival) >> 16), (buf[cnt++] = (ival) >> 8), (buf[cnt++] = (ival)))
 
-#define PutInt(buf, cnt, ival) (ival < 0 ? Put4Byte(buf, cnt, 0x7fffffff - ival + 1) : Put4Byte(buf, cnt, ival))
+#define PutInt(buf, cnt, ival) ((ival < 0) ? Put4Byte(buf, cnt, 0x7fffffff - ival + 1) : Put4Byte(buf, cnt, ival))
 
 static void
 dumpmap()
@@ -269,7 +269,7 @@ dumpmap()
       if (indx.hinum > 0)
         {
           indx.hipnt = (int *) Malloc(sizeof(int) * indx.hinum);
-          for (i = 0; i < indx.hinum; i++)
+          for (i = 0; i < indx.hinum; ++i)
             {
               nbytes = fread(mrec, sizeof(unsigned char), 4, mapfp);
               indx.hipnt[i] = GET_UINT4(mrec[0], mrec[1], mrec[2], mrec[3]);
@@ -283,7 +283,7 @@ dumpmap()
       if (indx.intnum > 0)
         {
           indx.intpnt = (int *) Malloc(sizeof(int) * indx.intnum);
-          for (i = 0; i < indx.intnum; i++)
+          for (i = 0; i < indx.intnum; ++i)
             {
               nbytes = fread(mrec, sizeof(unsigned char), 4, mapfp);
               indx.intpnt[i] = GET_UINT4(mrec[0], mrec[1], mrec[2], mrec[3]);
@@ -293,7 +293,7 @@ dumpmap()
       if (indx.fltnum > 0)
         {
           indx.fltpnt = (float *) Malloc(sizeof(float) * indx.fltnum);
-          for (i = 0; i < indx.fltnum; i++)
+          for (i = 0; i < indx.fltnum; ++i)
             {
               nbytes = fread(urec, sizeof(unsigned char), 4, mapfp);
               indx.fltpnt[i] = ibm2flt(urec);
@@ -352,11 +352,11 @@ dumpmap()
   fclose(mapfp);
 
   printf("hinum: %d\n", indx.hinum);
-  for (i = 0; i < indx.hinum; i++) printf("%3d %5d\n", i + 1, indx.hipnt[i]);
+  for (i = 0; i < indx.hinum; ++i) printf("%3d %5d\n", i + 1, indx.hipnt[i]);
 
   printf("\n");
   printf("hfnum: %d\n", indx.hfnum);
-  for (i = 0; i < indx.hfnum; i++) printf("%3d %g\n", i + 1, indx.hfpnt[i]);
+  for (i = 0; i < indx.hfnum; ++i) printf("%3d %g\n", i + 1, indx.hfpnt[i]);
 
   printf("\n");
 
@@ -365,29 +365,29 @@ dumpmap()
   if (indx.intnum == indx.fltnum)
     {
       printf("num: %d\n", indx.intnum);
-      for (i = 0; i < indx.intnum / 3; i++)
+      for (i = 0; i < indx.intnum / 3; ++i)
         printf("%3d %8d %6d %4d %8g %10g %8g\n", i + 1, indx.intpnt[i * 3], indx.intpnt[i * 3 + 1], indx.intpnt[i * 3 + 2],
                indx.fltpnt[i * 3], indx.fltpnt[i * 3 + 1], indx.fltpnt[i * 3 + 2]);
     }
   else if (indx.intnum == nrecords && indx.fltnum == nrecords * 3 && indxb.bignum == nrecords * 2)
     {
       printf("nrecords: %d\n", nrecords);
-      for (i = 0; i < nrecords; i++)
+      for (i = 0; i < nrecords; ++i)
         printf("%3d %8zd %6zd %4d %8g %10g %8g\n", i + 1, (size_t) indxb.bigpnt[i * 2], (size_t) indxb.bigpnt[i * 2 + 1],
                indx.intpnt[i], indx.fltpnt[i * 3], indx.fltpnt[i * 3 + 1], indx.fltpnt[i * 3 + 2]);
     }
   else
     {
       printf("intnum: %d\n", indx.intnum);
-      for (i = 0; i < indx.intnum; i++) printf("%3d %d\n", i + 1, indx.intpnt[i]);
+      for (i = 0; i < indx.intnum; ++i) printf("%3d %d\n", i + 1, indx.intpnt[i]);
 
       printf("\n");
       printf("fltnum: %d\n", indx.fltnum);
-      for (i = 0; i < indx.fltnum; i++) printf("%3d %g\n", i + 1, indx.fltpnt[i]);
+      for (i = 0; i < indx.fltnum; ++i) printf("%3d %g\n", i + 1, indx.fltpnt[i]);
 
       printf("\n");
       printf("bignum: %d\n", indxb.bignum);
-      for (i = 0; i < indxb.bignum; i++) printf("%3d %zd\n", i + 1, (size_t) indxb.bigpnt[i]);
+      for (i = 0; i < indxb.bignum; ++i) printf("%3d %zd\n", i + 1, (size_t) indxb.bigpnt[i]);
     }
 }
 
@@ -441,7 +441,7 @@ ctl_xydef(FILE *gdp, int gridID, bool *yrev)
       yrange = ((int) (ymax + 1.5)) - yfirst;
 
       ni = sizeof(inc) / sizeof(inc[0]);
-      for (i = 0; i < ni; i++)
+      for (i = 0; i < ni; ++i)
         {
           xinc = yinc = inc[i];
           nx = 1 + (int) (xrange / xinc);
@@ -466,7 +466,7 @@ ctl_xydef(FILE *gdp, int gridID, bool *yrev)
           gridInqXvals(gridID, xvals.data());
           fprintf(gdp, "XDEF %d LEVELS ", xsize);
           j = 0;
-          for (i = 0; i < xsize; i++)
+          for (i = 0; i < xsize; ++i)
             {
               fprintf(gdp, "%7.3f ", xvals[i]);
               j++;
@@ -517,7 +517,7 @@ ctl_xydef(FILE *gdp, int gridID, bool *yrev)
             }
           else
             {
-              for (i = 0; i < ysize; i++)
+              for (i = 0; i < ysize; ++i)
                 {
                   fprintf(gdp, "%7.3f ", yvals[i]);
                   j++;
@@ -558,7 +558,7 @@ ctl_zdef(FILE *gdp, int vlistID, bool *zrev)
   int nzaxis = vlistNzaxis(vlistID);
 
   int nlevmax = 0;
-  for (index = 0; index < nzaxis; index++)
+  for (index = 0; index < nzaxis; ++index)
     {
       zaxisID = vlistZaxis(vlistID, index);
       nlev = zaxisInqSize(zaxisID);
@@ -581,7 +581,7 @@ ctl_zdef(FILE *gdp, int vlistID, bool *zrev)
 
       if (IS_EQUAL(levinc, 1)) *zrev = false;
 
-      for (i = 1; i < nlevmax; i++)
+      for (i = 1; i < nlevmax; ++i)
         {
           if (IS_NOT_EQUAL(levinc, (levels[i] - levels[i - 1])))
             {
@@ -616,7 +616,7 @@ ctl_zdef(FILE *gdp, int vlistID, bool *zrev)
       else
       */
       {
-        for (i = 0; i < nlevmax; i++)
+        for (i = 0; i < nlevmax; ++i)
           {
             if (lplev)
               fprintf(gdp, "%g ", levels[i] / 100);
@@ -674,7 +674,7 @@ ctl_vars(FILE *gdp, int filetype, int vlistID, int nvarsout, int *vars)
 
   fprintf(gdp, "VARS  %d\n", nvarsout);
 
-  for (int varID = 0; varID < nvars; varID++)
+  for (int varID = 0; varID < nvars; ++varID)
     {
       if (vars[varID] == true)
         {
@@ -685,11 +685,11 @@ ctl_vars(FILE *gdp, int filetype, int vlistID, int nvarsout, int *vars)
           vlistInqVarName(vlistID, varID, varname);
 
           len = (int) strlen(varname);
-          for (i = 0; i < len; i++)
+          for (i = 0; i < len; ++i)
             if (varname[i] == '-') break;
 
           if (i < len)
-            for (j = i; j < len; j++) varname[j] = varname[j + 1];
+            for (j = i; j < len; ++j) varname[j] = varname[j + 1];
 
           vlistInqVarLongname(vlistID, varID, varlongname);
           vlistInqVarUnits(vlistID, varID, varunits);
@@ -837,36 +837,36 @@ write_map_grib1(const char *ctlfile, int map_version, int nrecords, int *intnum,
       Put1Byte(map, bcnt, 0); /* initial second */
 
       if (indx.hinum)
-        for (i = 0; i < indx.hinum; i++) Put4Byte(map, bcnt, hinum[i]);
+        for (i = 0; i < indx.hinum; ++i) Put4Byte(map, bcnt, hinum[i]);
 
       if (indx.hfnum)
         {
           /* blank for now */
         }
 
-      for (i = 0; i < nrecords; i++)
+      for (i = 0; i < nrecords; ++i)
         {
           PutInt(map, bcnt, (int) bignum[i * 2]);
           PutInt(map, bcnt, (int) bignum[i * 2 + 1]);
           PutInt(map, bcnt, intnum[i]);
         }
 
-      for (i = 0; i < indx.fltnum; i++)
+      for (i = 0; i < indx.fltnum; ++i)
         {
           fdum = fltnum[i];
           rc = flt2ibm(fdum, ibmfloat);
           if (rc < 0) cdo_abort("overflow in IBM float conversion");
-          for (j = 0; j < 4; j++) map[bcnt++] = ibmfloat[j];
+          for (j = 0; j < 4; ++j) map[bcnt++] = ibmfloat[j];
         }
 
       /* write out the factors for converting from grid to absolute time */
 
-      for (i = 0; i < 8; i++)
+      for (i = 0; i < 8; ++i)
         {
           fdum = 0;
           rc = flt2ibm(fdum, ibmfloat);
           if (rc < 0) cdo_abort("overflow in IBM float conversion");
-          for (j = 0; j < 4; j++) map[bcnt++] = ibmfloat[j];
+          for (j = 0; j < 4; ++j) map[bcnt++] = ibmfloat[j];
         }
 
       fwrite(map, 1, bcnt, mapfp);
@@ -880,7 +880,7 @@ write_map_grib1(const char *ctlfile, int map_version, int nrecords, int *intnum,
       if (map_version == 1)
         {
           std::vector<int> intnumbuf(indx.intnum);
-          for (i = 0; i < nrecords; i++)
+          for (i = 0; i < nrecords; ++i)
             {
               intnumbuf[i * 3 + 0] = (int) bignum[i * 2];
               intnumbuf[i * 3 + 1] = (int) bignum[i * 2 + 1];
@@ -992,7 +992,7 @@ Gradsdes(void *process)
   auto filetype = cdo_inq_filetype(streamID);
   auto byteorder = cdo_inq_byteorder(streamID);
 
-  if (filetype == CDI_FILETYPE_NC2 || filetype == CDI_FILETYPE_NC4 || filetype == CDI_FILETYPE_NC4C || filetype == CDI_FILETYPE_NC5)
+  if (filetype == CDI_FILETYPE_NC2 || filetype == CDI_FILETYPE_NC4 || filetype == CDI_FILETYPE_NC4C || filetype == CDI_FILETYPE_NC5 || filetype == CDI_FILETYPE_NCZARR)
     filetype = CDI_FILETYPE_NC;
 
   if (filetype != CDI_FILETYPE_SRV && filetype != CDI_FILETYPE_EXT && filetype != CDI_FILETYPE_IEG && filetype != CDI_FILETYPE_GRB)
@@ -1007,8 +1007,8 @@ Gradsdes(void *process)
         cdo_abort("Unsupported file format!");
     }
 
-  /* find the first lonlat or Gaussian grid */
-  for (index = 0; index < ngrids; index++)
+  // find the first lonlat or Gaussian grid
+  for (index = 0; index < ngrids; ++index)
     {
       gridID = vlistGrid(vlistID, index);
       gridtype = gridInqType(gridID);
@@ -1020,11 +1020,11 @@ Gradsdes(void *process)
 
   if (index == ngrids) cdo_abort("No Lon/Lat, Gaussian or Lambert grid found (%s data unsupported)!", gridNamePtr(gridtype));
 
-  /* select all variables with used gridID */
+  // select all variables with used gridID
   std::vector<int> vars(nvars);
   std::vector<int> recoffset(nvars);
   int nvarsout = 0, nrecsout = 0;
-  for (int varID = 0; varID < nvars; varID++)
+  for (int varID = 0; varID < nvars; ++varID)
     {
       if (vlistInqVarGrid(vlistID, varID) == gridID)
         {
@@ -1078,18 +1078,18 @@ Gradsdes(void *process)
       if (byteorder == CDI_LITTLEENDIAN) littleendian = true;
     }
 
-  /* ctl file name */
+  // ctl file name
   repl_filetypeext(ctlfile, filetypeext(filetype), ".ctl");
 
-  /* open ctl file*/
+  // open ctl file
   auto gdp = fopen(ctlfile, "w");
   if (gdp == nullptr) cdo_abort("Open failed on %s", ctlfile);
 
-  /* VERSION */
+  // VERSION
   fprintf(gdp, "* Generated by CDO operator gradsdes\n");
   fprintf(gdp, "*\n");
 
-  /* DSET */
+  // DSET
   if (datfile[0] == '/')
     fprintf(gdp, "DSET  %s\n", datfile);
   else
@@ -1145,10 +1145,10 @@ Gradsdes(void *process)
       fprintf(gdp, "DTYPE  NetCDF\n");
     }
 
-  /* XYHEADER */
+  // XYHEADER
   if (xyheader) fprintf(gdp, "XYHEADER  %d\n", xyheader);
 
-  /* TIME */
+  // TIME
 
   const auto taxisID = vlistInqTaxis(vlistID);
 
@@ -1160,13 +1160,13 @@ Gradsdes(void *process)
       const auto nrecs = cdo_stream_inq_timestep(streamID, tsID);
       if (nrecs == 0) break;
 
-      const auto vdate = taxisInqVdate(taxisID);
-      const auto vtime = taxisInqVtime(taxisID);
+      const auto vDateTime = taxisInqVdatetime(taxisID);
 
+      int ms;
       if (tsID == 0)
         {
-          cdiDecodeDate(vdate, &iyys, &imms, &idds);
-          cdiDecodeTime(vtime, &ihhs, &imns, &isds);
+          cdiDate_decode(vDateTime.date, &iyys, &imms, &idds);
+          cdiTime_decode(vDateTime.time, &ihhs, &imns, &isds, &ms);
 
           if (imms < 1 || imms > 12) imms = 1;
 
@@ -1179,8 +1179,8 @@ Gradsdes(void *process)
 
       if (tsID == 1)
         {
-          cdiDecodeDate(vdate, &iyy, &imm, &idd);
-          cdiDecodeTime(vtime, &ihh, &imn, &isd);
+          cdiDate_decode(vDateTime.date, &iyy, &imm, &idd);
+          cdiTime_decode(vDateTime.time, &ihh, &imn, &isd, &ms);
 
           idmn = imn - imns;
           idhh = ihh - ihhs;
@@ -1218,8 +1218,8 @@ Gradsdes(void *process)
 
       if (tsID > 0 && tsID < 6 && iik != 3 && (monavg == true || monavg == -1))
         {
-          cdiDecodeDate(vdate, &iyy, &imm, &idd);
-          cdiDecodeTime(vtime, &ihh, &imn, &isd);
+          cdiDate_decode(vDateTime.date, &iyy, &imm, &idd);
+          cdiTime_decode(vDateTime.time, &ihh, &imn, &isd, &ms);
 
           idmn = imn - imns;
           idhh = ihh - ihhs;
@@ -1261,7 +1261,7 @@ Gradsdes(void *process)
               bignum.resize(2 * maxrecs);
             }
 
-          for (int recID = 0; recID < nrecs; recID++)
+          for (int recID = 0; recID < nrecs; ++recID)
             {
               int varID, levelID;
               cdo_inq_record(streamID, &varID, &levelID);
@@ -1295,13 +1295,13 @@ Gradsdes(void *process)
 
 LABEL_STOP:
 
-  /* XYDEF */
+  // XYDEF
   ctl_xydef(gdp, gridID, &yrev);
 
-  /* ZDEF */
+  // ZDEF
   ctl_zdef(gdp, vlistID, &zrev);
 
-  /* TDEF */
+  // TDEF
 
   if (monavg == true)
     {
@@ -1320,7 +1320,7 @@ LABEL_STOP:
 
   fprintf(gdp, "TDEF %d LINEAR %s %s\n", tsID, Time, Incr);
 
-  /* TITLE */
+  // TITLE
 
   int xsize = gridInqXsize(gridID);
   int ysize = gridInqYsize(gridID);
@@ -1333,16 +1333,16 @@ LABEL_STOP:
   else
     fprintf(gdp, "TITLE  %s  %dx%d grid\n", datfile, xsize, ysize);
 
-  /* OPTIONS */
+  // OPTIONS
   ctl_options(gdp, yrev, zrev, sequential, bigendian, littleendian, flt64, cal365day);
 
-  /* UNDEF */
+  // UNDEF
   ctl_undef(gdp, vlistID);
 
-  /* VARS */
+  // VARS
   ctl_vars(gdp, filetype, vlistID, nvarsout, vars.data());
 
-  /* INDEX file */
+  // INDEX file
   if (filetype == CDI_FILETYPE_GRB)
     {
       write_map_grib1(idxfile, map_version, nrecords, intnum.data(), fltnum.data(), bignum.data());
