@@ -1,18 +1,8 @@
 /*
-  This file is part of CDO. CDO is a collection of Operators to
-  manipulate and analyse Climate model Data.
+  This file is part of CDO. CDO is a collection of Operators to manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2019 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
-  See COPYING file for copying and redistribution conditions.
+  Author: Uwe Schulzweida
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; version 2 of the License.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
 */
 
 #ifdef HAVE_CONFIG_H
@@ -29,9 +19,10 @@
 
 #include "cdo_options.h"
 #include "dmemory.h"
+#include "varray.h"
 #include "process_int.h"
-#include "cdo_cdiWrapper.h"
-#include "cdo_defaultValues.h"
+#include "cdo_cdi_wrapper.h"
+#include "cdo_default_values.h"
 #include <mpim_grid.h>
 
 #define MAX_DSETS 1024
@@ -51,7 +42,7 @@ struct dset_obj_t
   size_t gridsize;
   int lscale;
   int loffset;
-  int lmissval;
+  int hasMissvals;
   double scale;
   double offset;
   double missval;
@@ -89,7 +80,7 @@ print_filter(hid_t dset_id, char *varname)
   for (idx = 0; idx < nfilter; idx++)
     {
       H5Pget_filter(plist, idx, &flags, &cd_nelmts, &cd_values, pnamelen, pname);
-      cdoPrint("Dataset %s: filter %d =  %s", varname, idx + 1, pname);
+      cdo_print("Dataset %s: filter %d =  %s", varname, idx + 1, pname);
     }
 
   H5Pclose(plist);
@@ -98,28 +89,25 @@ print_filter(hid_t dset_id, char *varname)
 static void
 get_grid_info(double c0, double re, int *nrxp, int *nryp, double *r0p, double *s0p, double *cp)
 {
-  const double pi = M_PI;
-  double git, phi, s90;
-  double r0, s0, c;
-  int nrx, nry;
+  constexpr double pi = M_PI;
 
-  git = 2. * pi * re * std::cos(pi / 6.) / c0;
-  /* number of longitude pixels */
-  nrx = 2 * (int) std::lround(0.5 * git);
+  double git = 2. * pi * re * std::cos(pi / 6.) / c0;
+  // number of longitude pixels
+  int nrx = 2 * (int) std::lround(0.5 * git);
 
-  /* central index in longitude */
-  r0 = nrx / 2 + 0.5;
+  // central index in longitude
+  double r0 = nrx / 2 + 0.5;
 
-  /* resolution in km */
-  c = 2. * pi * re * std::cos(30. * pi / 180.) / nrx;
+  // resolution in km
+  double c = 2. * pi * re * std::cos(30. * pi / 180.) / nrx;
 
-  phi = pi / 2.;
-  s90 = re / c * std::sin(phi) / std::cos(30. * pi / 180.);
+  double phi = pi / 2.;
+  double s90 = re / c * std::sin(phi) / std::cos(30. * pi / 180.);
 
-  nry = (int) std::floor(s90);
-  /* central index in latitude */
-  s0 = nry + 0.5;
-  /* number of latitude pixels */
+  int nry = (int) std::floor(s90);
+  // central index in latitude
+  double s0 = nry + 0.5;
+  // number of latitude pixels
   nry = 2 * nry;
 
   *nrxp = nrx;
@@ -169,10 +157,8 @@ defLonLatGrid(int nx, int ny, double c0, double lts, double re)
       return -1;
     }
 
-  Varray<double> xvals(nx);
-  Varray<double> yvals(ny);
-  Varray<double> xbounds(nx * 2);
-  Varray<double> ybounds(ny * 2);
+  Varray<double> xvals(nx), yvals(ny);
+  Varray<double> xbounds(nx * 2), ybounds(ny * 2);
 
   for (i = 0; i < nx; ++i)
     {
@@ -212,23 +198,20 @@ defLonLatGrid(int nx, int ny, double c0, double lts, double re)
 }
 
 static int
-defSinusoidalGrid(int nx, int ny, double xmin, double ymax, double dx, double dy, double p1, double p2,
-                  double p3, double p4)
+defSinusoidalGrid(int nx, int ny, double xmin, double ymax, double dx, double dy, double p1, double p2, double p3, double p4)
 {
-  (void)(p1); //CDO_UNUSED
-  (void)(p2); //CDO_UNUSED
-  (void)(p3); //CDO_UNUSED
-  (void)(p4); //CDO_UNUSED
-  Varray<double> xvals(nx);
-  Varray<double> yvals(ny);
+  (void) (p1);  // CDO_UNUSED
+  (void) (p2);  // CDO_UNUSED
+  (void) (p3);  // CDO_UNUSED
+  (void) (p4);  // CDO_UNUSED
+  Varray<double> xvals(nx), yvals(ny);
 
   for (int i = 0; i < nx; ++i) xvals[i] = xmin + i * dx + dx / 2;
-
   for (int i = 0; i < ny; ++i) yvals[i] = ymax - i * dy - dy / 2;
 
-  int gridID = gridCreate(GRID_PROJECTION, nx * ny);
+  auto gridID = gridCreate(GRID_PROJECTION, nx * ny);
 
-  grid_def_param_sinu(gridID);
+  grid_def_params_sinu(gridID);
 
   gridDefXsize(gridID, nx);
   gridDefYsize(gridID, ny);
@@ -241,20 +224,19 @@ defSinusoidalGrid(int nx, int ny, double xmin, double ymax, double dx, double dy
 static int
 defLaeaGrid(int nx, int ny, double xmin, double ymax, double dx, double dy, double a, double lon0, double lat0)
 {
-  Varray<double> xvals(nx);
-  Varray<double> yvals(ny);
+  Varray<double> xvals(nx), yvals(ny);
 
   for (int i = 0; i < nx; ++i) xvals[i] = xmin + i * dx + dx / 2;
   for (int i = 0; i < ny; ++i) yvals[i] = ymax - i * dy - dy / 2;
 
-  int gridID = gridCreate(GRID_PROJECTION, nx * ny);
+  auto gridID = gridCreate(GRID_PROJECTION, nx * ny);
 
   gridDefXsize(gridID, nx);
   gridDefYsize(gridID, ny);
   gridDefXvals(gridID, xvals.data());
   gridDefYvals(gridID, yvals.data());
 
-  grid_def_param_laea(gridID, a, lon0, lat0);
+  grid_def_params_laea(gridID, a, lon0, lat0);
 
   return gridID;
 }
@@ -326,25 +308,25 @@ read_geolocation(hid_t loc_id, int nx, int ny, int lprojtype)
   int xsize, ysize;
   struct proj_t
   {
-    char name[64];
-    char ellipsoid[64];
-    float parameter[10];
+    char name[64] = { 0 };
+    char ellipsoid[64] = { 0 };
+    float parameter[10] = { 0.0 };
   };
   struct region_t
   {
-    float xmin;
-    float xmax;
-    float ymin;
-    float ymax;
-    float dx;
-    float dy;
+    float xmin = 0.0;
+    float xmax = 0.0;
+    float ymin = 0.0;
+    float ymax = 0.0;
+    float dx = 0.0;
+    float dy = 0.0;
   };
 
   proj_t proj;
   region_t region;
   char *projection_name = nullptr;
 
-  if (Options::cdoVerbose) cdoPrint("Read geolocation:");
+  if (Options::cdoVerbose) cdo_print("Read geolocation:");
 
   if (lprojtype)
     {
@@ -389,10 +371,7 @@ read_geolocation(hid_t loc_id, int nx, int ny, int lprojtype)
       }
   }
   */
-  if (proj_id < 0)
-    memset(&proj, 0, sizeof(proj_t));
-  else
-    H5Dread(proj_id, proj_tid, H5S_ALL, H5S_ALL, H5P_DEFAULT, &proj);
+  if (proj_id >= 0) H5Dread(proj_id, proj_tid, H5S_ALL, H5S_ALL, H5P_DEFAULT, &proj);
 
   H5Dclose(proj_id);
   H5Tclose(proj_tid);
@@ -400,8 +379,8 @@ read_geolocation(hid_t loc_id, int nx, int ny, int lprojtype)
   H5Tclose(fltarr_tid);
 
   if (Options::cdoVerbose)
-    cdoPrint("  Projection: name=%s\n\t\t\tellipsoid=%s\n\t\t\tparameter=%g %g %g %g %g %g", proj.name, proj.ellipsoid,
-             proj.parameter[0], proj.parameter[1], proj.parameter[2], proj.parameter[3], proj.parameter[4], proj.parameter[5]);
+    cdo_print("  Projection: name=%s\n\t\t\tellipsoid=%s\n\t\t\tparameter=%g %g %g %g %g %g", proj.name, proj.ellipsoid,
+              proj.parameter[0], proj.parameter[1], proj.parameter[2], proj.parameter[3], proj.parameter[4], proj.parameter[5]);
 
   region_tid = H5Tcreate(H5T_COMPOUND, sizeof(region_t));
   H5Tinsert(region_tid, "xmin", HOFFSET(region_t, xmin), H5T_NATIVE_FLOAT);
@@ -414,10 +393,7 @@ read_geolocation(hid_t loc_id, int nx, int ny, int lprojtype)
   region_id = H5Dopen(grp_id, "Region");
   if (region_id < 0) region_id = H5Dopen(grp_id, "region");
 
-  if (region_id < 0)
-    memset(&region, 0, sizeof(region_t));
-  else
-    H5Dread(region_id, region_tid, H5S_ALL, H5S_ALL, H5P_DEFAULT, &region);
+  if (region_id >= 0) H5Dread(region_id, region_tid, H5S_ALL, H5S_ALL, H5P_DEFAULT, &region);
 
   H5Dclose(region_id);
   H5Tclose(region_tid);
@@ -427,12 +403,12 @@ read_geolocation(hid_t loc_id, int nx, int ny, int lprojtype)
       double xmin = region.xmin;
       region.xmin = region.xmax;
       region.xmax = xmin;
-      if (Options::cdoVerbose) cdoPrint("  Swap xmin/xmax");
+      if (Options::cdoVerbose) cdo_print("  Swap xmin/xmax");
     }
 
   if (Options::cdoVerbose)
-    cdoPrint("  Region: xmin=%g xmax=%g ymin=%g ymax=%g dx=%g dy=%g", region.xmin, region.xmax, region.ymin, region.ymax, region.dx,
-             region.dy);
+    cdo_print("  Region: xmin=%g xmax=%g ymin=%g ymax=%g dx=%g dy=%g", region.xmin, region.xmax, region.ymin, region.ymax,
+              region.dx, region.dy);
 
   H5Gclose(grp_id);
 
@@ -440,7 +416,7 @@ read_geolocation(hid_t loc_id, int nx, int ny, int lprojtype)
   xsize = (int) std::lround((region.xmax - region.xmin) / region.dx);
   ysize = (int) std::lround((region.ymax - region.ymin) / region.dy);
 
-  if (Options::cdoVerbose) cdoPrint("  Size: xsize=%d  ysize=%d", xsize, ysize);
+  if (Options::cdoVerbose) cdo_print("  Size: xsize=%d  ysize=%d", xsize, ysize);
 
   /* some CM-SAF files have incorrect entries for some metadata. */
   /* these are corrected in the following sections. */
@@ -453,12 +429,12 @@ read_geolocation(hid_t loc_id, int nx, int ny, int lprojtype)
       region.xmax = 8887500.0;
       region.ymin = -8887500.0;
       if (Options::cdoVerbose)
-        cdoPrint("  Corrected region: xmin=%g xmax=%g ymin=%g ymax=%g dx=%g dy=%g", region.xmin, region.xmax, region.ymin,
-                 region.ymax, region.dx, region.dy);
+        cdo_print("  Corrected region: xmin=%g xmax=%g ymin=%g ymax=%g dx=%g dy=%g", region.xmin, region.xmax, region.ymin,
+                  region.ymax, region.dx, region.dy);
 
       xsize = (int) std::lround((region.xmax - region.xmin) / region.dx);
       ysize = (int) std::lround((region.ymax - region.ymin) / region.dy);
-      if (Options::cdoVerbose) cdoPrint("  Corrected size: xsize=%d  ysize=%d", xsize, ysize);
+      if (Options::cdoVerbose) cdo_print("  Corrected size: xsize=%d  ysize=%d", xsize, ysize);
     }
 
   if (nx == 298 && ny == 371 && (int) region.xmin == -6709222 && (int) region.xmax == 6709222 && (int) region.ymin == -6664078
@@ -468,12 +444,12 @@ read_geolocation(hid_t loc_id, int nx, int ny, int lprojtype)
       region.xmax = 6705000;
       region.ymin = -6705000;
       region.ymax = 9990000;
-      cdoPrint("  Corrected region: xmin=%g xmax=%g ymin=%g ymax=%g dx=%g dy=%g", region.xmin, region.xmax, region.ymin,
-               region.ymax, region.dx, region.dy);
+      cdo_print("  Corrected region: xmin=%g xmax=%g ymin=%g ymax=%g dx=%g dy=%g", region.xmin, region.xmax, region.ymin,
+                region.ymax, region.dx, region.dy);
 
       xsize = (int) std::lround((region.xmax - region.xmin) / region.dx);
       ysize = (int) std::lround((region.ymax - region.ymin) / region.dy);
-      if (Options::cdoVerbose) cdoPrint("  Corrected size: xsize=%d  ysize=%d", xsize, ysize);
+      if (Options::cdoVerbose) cdo_print("  Corrected size: xsize=%d  ysize=%d", xsize, ysize);
     }
 
   if (strcmp(proj.name, "sinusoidal") != 0
@@ -494,7 +470,7 @@ read_geolocation(hid_t loc_id, int nx, int ny, int lprojtype)
               && (int) region.ymin == -6705000 && (int) region.ymax == 9990000 && (int) region.dx == 45000
               && (int) region.dy == 45000)))
     {
-      if (Options::cdoVerbose) cdoPrint("Replacing incorrect projection parameters for sinusoidal products:");
+      if (Options::cdoVerbose) cdo_print("Replacing incorrect projection parameters for sinusoidal products:");
       strcpy(proj.ellipsoid, "WGS-84");
       strcpy(proj.name, "sinusoidal");
       proj.parameter[0] = 0.0;
@@ -504,29 +480,28 @@ read_geolocation(hid_t loc_id, int nx, int ny, int lprojtype)
       proj.parameter[4] = -99.99;
       proj.parameter[5] = -99.99;
       if (Options::cdoVerbose)
-        cdoPrint("proj1 = %g, proj2 = %g, proj3 = %g, proj4 = %g,", proj.parameter[0], proj.parameter[1], proj.parameter[2],
-                 proj.parameter[3]);
+        cdo_print("proj1 = %g, proj2 = %g, proj3 = %g, proj4 = %g,", proj.parameter[0], proj.parameter[1], proj.parameter[2],
+                  proj.parameter[3]);
     }
 
   if (nx == xsize && ny == ysize && strcmp(proj.name, "sinusoidal") == 0 && strcmp(proj.ellipsoid, "WGS-84") == 0)
     {
-      gridID = defSinusoidalGrid(nx, ny, region.xmin, region.ymax, region.dx, region.dy,
-                                 proj.parameter[0], proj.parameter[1], proj.parameter[2], proj.parameter[3]);
+      gridID = defSinusoidalGrid(nx, ny, region.xmin, region.ymax, region.dx, region.dy, proj.parameter[0], proj.parameter[1],
+                                 proj.parameter[2], proj.parameter[3]);
     }
   /* modification by Frank Kaspar */
   else if (nx == xsize && ny == ysize && strcmp(proj.name, "Lambert Azimuthal Equal Area") == 0
            && memcmp(proj.ellipsoid, "Sphere", 6) == 0)
     {
       double a = (proj.parameter[4] < 0) ? 6370997.0 : proj.parameter[4];
-      gridID = defLaeaGrid(nx, ny, region.xmin, region.ymax, region.dx, region.dy, a, proj.parameter[2],
-                           proj.parameter[3]);
+      gridID = defLaeaGrid(nx, ny, region.xmin, region.ymax, region.dx, region.dy, a, proj.parameter[2], proj.parameter[3]);
     }
   else if (memcmp(proj.name, "Cylindrical Equal Area", 22) == 0 && memcmp(proj.ellipsoid, "Sphere", 6) == 0)
     {
       double c0 = 0.001 * std::sqrt(proj.parameter[5]); /* nominal spatial resolution */
       double lts = proj.parameter[3];
       double re = proj.parameter[4] / 1000; /* Earth radius [km]*/
-      if (Options::cdoVerbose) cdoPrint("  c0 = %g, lts = %g, re = %g", c0, lts, re);
+      if (Options::cdoVerbose) cdo_print("  c0 = %g, lts = %g, re = %g", c0, lts, re);
       gridID = defLonLatGrid(nx, ny, c0, lts, re);
     }
   else if (nx == 386 && ny == 162)
@@ -534,7 +509,7 @@ read_geolocation(hid_t loc_id, int nx, int ny, int lprojtype)
       double c0 = 90; /* nominal spatial resolution */
       double lts = 30;
       double re = 6371.228; /* Earth radius [km]*/
-      if (Options::cdoVerbose) cdoPrint("  c0 = %g, lts = %g, re = %g", c0, lts, re);
+      if (Options::cdoVerbose) cdo_print("  c0 = %g, lts = %g, re = %g", c0, lts, re);
       gridID = defLonLatGrid(nx, ny, c0, lts, re);
     }
 
@@ -564,7 +539,7 @@ read_region(hid_t loc_id, int nx, int ny)
   char proj[128];
   double a, lon0, lat0;
 
-  if (Options::cdoVerbose) cdoPrint("Read region:");
+  if (Options::cdoVerbose) cdo_print("Read region:");
 
   /*
    * Create a data type for region
@@ -608,7 +583,7 @@ read_region(hid_t loc_id, int nx, int ny)
   }
   */
   herr_t status = H5Dread(region_id, region_tid, H5S_ALL, H5S_ALL, H5P_DEFAULT, &region);
-  (void)(status); //CDO_UNUSED
+  (void) (status);  // CDO_UNUSED
 
   if (Options::cdoVerbose)
     {
@@ -660,7 +635,7 @@ read_region(hid_t loc_id, int nx, int ny)
   xsize = (int)lround((region.xmax-region.xmin)/region.dx);
   ysize = (int)lround((region.ymax-region.ymin)/region.dy);
 
-  if ( Options::cdoVerbose ) cdoPrint("  Size: xsize=%d  ysize=%d", xsize, ysize);
+  if ( Options::cdoVerbose ) cdo_print("  Size: xsize=%d  ysize=%d", xsize, ysize);
   */
 
   if (nfound == 4 && nx == region.xsize && ny == region.ysize && strcmp(proj, "laea") == 0)
@@ -689,9 +664,8 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
   size_t gridsize, offset;
   double *array;
   double addoffset = 0, scalefactor = 1, missval = cdiInqMissval();
-  int laddoffset = 0, lscalefactor = 0, lmissval = 0;
+  int laddoffset = 0, lscalefactor = 0, hasMissvals = 0;
   int nset;
-  int i, k;
   int ftype = 0;
   int len;
   int dtype = CDI_DATATYPE_FLT32;
@@ -710,7 +684,7 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
   H5T_class_t type_class = H5Tget_class(type_id);
   if (type_class < 0)
     {
-      cdoAbort(" Invalid datatype for %s", varname);
+      cdo_abort(" Invalid datatype for %s", varname);
     }
   /*
   else {
@@ -771,7 +745,7 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
     }
   else
     {
-      cdoWarning("Dataset %s skipped, unsupported native datatype!", varname);
+      cdo_warning("Dataset %s skipped, unsupported native datatype!", varname);
       goto RETURN;
     }
   H5Tclose(native_type);
@@ -796,15 +770,15 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
     }
   else
     {
-      cdoWarning("Dataset %s skipped, unsupported rank (=%d)!", varname, rank);
+      cdo_warning("Dataset %s skipped, unsupported rank (=%d)!", varname, rank);
       goto RETURN;
     }
 
   len = (int) strlen(varname);
-  if (((datasets_t *) opdata)->mergelevel)
+  if (len > 0 && ((datasets_t *) opdata)->mergelevel)
     if (isdigit(varname[len - 1]) && memcmp(varname, "Data", 4) != 0)
       {
-        if (nt > 1) cdoAbort("Combination of nlevel > 1 and ntime > 1 not implemented!");
+        if (nt > 1) cdo_abort("Combination of nlevel > 1 and ntime > 1 not implemented!");
 
         nz = atoi(&varname[len - 1]);
         varname[len - 1] = 0;
@@ -821,7 +795,7 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
           if (strcmp(varname, ((datasets_t *) opdata)->obj[nset].name) == 0) break;
         }
 
-      if (nset >= ((datasets_t *) opdata)->nsets) cdoAbort("3D var %s not found!", varname);
+      if (nset >= ((datasets_t *) opdata)->nsets) cdo_abort("3D var %s not found!", varname);
     }
 
   if (nset < MAX_DSETS)
@@ -829,7 +803,7 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
       if (Options::cdoVerbose) print_filter(dset_id, varname);
 
       num_attrs = H5Aget_num_attrs(dset_id);
-      for (i = 0; i < num_attrs; i++)
+      for (int i = 0; i < num_attrs; ++i)
         {
           attr = H5Aopen_idx(dset_id, i);
           atype = H5Aget_type(attr);
@@ -842,7 +816,7 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
           atype_class = H5Tget_class(atype);
 
           len = strlen(attname);
-          for (k = 0; k < len; ++k) attname[k] = tolower(attname[k]);
+          for (int k = 0; k < len; ++k) attname[k] = tolower(attname[k]);
 
           if (strcmp(attname, "intercept") == 0 || strcmp(attname, "offset") == 0)
             {
@@ -867,7 +841,7 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
                         }
                     }
 
-                  if (laddoffset == 0) cdoWarning("Reading of float attribute %s failed!", attname);
+                  if (laddoffset == 0) cdo_warning("Reading of float attribute %s failed!", attname);
                 }
               else if (atype_class == H5T_INTEGER)
                 {
@@ -878,10 +852,10 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
                       laddoffset = 1;
                     }
                   else
-                    cdoWarning("Reading of integer attribute %s failed!", attname);
+                    cdo_warning("Reading of integer attribute %s failed!", attname);
                 }
               else
-                cdoWarning("Attribute %s has unsupported data type!", attname);
+                cdo_warning("Attribute %s has unsupported data type!", attname);
             }
           else if (strcmp(attname, "gain") == 0 || strcmp(attname, "scaling_factor") == 0)
             {
@@ -906,7 +880,7 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
                         }
                     }
 
-                  if (lscalefactor == 0) cdoWarning("Reading of float attribute %s failed!", attname);
+                  if (lscalefactor == 0) cdo_warning("Reading of float attribute %s failed!", attname);
                 }
               else if (atype_class == H5T_INTEGER)
                 {
@@ -917,10 +891,10 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
                       lscalefactor = 1;
                     }
                   else
-                    cdoWarning("Reading of integer attribute %s failed!", attname);
+                    cdo_warning("Reading of integer attribute %s failed!", attname);
                 }
               else
-                cdoWarning("Attribute %s has unsupported data type!", attname);
+                cdo_warning("Attribute %s has unsupported data type!", attname);
             }
           else if (strncmp(attname, "no_data", 7) == 0 || strncmp(attname, "nodata", 6) == 0)
             {
@@ -932,7 +906,7 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
                       if (status >= 0)
                         {
                           missval = fattr;
-                          lmissval = 1;
+                          hasMissvals = 1;
                         }
                     }
                   else
@@ -941,11 +915,11 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
                       if (status >= 0)
                         {
                           missval = dattr;
-                          lmissval = 1;
+                          hasMissvals = 1;
                         }
                     }
 
-                  if (lmissval == 0) cdoWarning("Reading of float attribute %s failed!", attname);
+                  if (hasMissvals == 0) cdo_warning("Reading of float attribute %s failed!", attname);
                 }
               else if (atype_class == H5T_INTEGER)
                 {
@@ -953,13 +927,13 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
                   if (status >= 0)
                     {
                       missval = iattr;
-                      lmissval = 1;
+                      hasMissvals = 1;
                     }
                   else
-                    cdoWarning("Reading of integer attribute %s failed!", attname);
+                    cdo_warning("Reading of integer attribute %s failed!", attname);
                 }
               else
-                cdoWarning("Attribute %s has unsupported data type!", attname);
+                cdo_warning("Attribute %s has unsupported data type!", attname);
             }
           else if (strcmp(attname, "description") == 0)
             {
@@ -1002,20 +976,20 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
             {
               std::vector<float> farray(gridsize * nt);
               status = H5Dread(dset_id, H5T_NATIVE_FLOAT, H5S_ALL, H5S_ALL, H5P_DEFAULT, farray.data());
-              if (status < 0) cdoAbort("Reading of NATIVE_FLOAT variable %s failed!", varname);
+              if (status < 0) cdo_abort("Reading of NATIVE_FLOAT variable %s failed!", varname);
               for (size_t i = 0; i < gridsize * nt; ++i) array[i] = farray[i];
             }
           else
             {
               status = H5Dread(dset_id, H5T_NATIVE_DOUBLE, H5S_ALL, H5S_ALL, H5P_DEFAULT, array);
-              if (status < 0) cdoAbort("Reading of NATIVE_DOUBLE variable %s failed!", varname);
+              if (status < 0) cdo_abort("Reading of NATIVE_DOUBLE variable %s failed!", varname);
             }
         }
       else
         {
-          std::vector<int> iarray(gridsize * nt);
+          Varray<int> iarray(gridsize * nt);
           status = H5Dread(dset_id, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, iarray.data());
-          if (status < 0) cdoAbort("Reading of NATIVE_INT variable %s failed!", varname);
+          if (status < 0) cdo_abort("Reading of NATIVE_INT variable %s failed!", varname);
           for (size_t i = 0; i < gridsize * nt; ++i) array[i] = iarray[i];
         }
 
@@ -1028,39 +1002,39 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
 
       if (nz > 1)
         {
-          if (((datasets_t *) opdata)->obj[nset].dtype != dtype) cdoWarning("Data type changes over levels!");
+          if (((datasets_t *) opdata)->obj[nset].dtype != dtype) cdo_warning("Data type changes over levels!");
 
           if (laddoffset && !DBL_IS_EQUAL(((datasets_t *) opdata)->obj[nset].offset, addoffset))
-            cdoWarning("Offset changes over levels!");
+            cdo_warning("Offset changes over levels!");
 
           if (lscalefactor && !DBL_IS_EQUAL(((datasets_t *) opdata)->obj[nset].scale, scalefactor))
-            cdoWarning("Scalefactor changes over levels!");
+            cdo_warning("Scalefactor changes over levels!");
 
-          if (lmissval && !DBL_IS_EQUAL(((datasets_t *) opdata)->obj[nset].missval, missval))
-            cdoWarning("Missing value changes over levels!");
+          if (hasMissvals && !DBL_IS_EQUAL(((datasets_t *) opdata)->obj[nset].missval, missval))
+            cdo_warning("Missing value changes over levels!");
         }
 
       if (nz == 1) ((datasets_t *) opdata)->nsets++;
 
-      std::vector<bool> mask(gridsize * nt, 0);
+      std::vector<bool> mask(gridsize * nt, false);
 
       nmiss = 0;
 
-      const auto minmax = varrayMinMax(gridsize * nt, array);
+      const auto mm = varray_min_max(gridsize * nt, array);
 
       if (Options::cdoVerbose)
-        cdoPrint("Dataset %s: missval = %g  addoffset = %g  scalefactor = %g", varname, missval, addoffset, scalefactor);
+        cdo_print("Dataset %s: missval = %g  addoffset = %g  scalefactor = %g", varname, missval, addoffset, scalefactor);
 
       if (Options::cdoVerbose)
-        cdoPrint("Dataset %s: dtype = %d  minval = %g  maxval = %g  missval = %g", varname, dtype, minmax.first, minmax.second, missval);
+        cdo_print("Dataset %s: dtype = %d  minval = %g  maxval = %g  missval = %g", varname, dtype, mm.min, mm.max, missval);
 
       if (dtype == CDI_DATATYPE_UINT8)
         {
-          if (minmax.first >= 0 && minmax.second <= 127) dtype = CDI_DATATYPE_INT8;
+          if (mm.min >= 0 && mm.max <= 127) dtype = CDI_DATATYPE_INT8;
         }
       else if (dtype == CDI_DATATYPE_UINT16)
         {
-          if (minmax.first >= 0 && minmax.second <= 32767) dtype = CDI_DATATYPE_INT16;
+          if (mm.min >= 0 && mm.max <= 32767) dtype = CDI_DATATYPE_INT16;
         }
 
       laddoffset = IS_NOT_EQUAL(addoffset, 0);
@@ -1068,7 +1042,7 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
 
       if (laddoffset || lscalefactor)
         {
-          for (size_t i = 0; i < gridsize * nt; i++)
+          for (size_t i = 0; i < gridsize * nt; ++i)
             if (!DBL_IS_EQUAL(array[i], missval))
               {
                 mask[i] = false;
@@ -1085,15 +1059,15 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
 
       double minval = 1e35;
       double maxval = -1e35;
-      for (size_t i = 0; i < gridsize * nt; i++)
+      for (size_t i = 0; i < gridsize * nt; ++i)
         if (mask[i] == false)
           {
-            if (array[i] < minval) minval = array[i];
-            if (array[i] > maxval) maxval = array[i];
+            minval = std::min(minval, array[i]);
+            maxval = std::max(maxval, array[i]);
           }
 
       if (Options::cdoVerbose)
-        cdoPrint("Dataset %s: dtype = %d  minval = %g  maxval = %g  missval = %g", varname, dtype, minval, maxval, missval);
+        cdo_print("Dataset %s: dtype = %d  minval = %g  maxval = %g  missval = %g", varname, dtype, minval, maxval, missval);
 
       if (nmiss)
         {
@@ -1103,29 +1077,29 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
                 {
                   missval = -255;
                   dtype = CDI_DATATYPE_INT16;
-                  cdoPrint("Dataset %s: changed missval to %g and datatype to INT16!", varname, missval);
+                  cdo_print("Dataset %s: changed missval to %g and datatype to INT16!", varname, missval);
 
-                  for (size_t i = 0; i < gridsize * nt; i++)
+                  for (size_t i = 0; i < gridsize * nt; ++i)
                     if (mask[i]) array[i] = missval;
                 }
               else
-                cdoWarning(" Missing value is inside the range of valid values!\n"
-                           "\tDataset %s,  Missval: %g,  Range: %g - %g",
-                           varname, missval, minval, maxval);
+                cdo_warning(" Missing value is inside the range of valid values!\n"
+                            "\tDataset %s,  Missval: %g,  Range: %g - %g",
+                            varname, missval, minval, maxval);
             }
         }
 
       ((datasets_t *) opdata)->obj[nset].dtype = dtype;
       ((datasets_t *) opdata)->obj[nset].loffset = laddoffset;
       ((datasets_t *) opdata)->obj[nset].lscale = lscalefactor;
-      ((datasets_t *) opdata)->obj[nset].lmissval = lmissval;
+      ((datasets_t *) opdata)->obj[nset].hasMissvals = hasMissvals;
       ((datasets_t *) opdata)->obj[nset].offset = addoffset;
       ((datasets_t *) opdata)->obj[nset].scale = scalefactor;
       ((datasets_t *) opdata)->obj[nset].missval = missval;
     }
   else
     {
-      cdoWarning("Too many datasets (MAX = %d)!", MAX_DSETS);
+      cdo_warning("Too many datasets (MAX = %d)!", MAX_DSETS);
       goto RETURN;
     }
 
@@ -1148,7 +1122,7 @@ obj_info(hid_t loc_id, const char *name, void *opdata)
   switch (obj_type)
     {
     case H5G_GROUP:
-      if (Options::cdoVerbose) cdoPrint(" Object with name %s is a group", name);
+      if (Options::cdoVerbose) cdo_print(" Object with name %s is a group", name);
       if (strcmp(name, "Data") == 0)
         {
           ((datasets_t *) opdata)->mergelevel = true;
@@ -1164,10 +1138,10 @@ obj_info(hid_t loc_id, const char *name, void *opdata)
         }
       break;
     case H5G_DATASET:
-      if (Options::cdoVerbose) cdoPrint(" Object with name %s is a dataset", name);
+      if (Options::cdoVerbose) cdo_print(" Object with name %s is a dataset", name);
       if (strstr(name, "PALETTE"))
         {
-          if (Options::cdoVerbose) cdoPrint("   Skip dataset: %s", name);
+          if (Options::cdoVerbose) cdo_print("   Skip dataset: %s", name);
         }
       /*else if ( strstr(name, "egion") ) */
       else if (strcmp(name, "region") == 0)
@@ -1176,18 +1150,18 @@ obj_info(hid_t loc_id, const char *name, void *opdata)
         }
       else
         {
-          if (Options::cdoVerbose) cdoPrint("   Read dataset: %s", name);
+          if (Options::cdoVerbose) cdo_print("   Read dataset: %s", name);
           read_dataset(loc_id, name, opdata);
         }
       break;
     case H5G_TYPE:
-      if (Options::cdoVerbose) cdoPrint(" Object with name %s is a named datatype", name);
+      if (Options::cdoVerbose) cdo_print(" Object with name %s is a named datatype", name);
       if (strcmp(name, "ProjType") == 0)
         {
           ((datasets_t *) opdata)->lprojtype = true;
         }
       break;
-    default: cdoAbort(" Unable to identify an object %s", name); break;
+    default: cdo_abort(" Unable to identify an object %s", name); break;
     }
 
   return 0;
@@ -1211,7 +1185,7 @@ get_global_att(hid_t file_id, const char *obj_path, int vlistID)
 
   num_attrs = H5Aget_num_attrs(obj_id);
 
-  for (i = 0; i < num_attrs; i++)
+  for (i = 0; i < num_attrs; ++i)
     {
       attr = H5Aopen_idx(obj_id, i);
       atype = H5Aget_type(attr);
@@ -1299,7 +1273,7 @@ dsets_init(datasets_t *dsets)
       dsets->obj[i].dtype = CdoDefault::DataType;
       dsets->obj[i].lscale = 0;
       dsets->obj[i].loffset = 0;
-      dsets->obj[i].lmissval = 0;
+      dsets->obj[i].hasMissvals = 0;
       dsets->obj[i].missval = cdiInqMissval();
       dsets->obj[i].array = nullptr;
     }
@@ -1315,32 +1289,29 @@ Importcmsaf(void *process)
   size_t nmiss;
   int ivar;
   int varID, levelID, tsID;
-  double *array;
   double missval;
-  hid_t file_id; /* HDF5 File ID	        	*/
-  herr_t status; /* Generic return value		*/
+  herr_t status;  // Generic return value
   datasets_t dsets;
-  int64_t vdate;
-  int vtime;
-  int *vtimes = nullptr;
 #endif
 
-  cdoInitialize(process);
+  cdo_initialize(process);
+
+  operator_check_argc(0);
 
   if (CdoDefault::FileType == CDI_UNDEFID) CdoDefault::FileType = CDI_FILETYPE_NC;
 
 #ifdef HAVE_LIBHDF5
   dsets_init(&dsets);
 
-  /* Open an existing file. */
-  file_id = H5Fopen(cdoGetStreamName(0), H5F_ACC_RDONLY, H5P_DEFAULT);
-  if (file_id < 0) cdoAbort("H5Fopen failed on %s", cdoGetStreamName(0));
+  // Open an existing file.
+  hid_t file_id = H5Fopen(cdo_get_stream_name(0), H5F_ACC_RDONLY, H5P_DEFAULT);
+  if (file_id < 0) cdo_abort("H5Fopen failed on %s", cdo_get_stream_name(0));
 
-  /* cmsaf_type = get_cmsaf_type(file_id); */
+  // cmsaf_type = get_cmsaf_type(file_id);
 
   H5Giterate(file_id, "/", nullptr, obj_info, (void *) &dsets);
 
-  if (dsets.nsets == 0) cdoAbort("No dataset found!");
+  if (dsets.nsets == 0) cdo_abort("No dataset found!");
 
   int gridsize = dsets.obj[0].gridsize;
   int nx = dsets.obj[0].nx;
@@ -1355,38 +1326,37 @@ Importcmsaf(void *process)
         break;
       }
 
+  Varray<int> vtimes;
   if (nt > 1)
     {
-      vtimes = (int *) Malloc(nt * sizeof(int));
+      vtimes.resize(nt);
 
       for (i = 0; i < nt; ++i) vtimes[i] = i * 10000 + 45 * 100;
 
       if (dsets.obj[ivar].time)
         {
-          long itime;
           char *pline = dsets.obj[ivar].time;
-
           for (i = 0; i < nt; ++i)
             {
-              itime = ((int) strtol(pline, &pline, 10)) * 100;
+              int itime = ((int) strtol(pline, &pline, 10)) * 100;
               if (itime < 0 || itime > 240000)
                 {
-                  cdoWarning("Wrong time string!");
+                  cdo_warning("Wrong time string!");
                   break;
                 }
-              vtimes[i] = (int) itime;
+              vtimes[i] = itime;
             }
         }
     }
 
   if (Options::cdoVerbose)
     for (ivar = 0; ivar < dsets.nsets; ++ivar)
-      cdoPrint(" Var %d %-20s %dx%d nlev = %d nts = %d", ivar, dsets.obj[ivar].name, nx, ny, nz, dsets.obj[ivar].nt);
+      cdo_print(" Var %d %-20s %dx%d nlev = %d nts = %d", ivar, dsets.obj[ivar].name, nx, ny, nz, dsets.obj[ivar].nt);
 
   for (ivar = 1; ivar < dsets.nsets; ++ivar)
     {
-      if (nx != dsets.obj[0].nx || ny != dsets.obj[0].ny) cdoAbort("Gridsize must not change!");
-      if (nz != dsets.obj[0].nz) cdoAbort("Number of levels must not change!");
+      if (nx != dsets.obj[0].nx || ny != dsets.obj[0].ny) cdo_abort("Gridsize must not change!");
+      if (nz != dsets.obj[0].nz) cdo_abort("Number of levels must not change!");
     }
 
   if (dsets.lgeoloc)
@@ -1417,23 +1387,20 @@ Importcmsaf(void *process)
 
   const auto vlistID = vlistCreate();
 
-  const auto taxisID = cdoTaxisCreate(nt > 1 ? TAXIS_RELATIVE : TAXIS_ABSOLUTE);
+  const auto taxisID = cdo_taxis_create((nt > 1) ? TAXIS_RELATIVE : TAXIS_ABSOLUTE);
   taxisDefCalendar(taxisID, CALENDAR_STANDARD);
   vlistDefTaxis(vlistID, taxisID);
 
   for (ivar = 0; ivar < dsets.nsets; ++ivar)
     {
       varID = vlistDefVar(vlistID, gridID, zaxisID, TIME_VARYING);
-      vlistDefVarName(vlistID, varID, dsets.obj[ivar].name);
-      if (dsets.obj[ivar].description) vlistDefVarLongname(vlistID, varID, dsets.obj[ivar].description);
-      if (dsets.obj[ivar].units) vlistDefVarUnits(vlistID, varID, dsets.obj[ivar].units);
+      cdiDefKeyString(vlistID, varID, CDI_KEY_NAME, dsets.obj[ivar].name);
+      if (dsets.obj[ivar].description) cdiDefKeyString(vlistID, varID, CDI_KEY_LONGNAME, dsets.obj[ivar].description);
+      if (dsets.obj[ivar].units) cdiDefKeyString(vlistID, varID, CDI_KEY_UNITS, dsets.obj[ivar].units);
       if (dsets.obj[ivar].title) cdiDefAttTxt(vlistID, varID, "title", (int) strlen(dsets.obj[ivar].title), dsets.obj[ivar].title);
 
-      /*
-      vlistDefVarUnits(vlistID, varID, units[i]);
-      */
       vlistDefVarDatatype(vlistID, varID, dsets.obj[ivar].dtype);
-      if (dsets.obj[ivar].lmissval) vlistDefVarMissval(vlistID, varID, dsets.obj[ivar].missval);
+      if (dsets.obj[ivar].hasMissvals) vlistDefVarMissval(vlistID, varID, dsets.obj[ivar].missval);
       if (dsets.obj[ivar].lscale) vlistDefVarScalefactor(vlistID, varID, dsets.obj[ivar].scale);
       if (dsets.obj[ivar].loffset) vlistDefVarAddoffset(vlistID, varID, dsets.obj[ivar].offset);
     }
@@ -1441,20 +1408,21 @@ Importcmsaf(void *process)
   get_global_att(file_id, "/", vlistID);
   if (dsets.lmetadata) get_global_att(file_id, "Metadata", vlistID);
 
-  vdate = get_vdate(vlistID);
+  int vdate = get_vdate(vlistID);
   if (vdate == 0) vdate = 10101;
 
-  const auto streamID = cdoOpenWrite(1);
+  const auto streamID = cdo_open_write(1);
 
-  cdoDefVlist(streamID, vlistID);
+  cdo_def_vlist(streamID, vlistID);
 
   for (tsID = 0; tsID < nt; ++tsID)
     {
-      taxisDefVdate(taxisID, vdate);
-      vtime = 0;
-      if (vtimes) vtime = vtimes[tsID];
-      taxisDefVtime(taxisID, vtime);
-      cdoDefTimestep(streamID, tsID);
+      const int vtime = (vtimes.empty()) ? 0 : vtimes[tsID];
+      CdiDateTime vDateTime = { };
+      vDateTime.date = cdiDate_set(vdate);
+      vDateTime.time = cdiTime_set(vtime);
+      taxisDefVdatetime(taxisID, vDateTime);
+      cdo_def_timestep(streamID, tsID);
 
       for (ivar = 0; ivar < dsets.nsets; ++ivar)
         {
@@ -1469,29 +1437,28 @@ Importcmsaf(void *process)
             {
               offset = gridsize * levelID;
               if (nz == 1) offset = gridsize * tsID;
-              array = dsets.obj[ivar].array + offset;
+              double *array = dsets.obj[ivar].array + offset;
 
-              size_t nvals;
-              const auto minmax = varrayMinMaxMV(gridsize, array, missval, nvals);
-              nmiss = gridsize - nvals;
+              const auto mm = varray_min_max_mv(gridsize, array, missval);
+              nmiss = gridsize - mm.n;
 
               if (Options::cdoVerbose)
-                cdoPrint(" Write var %d,  level %d, nmiss %zu, missval %g, minval %g, maxval %g", varID, levelID, nmiss, missval,
-                         minmax.first, minmax.second);
+                cdo_print(" Write var %d,  level %d, nmiss %zu, missval %g, minval %g, maxval %g", varID, levelID, nmiss, missval,
+                          mm.min, mm.max);
 
-              cdoDefRecord(streamID, varID, levelID);
-              cdoWriteRecord(streamID, array, nmiss);
+              cdo_def_record(streamID, varID, levelID);
+              cdo_write_record(streamID, array, nmiss);
             }
         }
     }
 
-  /* Close file */
+  // Close file
   status = H5Fclose(file_id);
-  (void)(status); //CDO_UNUSED
+  (void) (status);  // CDO_UNUSED
 
-  processDefVarNum(vlistNvars(vlistID));
+  process_def_var_num(vlistNvars(vlistID));
 
-  cdoStreamClose(streamID);
+  cdo_stream_close(streamID);
 
   vlistDestroy(vlistID);
   gridDestroy(gridID);
@@ -1500,11 +1467,9 @@ Importcmsaf(void *process)
 
   for (ivar = 0; ivar < dsets.nsets; ++ivar) Free(dsets.obj[ivar].array);
 
-  if (vtimes) Free(vtimes);
-
-  cdoFinish();
+  cdo_finish();
 #else
-  cdoAbort("HDF5 support not compiled in!");
+  cdo_abort("HDF5 support not compiled in!");
 #endif
 
   return nullptr;
