@@ -20,6 +20,7 @@
 #include "gridreference.h"
 #include "cimdOmp.h"
 #include "verifygrid.h"
+#include "field_functions.h"
 
 //#define TESTIMPL 1
 //#define USE_YAC  1
@@ -238,24 +239,20 @@ find_points_yac(std::vector<char> &vmask, size_t cell_no, size_t ncorner, size_t
   cell.array_size = ncorner;
   cell.num_corners = ncorner;
   cell.edge_type = new enum yac_edge_type[ncorner];
-  cell.coordinates_x = new double[ncorner];
-  cell.coordinates_y = new double[ncorner];
   cell.coordinates_xyz = new double[ncorner][3];
 
-  // enum yac_edge_type lonlat_circle_type[] = { LON_CIRCLE, LAT_CIRCLE, LON_CIRCLE, LAT_CIRCLE, LON_CIRCLE };
+  // enum yac_edge_type lonlat_circle_type[] = { LON_CIRCLE_EDGE, LAT_CIRCLE_EDGE, LON_CIRCLE_EDGE, LAT_CIRCLE_EDGE, LON_CIRCLE_EDGE };
 
   for (size_t k = 0; k < ncorner; ++k)
     {
       const auto lon = xbounds[cell_no * ncorner + k];
       const auto lat = ybounds[cell_no * ncorner + k];
-      cell.edge_type[k] = GREAT_CIRCLE;
+      cell.edge_type[k] = GREAT_CIRCLE_EDGE;
       // cell.edge_type[k] = lonlat_circle_type[k + 1];
-      cell.coordinates_x[k] = lon;
-      cell.coordinates_y[k] = lat;
       gcLLtoXYZ(lon, lat, cell.coordinates_xyz[k]);
     }
 
-  double center_coordinates[3];
+  double centerCoordinates[3];
   size_t nvalues = 0;
   for (size_t k = 0; k < nadds; ++k)
     {
@@ -263,9 +260,9 @@ find_points_yac(std::vector<char> &vmask, size_t cell_no, size_t ncorner, size_t
       const auto lon = xvals1[index1];
       const auto lat = yvals1[index1];
 
-      gcLLtoXYZ(lon, lat, center_coordinates);
+      gcLLtoXYZ(lon, lat, centerCoordinates);
 
-      if (yac_point_in_cell(center_coordinates, cell))
+      if (yac_point_in_cell(centerCoordinates, cell))
         {
           if (vmask[index1] == 0)
             {
@@ -277,8 +274,6 @@ find_points_yac(std::vector<char> &vmask, size_t cell_no, size_t ncorner, size_t
     }
 
   delete[] cell.edge_type;
-  delete[] cell.coordinates_x;
-  delete[] cell.coordinates_y;
   delete[] cell.coordinates_xyz;
 
   return nvalues;
@@ -294,44 +289,40 @@ find_points(std::vector<char> &vmask, size_t cell_no, size_t ncorner, size_t nad
   cdo_abort("Internal error: find_points() not implemented!");
 #endif
 
-  Point3D center_point_xyz;
-  Point center_point_plane_projection;
-  Varray<Point> cell_corners_plane_projection(ncorner + 1);
-  Varray<Point3D> cell_corners_xyz(ncorner + 1);
+  Point3D centerPoint3D;
+  Varray<Point> cellCornersPlaneProjection(ncorner + 1);
+  Varray<Point3D> cellCorners3D(ncorner + 1);
   Varray<Point3D> cell_corners_xyz_open_cell(ncorner);
   std::vector<bool> marked_duplicate_indices(ncorner);
 
-  set_cell_corners_xyz(ncorner, &xbounds[cell_no * ncorner], &ybounds[cell_no * ncorner], cell_corners_xyz_open_cell);
+  set_cell_corners_3D(ncorner, &xbounds[cell_no * ncorner], &ybounds[cell_no * ncorner], cell_corners_xyz_open_cell);
 
-  auto actual_number_of_corners = get_actual_number_of_corners(ncorner, cell_corners_xyz_open_cell);
+  auto actualNumberOfCorners = get_actual_number_of_corners(ncorner, cell_corners_xyz_open_cell);
 
-  auto no_duplicates = get_no_duplicates(actual_number_of_corners, cell_corners_xyz_open_cell, marked_duplicate_indices);
+  auto no_duplicates = get_no_duplicates(actualNumberOfCorners, cell_corners_xyz_open_cell, marked_duplicate_indices);
 
-  copy_unique_corners(actual_number_of_corners, cell_corners_xyz_open_cell, marked_duplicate_indices, cell_corners_xyz);
+  copy_unique_corners(actualNumberOfCorners, cell_corners_xyz_open_cell, marked_duplicate_indices, cellCorners3D);
 
-  actual_number_of_corners -= no_duplicates;
+  actualNumberOfCorners -= no_duplicates;
 
-  cell_corners_xyz[actual_number_of_corners] = cell_corners_xyz[0];
+  cellCorners3D[actualNumberOfCorners] = cellCorners3D[0];
 
-  if (actual_number_of_corners < 3) return 0;
+  if (actualNumberOfCorners < 3) return 0;
 
-  const auto coordinate_to_ignore = find_coordinate_to_ignore(cell_corners_xyz);
+  const auto coordinateToIgnore = find_coordinate_to_ignore(cellCorners3D);
 
-  bool invert_result = false;
-  const auto cval = (coordinate_to_ignore == 1) ? cell_corners_xyz[0].X
-                                                : ((coordinate_to_ignore == 2) ? cell_corners_xyz[0].Y : cell_corners_xyz[0].Z);
-  if (cval < 0.0) invert_result = true;
+  const auto cval = (coordinateToIgnore == 1) ? cellCorners3D[0].X
+                                              : ((coordinateToIgnore == 2) ? cellCorners3D[0].Y : cellCorners3D[0].Z);
+  const auto invertResult = (cval < 0.0);
 
-  set_cell_corners_plane_projection(coordinate_to_ignore, actual_number_of_corners, cell_corners_xyz,
-                                    cell_corners_plane_projection);
+  set_cell_corners_plane_projection(coordinateToIgnore, actualNumberOfCorners, cellCorners3D, cellCornersPlaneProjection);
 
-  const auto polygon_area = calculate_the_polygon_area(cell_corners_plane_projection, actual_number_of_corners + 1);
-  auto is_clockwise = are_polygon_vertices_arranged_in_clockwise_order(polygon_area);
+  auto isClockwise = are_polygon_vertices_arranged_in_clockwise_order(cellCornersPlaneProjection, actualNumberOfCorners + 1);
 
-  if (invert_result) is_clockwise = !is_clockwise;
-  if (is_clockwise) return 0;
+  if (invertResult) isClockwise = !isClockwise;
+  if (isClockwise) return 0;
 
-  double center_coordinates[3];
+  double centerCoordinates[3];
   size_t nvalues = 0;
   for (size_t k = 0; k < nadds; ++k)
     {
@@ -339,17 +330,17 @@ find_points(std::vector<char> &vmask, size_t cell_no, size_t ncorner, size_t nad
       const auto lon = xvals1[index1];
       const auto lat = yvals1[index1];
 
-      gcLLtoXYZ(lon, lat, center_coordinates);
-      center_point_xyz.X = center_coordinates[0];
-      center_point_xyz.Y = center_coordinates[1];
-      center_point_xyz.Z = center_coordinates[2];
+      gcLLtoXYZ(lon, lat, centerCoordinates);
+      centerPoint3D.X = centerCoordinates[0];
+      centerPoint3D.Y = centerCoordinates[1];
+      centerPoint3D.Z = centerCoordinates[2];
 
-      set_center_point_plane_projection(coordinate_to_ignore, center_point_xyz, center_point_plane_projection);
+      const auto centerPoint2D = set_center_point_plane_projection(coordinateToIgnore, centerPoint3D);
 
-      auto winding_number
-          = winding_numbers_algorithm(cell_corners_plane_projection, actual_number_of_corners + 1, center_point_plane_projection);
+      auto windingNumber
+          = winding_numbers_algorithm(cellCornersPlaneProjection, actualNumberOfCorners + 1, centerPoint2D);
 
-      if (winding_number != 0)
+      if (windingNumber != 0)
         {
           if (vmask[index1] == 0)
             {
@@ -474,9 +465,7 @@ gen_mapdata(int gridID1, int gridID2)
   StatInfo statInfo;
 
 #ifdef _OPENMP
-#pragma omp parallel for default(none) schedule(dynamic)                                                                          \
-    shared(Options::cdoVerbose, gridsize2, gps, statInfo, mapdata, xvals1, yvals1, xvals2, yvals2, grid2_is_reg2d, ndist_max, nv, \
-           nlon2, xbounds2d, ybounds2d, xbounds, ybounds, adds_2D, dist_2D, vmask)
+#pragma omp parallel for default(shared) schedule(dynamic)
 #endif
   for (size_t i = 0; i < gridsize2; ++i)
     {
@@ -564,7 +553,7 @@ remap_field(const Varray2D<size_t> &mapdata, const Field &field1, Field &field2,
 
   size_t nmiss2 = 0;
 #ifdef _OPENMP
-#pragma omp parallel for default(none) schedule(static) reduction(+ : nmiss2) shared(operfunc, gridsize2, mapdata, fields, field1, field2)
+#pragma omp parallel for default(shared) schedule(static) reduction(+ : nmiss2)
 #endif
   for (size_t i = 0; i < gridsize2; ++i)
     {
@@ -627,8 +616,8 @@ Remapstat(void *process)
 
   {
 #ifdef TESTIMPL
-    const auto lprojparams = ((gridtype2 == GRID_PROJECTION) && grid_has_proj_params(gridID2));
-    if (!gridProjIsSupported(gridID2) && !lprojparams && gridtype2 != GRID_LONLAT && gridtype2 != GRID_GAUSSIAN
+    const auto hasProjParams = ((gridtype2 == GRID_PROJECTION) && grid_has_proj_params(gridID2));
+    if (!gridProjIsSupported(gridID2) && !hasProjParams && gridtype2 != GRID_LONLAT && gridtype2 != GRID_GAUSSIAN
         && gridtype2 != GRID_CURVILINEAR && gridtype2 != GRID_UNSTRUCTURED)
 #else
     if (gridtype2 != GRID_LONLAT && gridtype2 != GRID_GAUSSIAN)
@@ -647,15 +636,14 @@ Remapstat(void *process)
 
   const auto ngrids = vlistNgrids(vlistID1);
   const auto gridID1 = vlistGrid(vlistID1, 0);
-  for (int index = 0; index < ngrids; index++)
+  for (int index = 0; index < ngrids; ++index)
     {
       if (index > 0) cdo_abort("Too many different grids!");
 
       // const auto gridID1 = vlistGrid(vlistID1, index);
       const auto gridtype = gridInqType(gridID1);
-
-      const bool lprojparams = (gridtype == GRID_PROJECTION) && grid_has_proj_params(gridID1);
-      if (!gridProjIsSupported(gridID1) && !lprojparams && gridtype != GRID_LONLAT && gridtype != GRID_GAUSSIAN
+      const auto hasProjParams = ((gridtype == GRID_PROJECTION) && grid_has_proj_params(gridID1));
+      if (!gridProjIsSupported(gridID1) && !hasProjParams && gridtype != GRID_LONLAT && gridtype != GRID_GAUSSIAN
           && gridtype != GRID_GME && gridtype != GRID_CURVILINEAR && gridtype != GRID_UNSTRUCTURED)
         cdo_abort("Interpolation of %s data unsupported!", gridNamePtr(gridtype));
 
@@ -682,7 +670,7 @@ Remapstat(void *process)
       cdo_taxis_copy_timestep(taxisID2, taxisID1);
       cdo_def_timestep(streamID2, tsID);
 
-      for (int recID = 0; recID < nrecs; recID++)
+      for (int recID = 0; recID < nrecs; ++recID)
         {
           int varID, levelID;
           cdo_inq_record(streamID1, &varID, &levelID);
