@@ -1,18 +1,8 @@
 /*
-  This file is part of CDO. CDO is a collection of Operators to
-  manipulate and analyse Climate model Data.
+  This file is part of CDO. CDO is a collection of Operators to manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2019 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
-  See COPYING file for copying and redistribution conditions.
+  Author: Uwe Schulzweida
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; version 2 of the License.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
 */
 
 #ifdef HAVE_CONFIG_H
@@ -36,21 +26,21 @@ static void
 nce(int istat)
 {
   // This routine provides a simple interface to NetCDF error message routine.
-  if (istat != NC_NOERR) cdoAbort(nc_strerror(istat));
+  if (istat != NC_NOERR) cdo_abort(nc_strerror(istat));
 }
 
 static size_t
-cdfReadDimlen(int ncfileid, const char *dimname)
+cdf_read_dimlen(int ncfileid, const char *dimname)
 {
   size_t dimlen = 0;
   int ncdimid;
-  const int status = nc_inq_dimid(ncfileid, dimname, &ncdimid);
+  const auto status = nc_inq_dimid(ncfileid, dimname, &ncdimid);
   if (status == NC_NOERR) nce(nc_inq_dimlen(ncfileid, ncdimid, &dimlen));
   return dimlen;
 }
 
 static void
-cdfReadAttText(int ncfileid, int ncvarid, const char *name, std::string &text)
+cdf_read_att_text(int ncfileid, int ncvarid, const char *name, std::string &text)
 {
   size_t attlen;
   nc_type atttype;
@@ -70,7 +60,7 @@ cdfReadAttText(int ncfileid, int ncvarid, const char *name, std::string &text)
 }
 
 static void
-cdfReadVarInt(int ncfileid, const char *name, int *array)
+cdf_read_var_int(int ncfileid, const char *name, int *array)
 {
   int ncvarid;
   nce(nc_inq_varid(ncfileid, name, &ncvarid));
@@ -78,12 +68,12 @@ cdfReadVarInt(int ncfileid, const char *name, int *array)
 }
 
 static void
-cdfReadVarSize(int ncfileid, const char *name, size_t len, size_t *array)
+cdf_read_var_size(int ncfileid, const char *name, size_t len, size_t *array)
 {
   if (len < 0x7FFFFC00)  // 2GB
     {
       std::vector<int> iarray(len);
-      cdfReadVarInt(ncfileid, name, iarray.data());
+      cdf_read_var_int(ncfileid, name, iarray.data());
       for (size_t i = 0; i < len; ++i) array[i] = (size_t) iarray[i];
     }
 #ifdef HAVE_NETCDF4
@@ -97,7 +87,7 @@ cdfReadVarSize(int ncfileid, const char *name, size_t len, size_t *array)
 }
 
 static void
-cdfReadVarDouble(int ncfileid, const char *name, double *array)
+cdf_read_var_double(int ncfileid, const char *name, double *array)
 {
   int ncvarid;
   nce(nc_inq_varid(ncfileid, name, &ncvarid));
@@ -105,14 +95,14 @@ cdfReadVarDouble(int ncfileid, const char *name, double *array)
 }
 
 static void
-cdfReadCoordinateRadian(int ncfileid, const char *name, size_t size, double *array)
+cdf_read_coordinate_radian(int ncfileid, const char *name, size_t size, double *array)
 {
   int ncvarid;
   nce(nc_inq_varid(ncfileid, name, &ncvarid));
   nce(nc_get_var_double(ncfileid, ncvarid, array));
 
   std::string grid_units;
-  cdfReadAttText(ncfileid, ncvarid, "units", grid_units);
+  cdf_read_att_text(ncfileid, ncvarid, "units", grid_units);
   grid_to_radian(grid_units.c_str(), size, array, name);
 }
 
@@ -170,7 +160,7 @@ struct RemapGridW
   }
 };
 
-void
+static void
 remapGridWAlloc(RemapMethod mapType, RemapGridW &grid)
 {
   if (mapType == RemapMethod::CONSERV_SCRIP || mapType == RemapMethod::CONSERV)
@@ -181,17 +171,15 @@ remapGridWAlloc(RemapMethod mapType, RemapGridW &grid)
 
 struct RemapVarsW
 {
-  bool sort_add;
-  RemapMethod mapType;  // identifier for remapping method
-  NormOpt normOpt;      // option for normalization (conserv only)
-  size_t num_links;     // number of links for remapping
-  size_t num_wts;       // num of weights used in remapping
+  bool sort_add = false;
+  RemapMethod mapType{ RemapMethod::UNDEF };  // identifier for remapping method
+  NormOpt normOpt{ NormOpt::NONE };           // option for normalization (conserv only)
+  size_t num_links = 0;                       // number of links for remapping
+  size_t num_wts = 0;                         // number of weights used in remapping
 
-  std::vector<size_t> src_cell_add;  // source grid address for each link
-  std::vector<size_t> tgt_cell_add;  // target grid address for each link
-  Varray<double> wts;           // map weights for each link [num_links*num_wts]
-
-  RemapVarsW() : sort_add(false), num_links(0), num_wts(0) {}
+  std::vector<size_t> srcCellIndices;  // source grid indices for each link
+  std::vector<size_t> tgtCellIndices;  // target grid indices for each link
+  Varray<double> wts;                  // map weights for each link [num_links*num_wts]
 };
 
 static void
@@ -214,75 +202,75 @@ remapGetNormOpt(const std::string &normOptStr)
   else if (normOptStr == "destarea") normOpt = NormOpt::DESTAREA;
   else
     {
-      cdoPrint("normalize_opt = %s", normOptStr.c_str());
-      cdoAbort("Invalid normalization option");
+      cdo_print("normalize_opt = %s", normOptStr);
+      cdo_abort("Invalid normalization option");
     }
   // clang-format on
 
-  if (Options::cdoVerbose) cdoPrint("normalize_opt = %s", normOptStr.c_str());
+  if (Options::cdoVerbose) cdo_print("normalize_opt = %s", normOptStr);
 
   return normOpt;
 }
 
-RemapMethod getMapType(int ncfileid, SubmapType *submapType, int *numNeighbors, int &remapOrder);
+RemapMethod getMapType(int ncfileid, SubmapType &submapType, int &numNeighbors, int &remapOrder);
 
 static void
-readRemapGridScrip(const int ncfileid, const std::string prefix, bool lgridarea, RemapGridW &grid)
+read_remapgrid_scrip(const int ncfileid, const std::string &prefix, bool lgridarea, RemapGridW &grid)
 {
   // Read all variables of the grid
-  cdfReadVarSize(ncfileid, (prefix + "_dims").c_str(), 2, grid.dims);
+  cdf_read_var_size(ncfileid, (prefix + "_dims").c_str(), 2, grid.dims);
 
-  cdfReadVarInt(ncfileid, (prefix + "_imask").c_str(), grid.mask.data());
+  cdf_read_var_int(ncfileid, (prefix + "_imask").c_str(), grid.mask.data());
 
-  cdfReadCoordinateRadian(ncfileid, (prefix + "_center_lat").c_str(), grid.ncells, grid.cell_center_lat.data());
-  cdfReadCoordinateRadian(ncfileid, (prefix + "_center_lon").c_str(), grid.ncells, grid.cell_center_lon.data());
+  cdf_read_coordinate_radian(ncfileid, (prefix + "_center_lat").c_str(), grid.ncells, grid.cell_center_lat.data());
+  cdf_read_coordinate_radian(ncfileid, (prefix + "_center_lon").c_str(), grid.ncells, grid.cell_center_lon.data());
 
   if (grid.ncorners)
     {
       const size_t size = grid.ncorners * grid.ncells;
-      cdfReadCoordinateRadian(ncfileid, (prefix + "_corner_lat").c_str(), size, grid.cell_corner_lat.data());
-      cdfReadCoordinateRadian(ncfileid, (prefix + "_corner_lon").c_str(), size, grid.cell_corner_lon.data());
+      cdf_read_coordinate_radian(ncfileid, (prefix + "_corner_lat").c_str(), size, grid.cell_corner_lat.data());
+      cdf_read_coordinate_radian(ncfileid, (prefix + "_corner_lon").c_str(), size, grid.cell_corner_lon.data());
     }
 
-  if (lgridarea) cdfReadVarDouble(ncfileid, (prefix + "_area").c_str(), grid.cell_area.data());
-  cdfReadVarDouble(ncfileid, (prefix + "_frac").c_str(), grid.cell_frac.data());
+  if (lgridarea) cdf_read_var_double(ncfileid, (prefix + "_area").c_str(), grid.cell_area.data());
+  cdf_read_var_double(ncfileid, (prefix + "_frac").c_str(), grid.cell_frac.data());
 }
 
 static void
-readRemapWeightsScrip(const int ncfileid, RemapVarsW &rv)
+read_remapweights_scrip(const int ncfileid, RemapVarsW &rv)
 {
-  cdfReadVarSize(ncfileid, "src_address", rv.num_links, rv.src_cell_add.data());
-  cdfReadVarSize(ncfileid, "dst_address", rv.num_links, rv.tgt_cell_add.data());
+  cdf_read_var_size(ncfileid, "src_address", rv.num_links, rv.srcCellIndices.data());
+  cdf_read_var_size(ncfileid, "tgt_address", rv.num_links, rv.tgtCellIndices.data());
 
-  for (size_t i = 0; i < rv.num_links; ++i) rv.src_cell_add[i]--;
-  for (size_t i = 0; i < rv.num_links; ++i) rv.tgt_cell_add[i]--;
+  for (size_t i = 0; i < rv.num_links; ++i) rv.srcCellIndices[i]--;
+  for (size_t i = 0; i < rv.num_links; ++i) rv.tgtCellIndices[i]--;
 
-  cdfReadVarDouble(ncfileid, "remap_matrix", rv.wts.data());
+  cdf_read_var_double(ncfileid, "remap_matrix", rv.wts.data());
 }
 
 static void
 readRemapFileScrip(const char *remapFile, RemapAttributes &remapAtts, RemapMethod &mapType, SubmapType &submapType,
-                   int &numNeighbors, int &remapOrder, RemapGridW &src_grid, RemapGridW &tgt_grid, RemapVarsW &rv)
+                   int &numNeighbors, int &remapOrder, RemapGridW &srcGrid, RemapGridW &tgtGrid, RemapVarsW &rv)
 {
   // The routine reads a NetCDF file to extract remapping info in SCRIP format
 
   // Open file and read some global information
-  const int ncfileid = cdo_cdf_openread(remapFile);
+  const auto ncfileid = cdo_cdf_openread(remapFile);
 
-  cdfReadAttText(ncfileid, NC_GLOBAL, "history", remapAtts.history);
+  cdf_read_att_text(ncfileid, NC_GLOBAL, "history", remapAtts.history);
 
   // Map name
-  cdfReadAttText(ncfileid, NC_GLOBAL, "title", remapAtts.map_name);
+  cdf_read_att_text(ncfileid, NC_GLOBAL, "title", remapAtts.map_name);
 
   if (Options::cdoVerbose)
     {
-      cdoPrint("Reading remapping: %s", remapAtts.map_name.c_str());
-      cdoPrint("From file: %s", remapFile);
+      cdo_print("Reading remapping: %s", remapAtts.map_name);
+      cdo_print("From file: %s", remapFile);
     }
 
   // Map Type
-  mapType = getMapType(ncfileid, &submapType, &numNeighbors, remapOrder);
-  const bool lgridarea = (mapType == RemapMethod::CONSERV || mapType == RemapMethod::CONSERV_SCRIP);
+  mapType = getMapType(ncfileid, submapType, numNeighbors, remapOrder);
+  const auto lgridarea = (mapType == RemapMethod::CONSERV || mapType == RemapMethod::CONSERV_SCRIP);
 
   remapVarsWInit(mapType, remapOrder, rv);
 
@@ -291,65 +279,65 @@ readRemapFileScrip(const char *remapFile, RemapAttributes &remapAtts, RemapMetho
 
   // Normalization option
   std::string normalizeOptStr;  // character string for normalization option
-  cdfReadAttText(ncfileid, NC_GLOBAL, "normalization", normalizeOptStr);
+  cdf_read_att_text(ncfileid, NC_GLOBAL, "normalization", normalizeOptStr);
   rv.normOpt = remapGetNormOpt(normalizeOptStr);
 
   // File convention
   std::string convention;  // character string for output convention
-  cdfReadAttText(ncfileid, NC_GLOBAL, "conventions", convention);
+  cdf_read_att_text(ncfileid, NC_GLOBAL, "conventions", convention);
   if (convention != "SCRIP")
     {
-      cdoPrint("convention = %s", convention.c_str());
+      cdo_print("convention = %s", convention);
       if (convention == "NCAR-CSM")
-        cdoAbort("Unsupported file convention: %s!", convention.c_str());
+        cdo_abort("Unsupported file convention: %s!", convention);
       else
-        cdoAbort("Unknown file convention!");
+        cdo_abort("Unknown file convention!");
     }
 
   // Read some additional global attributes
 
   // Source and destination grid names
-  cdfReadAttText(ncfileid, NC_GLOBAL, "source_grid", src_grid.name);
-  cdfReadAttText(ncfileid, NC_GLOBAL, "dest_grid", tgt_grid.name);
+  cdf_read_att_text(ncfileid, NC_GLOBAL, "source_grid", srcGrid.name);
+  cdf_read_att_text(ncfileid, NC_GLOBAL, "dest_grid", tgtGrid.name);
 
-  if (Options::cdoVerbose) cdoPrint("Remapping between: %s and %s", src_grid.name.c_str(), tgt_grid.name.c_str());
+  if (Options::cdoVerbose) cdo_print("Remapping between: %s and %s", srcGrid.name, tgtGrid.name);
 
   // Read dimension information
-  src_grid.setNumCells(cdfReadDimlen(ncfileid, "src_grid_size"));
-  tgt_grid.setNumCells(cdfReadDimlen(ncfileid, "dst_grid_size"));
+  srcGrid.setNumCells(cdf_read_dimlen(ncfileid, "src_grid_size"));
+  tgtGrid.setNumCells(cdf_read_dimlen(ncfileid, "dst_grid_size"));
 
-  src_grid.setNumCorners(cdfReadDimlen(ncfileid, "src_grid_corners"));
-  tgt_grid.setNumCorners(cdfReadDimlen(ncfileid, "dst_grid_corners"));
+  srcGrid.setNumCorners(cdf_read_dimlen(ncfileid, "src_grid_corners"));
+  tgtGrid.setNumCorners(cdf_read_dimlen(ncfileid, "dst_grid_corners"));
 
-  src_grid.rank = cdfReadDimlen(ncfileid, "src_grid_rank");
-  tgt_grid.rank = cdfReadDimlen(ncfileid, "dst_grid_rank");
+  srcGrid.rank = cdf_read_dimlen(ncfileid, "src_grid_rank");
+  tgtGrid.rank = cdf_read_dimlen(ncfileid, "dst_grid_rank");
 
-  remapGridWAlloc(rv.mapType, src_grid);
-  remapGridWAlloc(rv.mapType, tgt_grid);
+  remapGridWAlloc(rv.mapType, srcGrid);
+  remapGridWAlloc(rv.mapType, tgtGrid);
 
-  rv.num_links = cdfReadDimlen(ncfileid, "num_links");
-  //  if ( rv.num_links == 0 ) cdoAbort("Number of remap links is 0, no remap weights found!");
-  rv.num_wts = cdfReadDimlen(ncfileid, "num_wgts");
+  rv.num_links = cdf_read_dimlen(ncfileid, "num_links");
+  //  if ( rv.num_links == 0 ) cdo_abort("Number of remap links is 0, no remap weights found!");
+  rv.num_wts = cdf_read_dimlen(ncfileid, "num_wgts");
 
   // Allocate address and weight arrays
   if (rv.num_links > 0)
     {
-      rv.src_cell_add.resize(rv.num_links);
-      rv.tgt_cell_add.resize(rv.num_links);
+      rv.srcCellIndices.resize(rv.num_links);
+      rv.tgtCellIndices.resize(rv.num_links);
       rv.wts.resize(rv.num_wts * rv.num_links);
     }
 
-  readRemapGridScrip(ncfileid, "src_grid", lgridarea, src_grid);
-  readRemapGridScrip(ncfileid, "dst_grid", lgridarea, tgt_grid);
+  read_remapgrid_scrip(ncfileid, "src_grid", lgridarea, srcGrid);
+  read_remapgrid_scrip(ncfileid, "dst_grid", lgridarea, tgtGrid);
 
-  if (rv.num_links > 0) readRemapWeightsScrip(ncfileid, rv);
+  if (rv.num_links > 0) read_remapweights_scrip(ncfileid, rv);
 
   // Close input file
   cdo_cdf_close(ncfileid);
-}  // remapReadDataScrip
+}  // readRemapFileScrip
 
 static int
-cdfDefDim(int ncfileid, const char *name, size_t len)
+cdf_def_dim(int ncfileid, const char *name, size_t len)
 {
   int ncdimid = -1;
   nce(nc_def_dim(ncfileid, name, len, &ncdimid));
@@ -357,7 +345,7 @@ cdfDefDim(int ncfileid, const char *name, size_t len)
 }
 
 static int
-cdfDefVar(int ncfileid, const char *name, nc_type xtype, int ndims, const int *dimidsp)
+cdf_def_var(int ncfileid, const char *name, nc_type xtype, int ndims, const int *dimidsp)
 {
   int ncvarid = -1;
   nce(nc_def_var(ncfileid, name, xtype, ndims, dimidsp, &ncvarid));
@@ -402,43 +390,43 @@ cdfWriteVarSize(int ncfileid, int ncvarid, nc_type sizetype, size_t len, size_t
 }
 
 static void
-checkRemapFilesize(RemapGridW &src_grid, RemapGridW &tgt_grid, RemapVarsW &rv, int &writemode, nc_type &sizetype)
+checkRemapFilesize(const RemapGridW &srcGrid, const RemapGridW &tgtGrid, const RemapVarsW &rv, int &writemode, nc_type &sizetype)
 {
   const size_t nlinks = rv.num_links;
-  const size_t nele1 = 4 * 8 + 4 + src_grid.ncorners * 2 * 8;
-  const size_t nele2 = 4 * 8 + 4 + tgt_grid.ncorners * 2 * 8;
-  const size_t filesize = src_grid.ncells * nele1 + tgt_grid.ncells * nele2 + nlinks * (4 + 4 + rv.num_wts * 8);
+  const size_t nele1 = 4 * 8 + 4 + srcGrid.ncorners * 2 * 8;
+  const size_t nele2 = 4 * 8 + 4 + tgtGrid.ncorners * 2 * 8;
+  const size_t filesize = srcGrid.ncells * nele1 + tgtGrid.ncells * nele2 + nlinks * (4 + 4 + rv.num_wts * 8);
 
   if (Options::cdoVerbose)
     {
-      cdoPrint("Number of remap links:       %zu", nlinks);
-      cdoPrint("Filesize for remap weights: ~%zu", filesize);
+      cdo_print("Number of remap links:       %zu", nlinks);
+      cdo_print("Filesize for remap weights: ~%zu", filesize);
     }
 
   if (filesize > 0x7FFFFC00)  // 2**31 - 1024 (<2GB)
     {
       const size_t maxlinks = 0x3FFFFFFF;  // 1GB
-      const auto gridsizemax = (src_grid.ncells > tgt_grid.ncells) ? src_grid.ncells : tgt_grid.ncells;
+      const auto gridsizemax = (srcGrid.ncells > tgtGrid.ncells) ? srcGrid.ncells : tgtGrid.ncells;
       if (nlinks > maxlinks || filesize > 8 * maxlinks || gridsizemax > 0x7FFFFC00)
         {
 #ifdef HAVE_NETCDF4
-          if (Options::cdoVerbose) cdoPrint("Store weights and links to NetCDF4!");
+          if (Options::cdoVerbose) cdo_print("Store weights and links to NetCDF4!");
           writemode |= NC_NETCDF4;
           if (gridsizemax > 0x7FFFFC00)
             sizetype = NC_UINT64;
           else
             writemode |= NC_CLASSIC_MODEL;
 #else
-          cdoPrint("Number of remap links %zu exceeds maximum of %zu and NetCDF 4 is not available!", nlinks, maxlinks);
+          cdo_print("Number of remap links %zu exceeds maximum of %zu and NetCDF 4 is not available!", nlinks, maxlinks);
 #endif
         }
       else
         {
 #ifdef NC_64BIT_OFFSET
           writemode |= NC_64BIT_OFFSET;
-          if (Options::cdoVerbose) cdoPrint("Store weights and links to NetCDF2!");
+          if (Options::cdoVerbose) cdo_print("Store weights and links to NetCDF2!");
 #else
-          cdoPrint("Filesize for remap weights maybe too large!");
+          cdo_print("Filesize for remap weights maybe too large!");
 #endif
         }
     }
@@ -457,28 +445,28 @@ struct CDFgrid
 };
 
 static CDFgrid
-defineRemapGridScrip(const int ncfileid, const std::string prefix, nc_type sizetype, bool lgridarea, const RemapGridW &grid)
+define_remapgrid_scrip(const int ncfileid, const std::string &prefix, nc_type sizetype, bool lgridarea, const RemapGridW &grid)
 {
   CDFgrid cdfGrid;
 
   // Define grid size dimension
-  int nc_size_id = cdfDefDim(ncfileid, (prefix + "_size").c_str(), grid.ncells);
+  int nc_size_id = cdf_def_dim(ncfileid, (prefix + "_size").c_str(), grid.ncells);
   // Define grid corner dimension
-  int nc_corn_id = grid.ncorners ? cdfDefDim(ncfileid, (prefix + "_corners").c_str(), grid.ncorners) : -1;
+  int nc_corn_id = grid.ncorners ? cdf_def_dim(ncfileid, (prefix + "_corners").c_str(), grid.ncorners) : -1;
   // Define grid rank dimension
-  int nc_rank_id = cdfDefDim(ncfileid, (prefix + "_rank").c_str(), grid.rank);
+  int nc_rank_id = cdf_def_dim(ncfileid, (prefix + "_rank").c_str(), grid.rank);
 
   // Define grid dimensions
-  cdfGrid.dims_id = cdfDefVar(ncfileid, (prefix + "_dims").c_str(), sizetype, 1, &nc_rank_id);
+  cdfGrid.dims_id = cdf_def_var(ncfileid, (prefix + "_dims").c_str(), sizetype, 1, &nc_rank_id);
   // Define grid center latitude array
-  cdfGrid.cntrlat_id = cdfDefVar(ncfileid, (prefix + "_center_lat").c_str(), NC_DOUBLE, 1, &nc_size_id);
+  cdfGrid.cntrlat_id = cdf_def_var(ncfileid, (prefix + "_center_lat").c_str(), NC_DOUBLE, 1, &nc_size_id);
   // Define grid center longitude array
-  cdfGrid.cntrlon_id = cdfDefVar(ncfileid, (prefix + "_center_lon").c_str(), NC_DOUBLE, 1, &nc_size_id);
+  cdfGrid.cntrlon_id = cdf_def_var(ncfileid, (prefix + "_center_lon").c_str(), NC_DOUBLE, 1, &nc_size_id);
 
   // Define grid corner lat/lon arrays
   int nc_dims2_id[2] = { nc_size_id, nc_corn_id };
-  cdfGrid.crnrlat_id = grid.ncorners ? cdfDefVar(ncfileid, (prefix + "_corner_lat").c_str(), NC_DOUBLE, 2, nc_dims2_id) : -1;
-  cdfGrid.crnrlon_id = grid.ncorners ? cdfDefVar(ncfileid, (prefix + "_corner_lon").c_str(), NC_DOUBLE, 2, nc_dims2_id) : -1;
+  cdfGrid.crnrlat_id = grid.ncorners ? cdf_def_var(ncfileid, (prefix + "_corner_lat").c_str(), NC_DOUBLE, 2, nc_dims2_id) : -1;
+  cdfGrid.crnrlon_id = grid.ncorners ? cdf_def_var(ncfileid, (prefix + "_corner_lon").c_str(), NC_DOUBLE, 2, nc_dims2_id) : -1;
 
   // Define units for all coordinate arrays
   std::string gridunits = "radians";
@@ -491,30 +479,28 @@ defineRemapGridScrip(const int ncfileid, const std::string prefix, nc_type sizet
     }
 
   // Define grid mask
-  cdfGrid.imask_id = cdfDefVar(ncfileid, (prefix + "_imask").c_str(), NC_INT, 1, &nc_size_id);
+  cdfGrid.imask_id = cdf_def_var(ncfileid, (prefix + "_imask").c_str(), NC_INT, 1, &nc_size_id);
   cdfWriteAttText(ncfileid, cdfGrid.imask_id, "units", "unitless");
 
   // Define grid area array
   cdfGrid.area_id = -1;  // id for area of source grid cells
   if (lgridarea)
     {
-      cdfGrid.area_id = cdfDefVar(ncfileid, (prefix + "_area").c_str(), NC_DOUBLE, 1, &nc_size_id);
+      cdfGrid.area_id = cdf_def_var(ncfileid, (prefix + "_area").c_str(), NC_DOUBLE, 1, &nc_size_id);
       cdfWriteAttText(ncfileid, cdfGrid.area_id, "units", "square radians");
     }
 
   // Define grid fraction array
-  cdfGrid.frac_id = cdfDefVar(ncfileid, (prefix + "_frac").c_str(), NC_DOUBLE, 1, &nc_size_id);
+  cdfGrid.frac_id = cdf_def_var(ncfileid, (prefix + "_frac").c_str(), NC_DOUBLE, 1, &nc_size_id);
   cdfWriteAttText(ncfileid, cdfGrid.frac_id, "units", "unitless");
 
   return cdfGrid;
 }
 
 static void
-writeRemapGridScrip(const int ncfileid, CDFgrid &cdfGrid, bool lgridarea, RemapGridW &grid)
+write_remapgrid_scrip(const int ncfileid, const CDFgrid &cdfGrid, bool lgridarea, RemapGridW &grid)
 {
-  int dims[2];
-  dims[0] = (int) grid.dims[0];
-  dims[1] = (int) grid.dims[1];
+  int dims[2] = {(int)grid.dims[0], (int)grid.dims[1]};
   cdfWriteVarInt(ncfileid, cdfGrid.dims_id, dims);
 
   cdfWriteVarInt(ncfileid, cdfGrid.imask_id, grid.mask.data());
@@ -534,12 +520,12 @@ writeRemapGridScrip(const int ncfileid, CDFgrid &cdfGrid, bool lgridarea, RemapG
 }
 
 static std::string
-remapSetMapMethod(RemapMethod mapType, SubmapType submapType, int numNeighbors)
+remap_set_mapmethod(RemapMethod mapType, SubmapType submapType, int numNeighbors)
 {
-  std::string mapMethod;
-  const bool submapLAF = (submapType == SubmapType::LAF);
+  const auto submapLAF = (submapType == SubmapType::LAF);
 
   // clang-format off
+  std::string mapMethod;
   switch (mapType)
     {
     case RemapMethod::CONSERV_SCRIP:
@@ -563,8 +549,8 @@ remapSetMapMethod(RemapMethod mapType, SubmapType submapType, int numNeighbors)
 }
 
 static void
-writeRemapFileScrip(const char *remapFile, RemapAttributes &remapAtts, RemapMethod mapType, SubmapType submapType, int numNeighbors,
-                    int remapOrder, RemapGridW &src_grid, RemapGridW &tgt_grid, RemapVarsW &rv)
+write_remapfile_scrip(const char *remapFile, const RemapAttributes &remapAtts, RemapMethod mapType, SubmapType submapType,
+                      int numNeighbors, int remapOrder, RemapGridW &srcGrid, RemapGridW &tgtGrid, RemapVarsW &rv)
 {
   // Writes remap data to a NetCDF file using SCRIP conventions
 
@@ -572,13 +558,13 @@ writeRemapFileScrip(const char *remapFile, RemapAttributes &remapAtts, RemapMeth
 
   int nc_dims2_id[2];  // NetCDF ids for 2d array dims
 
-  const bool lgridarea = mapType == RemapMethod::CONSERV_SCRIP || mapType == RemapMethod::CONSERV;
+  const auto lgridarea = (mapType == RemapMethod::CONSERV_SCRIP || mapType == RemapMethod::CONSERV);
 
-  // if ( rv.num_links == 0 ) cdoAbort("Number of remap links is 0, no remap weights found!");
+  // if ( rv.num_links == 0 ) cdo_abort("Number of remap links is 0, no remap weights found!");
 
   int writemode = NC_CLOBBER;
-  nc_type sizetype = NC_INT;
-  checkRemapFilesize(src_grid, tgt_grid, rv, writemode, sizetype);
+  auto sizetype = NC_INT;
+  checkRemapFilesize(srcGrid, tgtGrid, rv, writemode, sizetype);
 
   // Create NetCDF file for mapping and define some global attributes
   int ncfileid = -1;
@@ -601,7 +587,7 @@ writeRemapFileScrip(const char *remapFile, RemapAttributes &remapAtts, RemapMeth
   cdfWriteAttText(ncfileid, NC_GLOBAL, "normalization", normalizeOptStr);
 
   // Map method
-  std::string mapMethod = remapSetMapMethod(mapType, submapType, numNeighbors);
+  const auto mapMethod = remap_set_mapmethod(mapType, submapType, numNeighbors);
   cdfWriteAttText(ncfileid, NC_GLOBAL, "map_method", mapMethod);
 
   // Remap order
@@ -612,8 +598,8 @@ writeRemapFileScrip(const char *remapFile, RemapAttributes &remapAtts, RemapMeth
   cdfWriteAttText(ncfileid, NC_GLOBAL, "conventions", "SCRIP");
 
   // Source and destination grid names
-  cdfWriteAttText(ncfileid, NC_GLOBAL, "source_grid", src_grid.name);
-  cdfWriteAttText(ncfileid, NC_GLOBAL, "dest_grid", tgt_grid.name);
+  cdfWriteAttText(ncfileid, NC_GLOBAL, "source_grid", srcGrid.name);
+  cdfWriteAttText(ncfileid, NC_GLOBAL, "dest_grid", tgtGrid.name);
 
   // History
   cdfWriteAttText(ncfileid, NC_GLOBAL, "history", remapAtts.history);
@@ -621,20 +607,20 @@ writeRemapFileScrip(const char *remapFile, RemapAttributes &remapAtts, RemapMeth
   cdfWriteAttText(ncfileid, NC_GLOBAL, "CDO", remapAtts.cdo_version);
 
   // Define grids
-  CDFgrid cdfSrcGrid = defineRemapGridScrip(ncfileid, "src_grid", sizetype, lgridarea, src_grid);
-  CDFgrid cdfTgtGrid = defineRemapGridScrip(ncfileid, "dst_grid", sizetype, lgridarea, tgt_grid);
+  const auto cdfSrcGrid = define_remapgrid_scrip(ncfileid, "src_grid", sizetype, lgridarea, srcGrid);
+  const auto cdfTgtGrid = define_remapgrid_scrip(ncfileid, "dst_grid", sizetype, lgridarea, tgtGrid);
 
   // Define map size dimensions
-  const int nc_numlinks_id = cdfDefDim(ncfileid, "num_links", rv.num_links);
-  const int nc_numwgts_id = cdfDefDim(ncfileid, "num_wgts", rv.num_wts);
+  const auto nc_numlinks_id = cdf_def_dim(ncfileid, "num_links", rv.num_links);
+  const auto nc_numwgts_id = cdf_def_dim(ncfileid, "num_wgts", rv.num_wts);
 
   // Define mapping arrays
-  const int nc_srcadd_id = cdfDefVar(ncfileid, "src_address", sizetype, 1, &nc_numlinks_id);
-  const int nc_dstadd_id = cdfDefVar(ncfileid, "dst_address", sizetype, 1, &nc_numlinks_id);
+  const auto nc_srcadd_id = cdf_def_var(ncfileid, "src_address", sizetype, 1, &nc_numlinks_id);
+  const auto nc_dstadd_id = cdf_def_var(ncfileid, "tgt_address", sizetype, 1, &nc_numlinks_id);
 
   nc_dims2_id[0] = nc_numlinks_id;
   nc_dims2_id[1] = nc_numwgts_id;
-  const int nc_rmpmatrix_id = cdfDefVar(ncfileid, "remap_matrix", NC_DOUBLE, 2, nc_dims2_id);
+  const int nc_rmpmatrix_id = cdf_def_var(ncfileid, "remap_matrix", NC_DOUBLE, 2, nc_dims2_id);
 
   // End definition stage
 
@@ -642,27 +628,27 @@ writeRemapFileScrip(const char *remapFile, RemapAttributes &remapAtts, RemapMeth
 
   // Write mapping data
 
-  writeRemapGridScrip(ncfileid, cdfSrcGrid, lgridarea, src_grid);
-  writeRemapGridScrip(ncfileid, cdfTgtGrid, lgridarea, tgt_grid);
+  write_remapgrid_scrip(ncfileid, cdfSrcGrid, lgridarea, srcGrid);
+  write_remapgrid_scrip(ncfileid, cdfTgtGrid, lgridarea, tgtGrid);
 
-  for (size_t i = 0; i < rv.num_links; ++i) rv.src_cell_add[i]++;
-  for (size_t i = 0; i < rv.num_links; ++i) rv.tgt_cell_add[i]++;
+  for (size_t i = 0; i < rv.num_links; ++i) rv.srcCellIndices[i]++;
+  for (size_t i = 0; i < rv.num_links; ++i) rv.tgtCellIndices[i]++;
 
-  cdfWriteVarSize(ncfileid, nc_srcadd_id, sizetype, rv.num_links, rv.src_cell_add.data());
-  cdfWriteVarSize(ncfileid, nc_dstadd_id, sizetype, rv.num_links, rv.tgt_cell_add.data());
+  cdfWriteVarSize(ncfileid, nc_srcadd_id, sizetype, rv.num_links, rv.srcCellIndices.data());
+  cdfWriteVarSize(ncfileid, nc_dstadd_id, sizetype, rv.num_links, rv.tgtCellIndices.data());
   cdfWriteVarDouble(ncfileid, nc_rmpmatrix_id, rv.wts.data());
 
   nce(nc_close(ncfileid));
 
 #else
-  cdoAbort("NetCDF support not compiled in!");
+  cdo_abort("NetCDF support not compiled in!");
 #endif
 
-}  // remapWriteDataScrip
+}  // remap_write_data_scrip
 
 static void
-checkAreas(size_t n_a, const Varray<double> &area_a, const Varray<double> &area_b, size_t n_s, const size_t *col,
-           const size_t *row, const double *S)
+check_areas(size_t n_a, const Varray<double> &area_a, const Varray<double> &area_b, size_t n_s, const size_t *col, const size_t *row,
+           const double *S)
 {
   Varray<double> sum(n_a, 0.0);
 
@@ -678,34 +664,34 @@ checkAreas(size_t n_a, const Varray<double> &area_a, const Varray<double> &area_
 }
 
 static void
-verifyWeights(const char *remapFile)
+verify_weights(const char *remapFile)
 {
   RemapMethod mapType(RemapMethod::UNDEF);
   SubmapType submapType(SubmapType::NONE);
   int numNeighbors = 0;
   int remapOrder = 0;
-  RemapGridW src_grid, tgt_grid;
+  RemapGridW srcGrid, tgtGrid;
   RemapVarsW remapVars;
   RemapAttributes remapAtts;
 
-  readRemapFileScrip(remapFile, remapAtts, mapType, submapType, numNeighbors, remapOrder, src_grid, tgt_grid, remapVars);
+  readRemapFileScrip(remapFile, remapAtts, mapType, submapType, numNeighbors, remapOrder, srcGrid, tgtGrid, remapVars);
 
-  checkAreas(src_grid.ncells, src_grid.cell_area, tgt_grid.cell_area, remapVars.num_links, remapVars.src_cell_add.data(),
-             remapVars.tgt_cell_add.data(), remapVars.wts.data());
+  check_areas(srcGrid.ncells, srcGrid.cell_area, tgtGrid.cell_area, remapVars.num_links, remapVars.srcCellIndices.data(),
+              remapVars.tgtCellIndices.data(), remapVars.wts.data());
 }
 
 static void
-writeRemapScrip(const char *remapFileIn, const char *remapFileOut)
+write_remap_scrip(const char *remapFileIn, const char *remapFileOut)
 {
   RemapMethod mapType(RemapMethod::UNDEF);
   SubmapType submapType(SubmapType::NONE);
   int numNeighbors = 0;
   int remapOrder = 0;
-  RemapGridW src_grid, tgt_grid;
+  RemapGridW srcGrid, tgtGrid;
   RemapVarsW remapVars;
   RemapAttributes remapAtts;
 
-  readRemapFileScrip(remapFileIn, remapAtts, mapType, submapType, numNeighbors, remapOrder, src_grid, tgt_grid, remapVars);
+  readRemapFileScrip(remapFileIn, remapAtts, mapType, submapType, numNeighbors, remapOrder, srcGrid, tgtGrid, remapVars);
 
   /*
   char history[1024] = "date and time";
@@ -714,41 +700,41 @@ writeRemapScrip(const char *remapFileIn, const char *remapFileOut)
     {
       struct tm *date_and_time = localtime(&date_and_time_in_sec);
       (void) strftime(history, 1024, "%d %b %Y : ", date_and_time);
-      strcat(history, commandLine());
+      strcat(history, command_line());
     }
     */
-  if (Options::VersionInfo) remapAtts.cdo_version = cdoComment();
-  writeRemapFileScrip(remapFileOut, remapAtts, mapType, submapType, numNeighbors, remapOrder, src_grid, tgt_grid, remapVars);
+  if (Options::VersionInfo) remapAtts.cdo_version = cdo_comment();
+  write_remapfile_scrip(remapFileOut, remapAtts, mapType, submapType, numNeighbors, remapOrder, srcGrid, tgtGrid, remapVars);
 }
 #endif
 
 void *
 Remapweights(void *argument)
 {
-  cdoInitialize(argument);
+  cdo_initialize(argument);
 
 #ifdef HAVE_LIBNETCDF
-  const auto VERIFYWEIGHTS = cdoOperatorAdd("verifyweights", 0, 1, "remap file name");
-  const auto WRITEREMAPSCRIP = cdoOperatorAdd("writeremapscrip", 0, 2, "input and output remap file name");
+  const auto VERIFYWEIGHTS = cdo_operator_add("verifyweights", 0, 1, "remap file name");
+  const auto WRITEREMAPSCRIP = cdo_operator_add("writeremapscrip", 0, 2, "input and output remap file name");
 
-  const auto operatorID = cdoOperatorID();
+  const auto operatorID = cdo_operator_id();
 
-  operatorInputArg(cdoOperatorEnter(operatorID));
-  const auto nfiles = cdoOperatorF2(operatorID);
-  operatorCheckArgc(nfiles);
+  operator_input_arg(cdo_operator_enter(operatorID));
+  const auto nfiles = cdo_operator_f2(operatorID);
+  operator_check_argc(nfiles);
 
-  const char *remapFileIn = cdoOperatorArgv(0).c_str();
-  const char *remapFileOut = (nfiles == 2) ? cdoOperatorArgv(1).c_str() : nullptr;
+  const char *remapFileIn = cdo_operator_argv(0).c_str();
+  const char *remapFileOut = (nfiles == 2) ? cdo_operator_argv(1).c_str() : nullptr;
 
   // clang-format off
-  if      (operatorID == VERIFYWEIGHTS) verifyWeights(remapFileIn);
-  else if (operatorID == WRITEREMAPSCRIP) writeRemapScrip(remapFileIn, remapFileOut);
+  if      (operatorID == VERIFYWEIGHTS) verify_weights(remapFileIn);
+  else if (operatorID == WRITEREMAPSCRIP) write_remap_scrip(remapFileIn, remapFileOut);
     // clang-format on
 #else
-  cdoAbort("NetCDF support not compiled in!");
+  cdo_abort("NetCDF support not compiled in!");
 #endif
 
-  cdoFinish();
+  cdo_finish();
 
   return nullptr;
 }
