@@ -158,7 +158,7 @@ Select(void *process)
   operator_input_arg(cdo_operator_enter(operatorID));
 
   const auto argc = cdo_operator_argc();
-  auto argnames = cdo_get_oper_argv();
+  const auto &argnames = cdo_get_oper_argv();
 
   if (argc == 0) cdo_abort("Parameter missing!");
 
