@@ -70,23 +70,17 @@
 #include "util_date.h"
 #include "param_conversion.h"
 #include "progress.h"
+#include "field_functions.h"
 
-enum
-{
-  HOUR_LEN = 4,
-  DAY_LEN = 6,
-  MON_LEN = 8,
-  YEAR_LEN = 10
-};
 
 static void
-vlist_set_frequency(const int vlistID, const int comparelen)
+vlist_set_frequency(const int vlistID, const int compareDate)
 {
   const char *freq = nullptr;
   // clang-format off
-  if      (comparelen == DAY_LEN)  freq = "day";
-  else if (comparelen == MON_LEN)  freq = "mon";
-  else if (comparelen == YEAR_LEN) freq = "year";
+  if      (compareDate == CMP_DAY)   freq = "day";
+  else if (compareDate == CMP_MONTH) freq = "mon";
+  else if (compareDate == CMP_YEAR)  freq = "year";
   // clang-format on
   if (freq) cdiDefAttTxt(vlistID, CDI_GLOBAL, "frequency", (int) strlen(freq), freq);
 }
@@ -114,60 +108,60 @@ static void
 addOperators(void)
 {
   // clang-format off
-  cdo_operator_add("timrange",   FieldFunc_Range,  DATE_LEN, nullptr);
-  cdo_operator_add("timmin",     FieldFunc_Min,    DATE_LEN, nullptr);
-  cdo_operator_add("timmax",     FieldFunc_Max,    DATE_LEN, nullptr);
-  cdo_operator_add("timminidx",  FieldFunc_Minidx, DATE_LEN, nullptr);
-  cdo_operator_add("timmaxidx",  FieldFunc_Maxidx, DATE_LEN, nullptr);
-  cdo_operator_add("timsum",     FieldFunc_Sum,    DATE_LEN, nullptr);
-  cdo_operator_add("timmean",    FieldFunc_Mean,   DATE_LEN, nullptr);
-  cdo_operator_add("timavg",     FieldFunc_Avg,    DATE_LEN, nullptr);
-  cdo_operator_add("timvar",     FieldFunc_Var,    DATE_LEN, nullptr);
-  cdo_operator_add("timvar1",    FieldFunc_Var1,   DATE_LEN, nullptr);
-  cdo_operator_add("timstd",     FieldFunc_Std,    DATE_LEN, nullptr);
-  cdo_operator_add("timstd1",    FieldFunc_Std1,   DATE_LEN, nullptr);
-  cdo_operator_add("yearrange",  FieldFunc_Range,  YEAR_LEN, nullptr);
-  cdo_operator_add("yearmin",    FieldFunc_Min,    YEAR_LEN, nullptr);
-  cdo_operator_add("yearmax",    FieldFunc_Max,    YEAR_LEN, nullptr);
-  cdo_operator_add("yearminidx", FieldFunc_Minidx, YEAR_LEN, nullptr);
-  cdo_operator_add("yearmaxidx", FieldFunc_Maxidx, YEAR_LEN, nullptr);
-  cdo_operator_add("yearsum",    FieldFunc_Sum,    YEAR_LEN, nullptr);
-  cdo_operator_add("yearmean",   FieldFunc_Mean,   YEAR_LEN, nullptr);
-  cdo_operator_add("yearavg",    FieldFunc_Avg,    YEAR_LEN, nullptr);
-  cdo_operator_add("yearvar",    FieldFunc_Var,    YEAR_LEN, nullptr);
-  cdo_operator_add("yearvar1",   FieldFunc_Var1,   YEAR_LEN, nullptr);
-  cdo_operator_add("yearstd",    FieldFunc_Std,    YEAR_LEN, nullptr);
-  cdo_operator_add("yearstd1",   FieldFunc_Std1,   YEAR_LEN, nullptr);
-  cdo_operator_add("monrange",   FieldFunc_Range,  MON_LEN, nullptr);
-  cdo_operator_add("monmin",     FieldFunc_Min,    MON_LEN, nullptr);
-  cdo_operator_add("monmax",     FieldFunc_Max,    MON_LEN, nullptr);
-  cdo_operator_add("monsum",     FieldFunc_Sum,    MON_LEN, nullptr);
-  cdo_operator_add("monmean",    FieldFunc_Mean,   MON_LEN, nullptr);
-  cdo_operator_add("monavg",     FieldFunc_Avg,    MON_LEN, nullptr);
-  cdo_operator_add("monvar",     FieldFunc_Var,    MON_LEN, nullptr);
-  cdo_operator_add("monvar1",    FieldFunc_Var1,   MON_LEN, nullptr);
-  cdo_operator_add("monstd",     FieldFunc_Std,    MON_LEN, nullptr);
-  cdo_operator_add("monstd1",    FieldFunc_Std1,   MON_LEN, nullptr);
-  cdo_operator_add("dayrange",   FieldFunc_Range,  DAY_LEN, nullptr);
-  cdo_operator_add("daymin",     FieldFunc_Min,    DAY_LEN, nullptr);
-  cdo_operator_add("daymax",     FieldFunc_Max,    DAY_LEN, nullptr);
-  cdo_operator_add("daysum",     FieldFunc_Sum,    DAY_LEN, nullptr);
-  cdo_operator_add("daymean",    FieldFunc_Mean,   DAY_LEN, nullptr);
-  cdo_operator_add("dayavg",     FieldFunc_Avg,    DAY_LEN, nullptr);
-  cdo_operator_add("dayvar",     FieldFunc_Var,    DAY_LEN, nullptr);
-  cdo_operator_add("dayvar1",    FieldFunc_Var1,   DAY_LEN, nullptr);
-  cdo_operator_add("daystd",     FieldFunc_Std,    DAY_LEN, nullptr);
-  cdo_operator_add("daystd1",    FieldFunc_Std1,   DAY_LEN, nullptr);
-  cdo_operator_add("hourrange",  FieldFunc_Range,  HOUR_LEN, nullptr);
-  cdo_operator_add("hourmin",    FieldFunc_Min,    HOUR_LEN, nullptr);
-  cdo_operator_add("hourmax",    FieldFunc_Max,    HOUR_LEN, nullptr);
-  cdo_operator_add("hoursum",    FieldFunc_Sum,    HOUR_LEN, nullptr);
-  cdo_operator_add("hourmean",   FieldFunc_Mean,   HOUR_LEN, nullptr);
-  cdo_operator_add("houravg",    FieldFunc_Avg,    HOUR_LEN, nullptr);
-  cdo_operator_add("hourvar",    FieldFunc_Var,    HOUR_LEN, nullptr);
-  cdo_operator_add("hourvar1",   FieldFunc_Var1,   HOUR_LEN, nullptr);
-  cdo_operator_add("hourstd",    FieldFunc_Std,    HOUR_LEN, nullptr);
-  cdo_operator_add("hourstd1",   FieldFunc_Std1,   HOUR_LEN, nullptr);
+  cdo_operator_add("timrange",   FieldFunc_Range,  CMP_DATE, nullptr);
+  cdo_operator_add("timmin",     FieldFunc_Min,    CMP_DATE, nullptr);
+  cdo_operator_add("timmax",     FieldFunc_Max,    CMP_DATE, nullptr);
+  cdo_operator_add("timminidx",  FieldFunc_Minidx, CMP_DATE, nullptr);
+  cdo_operator_add("timmaxidx",  FieldFunc_Maxidx, CMP_DATE, nullptr);
+  cdo_operator_add("timsum",     FieldFunc_Sum,    CMP_DATE, nullptr);
+  cdo_operator_add("timmean",    FieldFunc_Mean,   CMP_DATE, nullptr);
+  cdo_operator_add("timavg",     FieldFunc_Avg,    CMP_DATE, nullptr);
+  cdo_operator_add("timvar",     FieldFunc_Var,    CMP_DATE, nullptr);
+  cdo_operator_add("timvar1",    FieldFunc_Var1,   CMP_DATE, nullptr);
+  cdo_operator_add("timstd",     FieldFunc_Std,    CMP_DATE, nullptr);
+  cdo_operator_add("timstd1",    FieldFunc_Std1,   CMP_DATE, nullptr);
+  cdo_operator_add("yearrange",  FieldFunc_Range,  CMP_YEAR, nullptr);
+  cdo_operator_add("yearmin",    FieldFunc_Min,    CMP_YEAR, nullptr);
+  cdo_operator_add("yearmax",    FieldFunc_Max,    CMP_YEAR, nullptr);
+  cdo_operator_add("yearminidx", FieldFunc_Minidx, CMP_YEAR, nullptr);
+  cdo_operator_add("yearmaxidx", FieldFunc_Maxidx, CMP_YEAR, nullptr);
+  cdo_operator_add("yearsum",    FieldFunc_Sum,    CMP_YEAR, nullptr);
+  cdo_operator_add("yearmean",   FieldFunc_Mean,   CMP_YEAR, nullptr);
+  cdo_operator_add("yearavg",    FieldFunc_Avg,    CMP_YEAR, nullptr);
+  cdo_operator_add("yearvar",    FieldFunc_Var,    CMP_YEAR, nullptr);
+  cdo_operator_add("yearvar1",   FieldFunc_Var1,   CMP_YEAR, nullptr);
+  cdo_operator_add("yearstd",    FieldFunc_Std,    CMP_YEAR, nullptr);
+  cdo_operator_add("yearstd1",   FieldFunc_Std1,   CMP_YEAR, nullptr);
+  cdo_operator_add("monrange",   FieldFunc_Range,  CMP_MONTH, nullptr);
+  cdo_operator_add("monmin",     FieldFunc_Min,    CMP_MONTH, nullptr);
+  cdo_operator_add("monmax",     FieldFunc_Max,    CMP_MONTH, nullptr);
+  cdo_operator_add("monsum",     FieldFunc_Sum,    CMP_MONTH, nullptr);
+  cdo_operator_add("monmean",    FieldFunc_Mean,   CMP_MONTH, nullptr);
+  cdo_operator_add("monavg",     FieldFunc_Avg,    CMP_MONTH, nullptr);
+  cdo_operator_add("monvar",     FieldFunc_Var,    CMP_MONTH, nullptr);
+  cdo_operator_add("monvar1",    FieldFunc_Var1,   CMP_MONTH, nullptr);
+  cdo_operator_add("monstd",     FieldFunc_Std,    CMP_MONTH, nullptr);
+  cdo_operator_add("monstd1",    FieldFunc_Std1,   CMP_MONTH, nullptr);
+  cdo_operator_add("dayrange",   FieldFunc_Range,  CMP_DAY, nullptr);
+  cdo_operator_add("daymin",     FieldFunc_Min,    CMP_DAY, nullptr);
+  cdo_operator_add("daymax",     FieldFunc_Max,    CMP_DAY, nullptr);
+  cdo_operator_add("daysum",     FieldFunc_Sum,    CMP_DAY, nullptr);
+  cdo_operator_add("daymean",    FieldFunc_Mean,   CMP_DAY, nullptr);
+  cdo_operator_add("dayavg",     FieldFunc_Avg,    CMP_DAY, nullptr);
+  cdo_operator_add("dayvar",     FieldFunc_Var,    CMP_DAY, nullptr);
+  cdo_operator_add("dayvar1",    FieldFunc_Var1,   CMP_DAY, nullptr);
+  cdo_operator_add("daystd",     FieldFunc_Std,    CMP_DAY, nullptr);
+  cdo_operator_add("daystd1",    FieldFunc_Std1,   CMP_DAY, nullptr);
+  cdo_operator_add("hourrange",  FieldFunc_Range,  CMP_HOUR, nullptr);
+  cdo_operator_add("hourmin",    FieldFunc_Min,    CMP_HOUR, nullptr);
+  cdo_operator_add("hourmax",    FieldFunc_Max,    CMP_HOUR, nullptr);
+  cdo_operator_add("hoursum",    FieldFunc_Sum,    CMP_HOUR, nullptr);
+  cdo_operator_add("hourmean",   FieldFunc_Mean,   CMP_HOUR, nullptr);
+  cdo_operator_add("houravg",    FieldFunc_Avg,    CMP_HOUR, nullptr);
+  cdo_operator_add("hourvar",    FieldFunc_Var,    CMP_HOUR, nullptr);
+  cdo_operator_add("hourvar1",   FieldFunc_Var1,   CMP_HOUR, nullptr);
+  cdo_operator_add("hourstd",    FieldFunc_Std,    CMP_HOUR, nullptr);
+  cdo_operator_add("hourstd1",   FieldFunc_Std1,   CMP_HOUR, nullptr);
   // clang-format on
 }
 
@@ -175,12 +169,11 @@ void *
 Timstat(void *argument)
 {
   const TimeStat timestat_date = TimeStat::MEAN;
-  int64_t vdate0 = 0;
-  int vtime0 = 0;
+  CdiDateTime vDateTime0 = { };
+  CdiDateTime vDateTimeN = { };
   CdoStreamID streamID3;
   int vlistID3, taxisID3 = -1;
   bool lvfrac = false;
-  char indate1[DATE_LEN + 1], indate2[DATE_LEN + 1];
   double vfrac = 1;
 
   cdo_initialize(argument);
@@ -189,7 +182,7 @@ Timstat(void *argument)
 
   const auto operatorID = cdo_operator_id();
   const auto operfunc = cdo_operator_f1(operatorID);
-  const auto comparelen = cdo_operator_f2(operatorID);
+  const auto compareDate = cdo_operator_f2(operatorID);
 
   const auto lminidx = (operfunc == FieldFunc_Minidx);
   const auto lmaxidx = (operfunc == FieldFunc_Maxidx);
@@ -221,8 +214,6 @@ Timstat(void *argument)
       operator_check_argc(0);
     }
 
-  const int cmplen = DATE_LEN - comparelen;
-
   const auto streamID1 = cdo_open_read(0);
 
   const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
@@ -230,7 +221,7 @@ Timstat(void *argument)
 
   vlist_define_timestep_type(vlistID2, operfunc);
 
-  vlistDefNtsteps(vlistID2, (cmplen == 0) ? 1 : -1);
+  vlistDefNtsteps(vlistID2, (compareDate == CMP_DATE) ? 1 : -1);
 
   const auto taxisID1 = vlistInqTaxis(vlistID1);
   const auto taxisID2 = taxisDuplicate(taxisID1);
@@ -243,7 +234,7 @@ Timstat(void *argument)
   if (lminidx || lmaxidx)
     for (int varID = 0; varID < nvars; ++varID) vlistDefVarDatatype(vlistID2, varID, CDI_DATATYPE_INT32);
 
-  vlist_set_frequency(vlistID2, comparelen);
+  vlist_set_frequency(vlistID2, compareDate);
 
   const auto streamID2 = cdo_open_write(1);
   cdo_def_vlist(streamID2, vlistID2);
@@ -316,15 +307,17 @@ Timstat(void *argument)
           if (!Options::cdoVerbose && ntsteps1 > 1) progress::update(0, 1, (tsID + 1.0) / ntsteps1);
 
           dtlist.taxis_inq_timestep(taxisID1, nsets);
-          const auto vdate = dtlist.get_vdate(nsets);
-          const auto vtime = dtlist.get_vtime(nsets);
+          const auto vDateTime = dtlist.get_vDateTime(nsets);
 
-          if (nsets == 0) SET_DATE(indate2, vdate, vtime);
-          SET_DATE(indate1, vdate, vtime);
+          if (nsets == 0) vDateTime0 = vDateTime;
 
-          if (DATE_IS_NEQ(indate1, indate2, cmplen)) break;
+          if (date_is_neq(vDateTime, vDateTime0, compareDate))
+            {
+              cdo_add_steps(-1);
+              break;
+            }
 
-          for (int recID = 0; recID < nrecs; recID++)
+          for (int recID = 0; recID < nrecs; ++recID)
             {
               int varID, levelID;
               cdo_inq_record(streamID1, &varID, &levelID);
@@ -378,7 +371,7 @@ Timstat(void *argument)
             }
 
           if (nsets == 0 && lvarstd)
-            for (int recID = 0; recID < maxrecs; recID++)
+            for (int recID = 0; recID < maxrecs; ++recID)
               {
                 if (recList[recID].lconst) continue;
 
@@ -387,15 +380,14 @@ Timstat(void *argument)
                 field2_moq(vars2[varID][levelID], vars1[varID][levelID]);
               }
 
-          vdate0 = vdate;
-          vtime0 = vtime;
+          vDateTimeN = vDateTime;
           nsets++;
           tsID++;
         }
 
       if (nrecs == 0 && nsets == 0) break;
 
-      for (int recID = 0; recID < maxrecs; recID++)
+      for (int recID = 0; recID < maxrecs; ++recID)
         {
           if (recList[recID].lconst) continue;
 
@@ -425,10 +417,10 @@ Timstat(void *argument)
         }
 
       if (Options::cdoVerbose)
-        cdo_print("%s %s  vfrac = %g, nsets = %d", date_to_string(vdate0).c_str(), time_to_string(vtime0).c_str(), vfrac, nsets);
+        cdo_print("%s  vfrac = %g, nsets = %d", datetime_to_string(vDateTimeN), vfrac, nsets);
 
       if (lvfrac && operfunc == FieldFunc_Mean)
-        for (int recID = 0; recID < maxrecs; recID++)
+        for (int recID = 0; recID < maxrecs; ++recID)
           {
             if (recList[recID].lconst) continue;
 
@@ -448,7 +440,7 @@ Timstat(void *argument)
           cdo_def_timestep(streamID3, otsID);
         }
 
-      for (int recID = 0; recID < maxrecs; recID++)
+      for (int recID = 0; recID < maxrecs; ++recID)
         {
           if (otsID && recList[recID].lconst) continue;
 
