@@ -17,6 +17,7 @@
 #include <cstdlib>
 #include <cassert>
 #include <cdi.h>
+#include "julian_date.h"
 
 #include "cdo_options.h"
 #include "process_int.h"
@@ -27,7 +28,6 @@
 #include "griddes.h"
 #include "constants.h"
 #include "stdnametable.h"
-#include "timebase.h"
 #include "param_conversion.h"
 
 static constexpr double etopo_scale = 3.0;
@@ -130,12 +130,12 @@ remap_nn_reg2d_to_reg2d(size_t nx, size_t ny, const Varray<double> &data, const
   cdo_grid_to_degree(gridID, CDI_YAXIS, nyvals, yvals.data(), "grid center lat");
 
 #ifdef _OPENMP
-#pragma omp parallel for default(none) schedule(static) shared(nx, ny, nxvals, nyvals, xvals, yvals, data, array)
+#pragma omp parallel for default(shared) schedule(static)
 #endif
-  for (size_t j = 0; j < nyvals; j++)
+  for (size_t j = 0; j < nyvals; ++j)
     {
       const auto jj = calc_index_jj(ny, yvals[j]);
-      for (size_t i = 0; i < nxvals; i++)
+      for (size_t i = 0; i < nxvals; ++i)
         {
           const auto ii = calc_index_ii(nx, xvals[i]);
           array[j * nxvals + i] = data[jj * nx + ii];
@@ -150,7 +150,9 @@ remap_nn_reg2d_to_nonreg2d(const size_t nx, const size_t ny, const Varray<double
   const auto gridsize = gridInqSize(gridID2);
   Varray<double> xvals(gridsize), yvals(gridsize);
 
-  if (gridInqType(gridID2) == GRID_GME || gridInqType(gridID2) == GRID_GAUSSIAN_REDUCED) gridID2 = gridToUnstructured(gridID2, 0);
+  if (gridInqType(gridID2) == GRID_GME || gridInqType(gridID2) == GRID_GAUSSIAN_REDUCED ||
+      (gridInqType(gridID2) == GRID_PROJECTION && gridInqProjType(gridID2) == CDI_PROJ_HEALPIX))
+      gridID2 = gridToUnstructured(gridID2, 0);
 
   if (gridInqType(gridID2) != GRID_UNSTRUCTURED && gridInqType(gridID2) != GRID_CURVILINEAR)
     gridID2 = gridToCurvilinear(gridID2, 0);
@@ -162,7 +164,7 @@ remap_nn_reg2d_to_nonreg2d(const size_t nx, const size_t ny, const Varray<double
   cdo_grid_to_degree(gridID2, CDI_XAXIS, gridsize, xvals.data(), "grid center lon");
   cdo_grid_to_degree(gridID2, CDI_YAXIS, gridsize, yvals.data(), "grid center lat");
 
-  for (size_t i = 0; i < gridsize; i++)
+  for (size_t i = 0; i < gridsize; ++i)
     {
       const auto jj = calc_index_jj(ny, yvals[i]);
       const auto ii = calc_index_ii(nx, xvals[i]);
@@ -342,8 +344,8 @@ Vargen(void *process)
       gridDefXsize(gridIDdata, nlon);
       gridDefYsize(gridIDdata, nlat);
 
-      for (size_t i = 0; i < nlon; i++) lon[i] = -179.75 + i * 0.5;
-      for (size_t i = 0; i < nlat; i++) lat[i] = -89.75 + i * 0.5;
+      for (size_t i = 0; i < nlon; ++i) lon[i] = -179.75 + i * 0.5;
+      for (size_t i = 0; i < nlat; ++i) lat[i] = -89.75 + i * 0.5;
 
       gridDefXvals(gridIDdata, lon);
       gridDefYvals(gridIDdata, lat);
@@ -426,19 +428,18 @@ Vargen(void *process)
 
   const auto nvars = vlistNvars(vlistID);
 
-  for (int tsID = 0; tsID < ntimesteps; tsID++)
+  for (int tsID = 0; tsID < ntimesteps; ++tsID)
     {
       const auto rval = rstart + rinc * tsID;
-      const auto vdate = julday_to_date(CALENDAR_PROLEPTIC, julday + tsID);
-      const int vtime = 0;
-      taxisDefVdate(taxisID, vdate);
-      taxisDefVtime(taxisID, vtime);
+      CdiDateTime vDateTime = { };
+      vDateTime.date = cdiDate_set(julday_to_date(CALENDAR_PROLEPTIC, julday + tsID));
+      taxisDefVdatetime(taxisID, vDateTime);
       cdo_def_timestep(streamID, tsID);
 
-      for (varID = 0; varID < nvars; varID++)
+      for (varID = 0; varID < nvars; ++varID)
         {
           nlevels = zaxisInqSize(vlistInqVarZaxis(vlistID, varID));
-          for (int levelID = 0; levelID < nlevels; levelID++)
+          for (int levelID = 0; levelID < nlevels; ++levelID)
             {
               cdo_def_record(streamID, varID, levelID);
 
@@ -484,7 +485,7 @@ Vargen(void *process)
                 }
               else if (operatorID == CONST)
                 {
-                  for (size_t i = 0; i < gridsize; i++) array[i] = rconst;
+                  for (size_t i = 0; i < gridsize; ++i) array[i] = rconst;
                 }
               else if (operatorID == TOPO || operatorID == TEMP || operatorID == MASK)
                 {
