@@ -756,14 +756,14 @@ cdo_set_options()
 }
 
 static long
-cstrToNumBytes(const char *intstring)
+stringToNumBytes(const std::string &intstring)
 {
   long intval = -1;
 
-  if (intstring)
+  const auto len = (int) intstring.size();
+  if (len)
     {
       long fact = 1;
-      const auto len = (int) strlen(intstring);
       for (int loop = 0; loop < len; loop++)
         {
           if (!isdigit((int) intstring[loop]))
@@ -779,7 +779,7 @@ cstrToNumBytes(const char *intstring)
             }
         }
 
-      if (fact) intval = fact * atol(intstring);
+      if (fact) intval = fact * atol(intstring.c_str());
     }
 
   return intval;
@@ -1031,7 +1031,7 @@ setup_cli_options()
   CLIOptions::option("netcdf_hdr_pad")
       ->describe_argument("nbr")
       ->add_effect([&](const std::string &argument) {
-        const int netcdf_hdr_pad = cstrToNumBytes(argument.c_str());
+        const int netcdf_hdr_pad = stringToNumBytes(argument);
         if (netcdf_hdr_pad >= 0) CDO_netcdf_hdr_pad = netcdf_hdr_pad;
       })
       ->add_help("Pad NetCDF output header with nbr bytes.");
@@ -1227,6 +1227,14 @@ setup_cli_options()
       ->add_effect([&](const std::string &argument) { define_chunktype(argument); })
       ->add_help("NetCDF4 chunk type: auto, grid or lines.");
 
+  CLIOptions::option("chunksize")
+      ->describe_argument("size")
+      ->add_effect([&](const std::string &argument) {
+        const int chunkSize = stringToNumBytes(argument);
+        if (chunkSize >= 0) Options::cdoChunkSize = chunkSize;
+      })
+      ->add_help("NetCDF4 chunk size.");
+
   CLIOptions::option("lock_io", "L")->add_effect([&]() { Threading::cdoLockIO = true; })->add_help("Lock IO (sequential access).");
 
   CLIOptions::option("zaxis", "l")
@@ -1432,7 +1440,10 @@ main(int argc, char *argv[])
   setup_cli_options();
 
   int CDO_optind = CLIOptions::parse(std::vector<std::string>(argv, argv + argc));
+
   if (CDO_optind == CLIOptions::ABORT_REQUESTED) exit(EXIT_FAILURE);
+  else if (CDO_optind == CLIOptions::EXIT_REQUESTED) exit(EXIT_SUCCESS);
+
   if (CDO_optind >= argc && !Help)
     {
       fprintf(stderr, "\nNo operator given!\n\n");
@@ -1456,7 +1467,6 @@ main(int argc, char *argv[])
         }
 
       std::vector<std::string> new_argv(&argv[CDO_optind], argv + argc);
-      Debug("ReachedHere");
 
       new_argv = expand_wild_cards(new_argv);
       if (applyDryRun == true)
@@ -1472,7 +1482,7 @@ main(int argc, char *argv[])
       timer_write = timer_new("write");
 
 #ifdef HAVE_NC4HDF5
-      H5dont_atexit();
+      H5dont_atexit(); // don't call H5close on exit
 #endif
 #ifdef CUSTOM_MODULES
       load_custom_modules("custom_modules");
