@@ -18,7 +18,7 @@ printDblsPrefixAutoBrk(FILE *fp, int dig, const char prefix[], int nbyte0, size_
 {
   fputs(prefix, fp);
   auto nbyte = nbyte0;
-  for (size_t i = 0; i < n; i++)
+  for (size_t i = 0; i < n; ++i)
     {
       if (nbyte > 80)
         {
@@ -35,7 +35,7 @@ printIntsPrefixAutoBrk(FILE *fp, const char prefix[], int nbyte0, size_t n, cons
 {
   fputs(prefix, fp);
   auto nbyte = nbyte0;
-  for (size_t i = 0; i < n; i++)
+  for (size_t i = 0; i < n; ++i)
     {
       if (nbyte > 80)
         {
@@ -51,7 +51,7 @@ static void
 printBounds(FILE *fp, int dig, const char prefix[], size_t nbyte0, size_t n, size_t nvertex, const double bounds[])
 {
   fputs(prefix, fp);
-  for (size_t i = 0; i < n; i++)
+  for (size_t i = 0; i < n; ++i)
     {
       if (i > 0) fprintf(fp, "\n%*s", (int) nbyte0, "");
       for (size_t iv = 0; iv < nvertex; iv++) fprintf(fp, "%.*g ", dig, bounds[i * nvertex + iv]);
@@ -64,7 +64,7 @@ printMask(FILE *fp, const char prefix[], size_t nbyte0, size_t n, const int mask
 {
   fputs(prefix, fp);
   auto nbyte = nbyte0;
-  for (size_t i = 0; i < n; i++)
+  for (size_t i = 0; i < n; ++i)
     {
       if (nbyte > 80)
         {
@@ -172,10 +172,10 @@ grid_print_kernel(int gridID, int opt, FILE *fp)
   if (xstrlen)
     {
       xcvals = (char **) Malloc(xsize * sizeof(char *));
-      for (size_t i = 0; i < xsize; i++) xcvals[i] = (char *) Malloc((xstrlen + 1) * sizeof(char));
+      for (size_t i = 0; i < xsize; ++i) xcvals[i] = (char *) Malloc((xstrlen + 1) * sizeof(char));
       gridInqXCvals(gridID, xcvals);
-      for (size_t i = 0; i < xsize; i++) xcvals[i][xstrlen] = 0;
-      for (size_t i = 0; i < xsize; i++)
+      for (size_t i = 0; i < xsize; ++i) xcvals[i][xstrlen] = 0;
+      for (size_t i = 0; i < xsize; ++i)
         for (int k = xstrlen - 1; k; k--)
           {
             if (xcvals[i][k] == ' ')
@@ -189,10 +189,10 @@ grid_print_kernel(int gridID, int opt, FILE *fp)
   if (ystrlen)
     {
       ycvals = (char **) Malloc(ysize * sizeof(char *));
-      for (size_t i = 0; i < ysize; i++) ycvals[i] = (char *) Malloc((ystrlen + 1) * sizeof(char));
+      for (size_t i = 0; i < ysize; ++i) ycvals[i] = (char *) Malloc((ystrlen + 1) * sizeof(char));
       gridInqYCvals(gridID, ycvals);
-      for (size_t i = 0; i < ysize; i++) ycvals[i][ystrlen] = 0;
-      for (size_t i = 0; i < ysize; i++)
+      for (size_t i = 0; i < ysize; ++i) ycvals[i][ystrlen] = 0;
+      for (size_t i = 0; i < ysize; ++i)
         for (int k = ystrlen - 1; k; k--)
           {
             if (ycvals[i][k] == ' ')
@@ -348,10 +348,10 @@ grid_print_kernel(int gridID, int opt, FILE *fp)
               fprintf(fp, "x%ss  = \"%.*s\"", attstr, xstrlen, xcvals[0]);
             else
               fprintf(fp, "xstrings  = \"%.*s\"", xstrlen, xcvals[0]);
-            for (size_t i = 1; i < xsize; i++) fprintf(fp, ", \"%.*s\"", xstrlen, xcvals[i]);
+            for (size_t i = 1; i < xsize; ++i) fprintf(fp, ", \"%.*s\"", xstrlen, xcvals[i]);
             fprintf(fp, "\n");
 
-            for (size_t i = 0; i < xsize; i++) Free(xcvals[i]);
+            for (size_t i = 0; i < xsize; ++i) Free(xcvals[i]);
             Free(xcvals);
           }
 
@@ -395,10 +395,10 @@ grid_print_kernel(int gridID, int opt, FILE *fp)
               fprintf(fp, "x%ss  = \"%.*s\"", attstr, ystrlen, ycvals[0]);
             else
               fprintf(fp, "ystrings  = \"%.*s\"", ystrlen, ycvals[0]);
-            for (size_t i = 1; i < ysize; i++) fprintf(fp, ", \"%.*s\"", ystrlen, ycvals[i]);
+            for (size_t i = 1; i < ysize; ++i) fprintf(fp, ", \"%.*s\"", ystrlen, ycvals[i]);
             fprintf(fp, "\n");
 
-            for (size_t i = 0; i < ysize; i++) Free(ycvals[i]);
+            for (size_t i = 0; i < ysize; ++i) Free(ycvals[i]);
             Free(ycvals);
           }
 
@@ -486,7 +486,7 @@ grid_print_kernel(int gridID, int opt, FILE *fp)
 }
 
 void
-cdoPrintGrid(int gridID, int opt)
+cdo_print_griddes(int gridID, int opt)
 {
   grid_print_kernel(gridID, opt, stdout);
 }
