@@ -1,18 +1,8 @@
 /*
-  This file is part of CDO. CDO is a collection of Operators to
-  manipulate and analyse Climate model Data.
+  This file is part of CDO. CDO is a collection of Operators to manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2020 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
-  See COPYING file for copying and redistribution conditions.
+  Author: Uwe Schulzweida
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; version 2 of the License.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
 */
 #ifndef GRIDDES_H
 #define GRIDDES_H
@@ -21,11 +11,11 @@
 #include <string>
 #include <cdi.h>
 
-constexpr double undef_grid_value = 9.e20;
+constexpr double undefGridValue = 9.e20;
 
 struct // GridDesciption
-#ifdef  __GNUG__
-__attribute__((warn_unused))
+#ifdef WARN_UNUSED
+[[gnu::warn_unused]]
 #endif
 GridDesciption
 {
@@ -36,9 +26,9 @@ GridDesciption
   std::vector<double> ybounds;
   std::vector<double> area;
   std::vector<int> reducedPoints;
-  double xfirst = undef_grid_value, yfirst = undef_grid_value;
-  double xlast = undef_grid_value, ylast = undef_grid_value;
-  double xinc = undef_grid_value, yinc = undef_grid_value;
+  double xfirst = undefGridValue, yfirst = undefGridValue;
+  double xlast = undefGridValue, ylast = undefGridValue;
+  double xinc = undefGridValue, yinc = undefGridValue;
   double xpole = 0.0, ypole = 0.0, angle = 0.0;  // rotated north pole
   int scanningMode = 64;
   /*
@@ -75,15 +65,15 @@ GridDesciption
   char vdimname[CDI_MAX_NAME] = { 0 };
 };
 
-int gridDefine(GridDesciption &grid);
+int grid_define(GridDesciption &grid);
 
-int gridFromNCfile(const char *gridfile);
-int gridFromH5file(const char *gridfile);
-int gridFromName(const char *gridname);
+int gird_from_nc_file(const char *gridfile);
+int grid_from_h5_file(const char *gridfile);
+int grid_from_name(const char *gridname);
 
-void writeNCgrid(const char *gridfile, int gridID, int *imask);
+void write_n_cgrid(const char *gridfile, int gridID, int *imask);
 
-int cdoDefineGrid(const std::string &gridfile);
+int cdo_define_grid(const std::string &gridfile);
 
 int grid_read(FILE *gfp, const char *dname);  // TODO: Find better place for this
 
@@ -91,6 +81,6 @@ int cdo_cdf_openread(const char *filename);
 void cdo_cdf_close(int nc_file_id);
 void cdo_set_grids(const char *gridarg);
 
-void gaussianLatitudesInDegrees(std::vector<double> &lats, std::vector<double> &lat_bounds, size_t nlat);
+void gaussian_latitudes_in_degrees(std::vector<double> &lats, std::vector<double> &lat_bounds, size_t nlat);
 
 #endif /* GRIDDES_H */
