@@ -8,25 +8,16 @@
 #include "compare.h"
 #include "printinfo.h"
 
-std::string
-datetimeToString(int64_t date, int time)
-{
-  int year, month, day;
-  cdiDecodeDate(date, &year, &month, &day);
-  int hour, minute, second;
-  cdiDecodeTime(time, &hour, &minute, &second);
 
-  char cstr[64];
-  snprintf(cstr, sizeof(cstr), DATE_FORMAT "T" TIME_FORMAT, year, month, day, hour, minute, second);
+#define DATE_FORMAT "%5.4d-%2.2d-%2.2d"
+#define TIME_FORMAT "%2.2d:%2.2d:%2.2d"
 
-  return std::string(cstr);
-}
 
 std::string
-dateToString(int64_t date)
+date_to_string(CdiDate date)
 {
   int year, month, day;
-  cdiDecodeDate(date, &year, &month, &day);
+  cdiDate_decode(date, &year, &month, &day);
 
   char cstr[32];
   snprintf(cstr, sizeof(cstr), DATE_FORMAT, year, month, day);
@@ -35,19 +26,43 @@ dateToString(int64_t date)
 }
 
 std::string
-timeToString(int time)
+time_to_string(CdiTime time)
 {
-  int hour, minute, second;
-  cdiDecodeTime(time, &hour, &minute, &second);
+  static bool readEnv = true;
+  static int msDigitsNum = 0;
+  if (readEnv)
+    {
+      readEnv = false;
+      char *envString = getenv("CDO_MS_DIGITS");
+      if (envString)
+        {
+          const int ival = atol(envString);
+          if (ival > 0) msDigitsNum = ival;
+          if (ival > 3) msDigitsNum = 3;
+        }
+    }
+
+  int hour, minute, second, ms;
+  cdiTime_decode(time, &hour, &minute, &second, &ms);
 
   char cstr[32];
-  snprintf(cstr, sizeof(cstr), TIME_FORMAT, hour, minute, second);
+
+  if (msDigitsNum)
+    snprintf(cstr, sizeof(cstr), "%2.2d:%2.2d:%0*.*f", hour, minute, msDigitsNum + 3, msDigitsNum, second + ms / 1000.0);
+  else
+    snprintf(cstr, sizeof(cstr), TIME_FORMAT, hour, minute, second);
 
   return std::string(cstr);
 }
 
+std::string
+datetime_to_string(CdiDateTime dt)
+{
+  return date_to_string(dt.date) + "T" + time_to_string(dt.time);
+}
+
 const char *
-comptypeToName(int comptype)
+comptype_to_name(int comptype)
 {
   switch (comptype)
     {
@@ -60,38 +75,38 @@ comptypeToName(int comptype)
 }
 
 void
-printFiletype(CdoStreamID streamID, int vlistID)
+print_filetype(CdoStreamID streamID, int vlistID)
 {
-  const auto filetype = cdoInqFiletype(streamID);
+  const auto filetype = cdo_inq_filetype(streamID);
 
-  const auto filetypestr = cdi_filetype2str(filetype);
+  const auto filetypestr = cdi_filetype_to_str(filetype);
   if (filetypestr == nullptr || *filetypestr == 0)
-    printf("  unsupported filetype %d" , filetype);
+    printf("  unsupported filetype %d", filetype);
   else
     printf("%s", filetypestr);
 
   // clang-format off
   if (filetype == CDI_FILETYPE_SRV || filetype == CDI_FILETYPE_EXT || filetype == CDI_FILETYPE_IEG)
     {
-      switch (cdoInqByteorder(streamID))
+      switch (cdo_inq_byteorder(streamID))
 	{
 	case CDI_BIGENDIAN:    printf("  BIGENDIAN");  break;
 	case CDI_LITTLEENDIAN: printf("  LITTLEENDIAN");  break;
-	default: printf("  byteorder: %d undefined", cdoInqByteorder(streamID));  break;
+	default: printf("  byteorder: %d undefined", cdo_inq_byteorder(streamID));  break;
 	}
     }
   // clang-format on
 
   const int nvars = vlistNvars(vlistID);
   const int comps[] = { CDI_COMPRESS_ZIP, CDI_COMPRESS_JPEG, CDI_COMPRESS_SZIP, CDI_COMPRESS_AEC };
-  unsigned kk = 0;
-  for (unsigned k = 0; k < sizeof(comps) / sizeof(int); ++k)
-    for (int varID = 0; varID < nvars; varID++)
+  int kk = 0;
+  for (size_t k = 0; k < sizeof(comps) / sizeof(int); ++k)
+    for (int varID = 0; varID < nvars; ++varID)
       {
         const auto comptype = vlistInqVarCompType(vlistID, varID);
         if (comptype == comps[k])
           {
-            printf("%c%s", (kk++ == 0) ? ' ' : '/', comptypeToName(comptype));
+            printf("%c%s", (kk++ == 0) ? ' ' : '/', comptype_to_name(comptype));
             break;
           }
       }
@@ -114,15 +129,24 @@ print_xvals(int gridID, int dig)
       const auto xfirst = gridInqXval(gridID, 0);
       const auto xlast = gridInqXval(gridID, xsize - 1);
       const auto xinc = gridInqXinc(gridID);
-      fprintf(stdout, "%33s : %.*g", xname, dig, xfirst);
-      if (xsize > 1)
+      const auto gridtype = gridInqType(gridID);
+
+      if (gridtype == GRID_GAUSSIAN_REDUCED)
         {
-          fprintf(stdout, " to %.*g", dig, xlast);
-          if (IS_NOT_EQUAL(xinc, 0)) fprintf(stdout, " by %.*g", dig, xinc);
+          if (xsize == 2) fprintf(stdout, "%33s : %.*g to %.*g %s\n", xname, dig, xfirst, dig, xlast, xunits);
+        }
+      else
+        {
+          fprintf(stdout, "%33s : %.*g", xname, dig, xfirst);
+          if (xsize > 1)
+            {
+              fprintf(stdout, " to %.*g", dig, xlast);
+              if (IS_NOT_EQUAL(xinc, 0)) fprintf(stdout, " by %.*g", dig, xinc);
+            }
+          fprintf(stdout, " %s", xunits);
+          if (gridIsCircular(gridID)) fprintf(stdout, "  circular");
+          fprintf(stdout, "\n");
         }
-      fprintf(stdout, " %s", xunits);
-      if (gridIsCircular(gridID)) fprintf(stdout, "  circular");
-      fprintf(stdout, "\n");
     }
 }
 
@@ -154,6 +178,73 @@ print_yvals(int gridID, int dig)
     }
 }
 
+static double
+calc_curvi_xinc(int gridID)
+{
+  auto xinc = 0.0;
+  if (gridInqType(gridID) != GRID_CURVILINEAR) return xinc;
+  const auto *xvals2D = gridInqXvalsPtr(gridID);
+  const auto xsize = gridInqXsize(gridID);
+  const auto ysize = gridInqYsize(gridID);
+  if (xsize > 1)
+    {
+      Varray<double> xvals(xsize);
+      for (size_t i = 0; i < xsize; ++i) xvals[i] = xvals2D[i];
+      xinc = fabs(xvals[xsize - 1] - xvals[0]) / (xsize - 1);
+      for (size_t i = 1; i < xsize; ++i)
+        if (fabs(fabs(xvals[i - 1] - xvals[i]) - xinc) > 0.005 * xinc)
+          {
+            xinc = 0.0;
+            break;
+          }
+      if (IS_NOT_EQUAL(xinc, 0.0))
+        {
+          for (size_t i = 1; i < ysize; ++i)
+            if (IS_NOT_EQUAL(xvals2D[i * xsize], xvals2D[0])|| IS_NOT_EQUAL(xvals2D[(i + 1) * xsize - 1], xvals2D[xsize - 1]))
+              {
+                xinc = 0.0;
+                break;
+              }
+        }
+    }
+
+  return xinc;
+}
+
+static double
+calc_curvi_yinc(int gridID)
+{
+  auto yinc = 0.0;
+  if (gridInqType(gridID) != GRID_CURVILINEAR) return yinc;
+  const auto *yvals2D = gridInqYvalsPtr(gridID);
+  const auto xsize = gridInqXsize(gridID);
+  const auto ysize = gridInqYsize(gridID);
+  if (ysize > 1)
+    {
+      Varray<double> yvals(ysize);
+      for (size_t i = 0; i < ysize; ++i) yvals[i] = yvals2D[i * xsize];
+      yinc = fabs(yvals[ysize - 1] - yvals[0]) / (ysize - 1);
+      for (size_t i = 1; i < ysize; ++i)
+        if (fabs(fabs(yvals[i - 1] - yvals[i]) - yinc) > 0.005 * yinc)
+          {
+            yinc = 0.0;
+            break;
+          }
+      if (IS_NOT_EQUAL(yinc, 0.0))
+        {
+          for (size_t i = 1; i < xsize; ++i)
+            if (IS_NOT_EQUAL(yvals2D[i], yvals2D[0])
+                || IS_NOT_EQUAL(yvals2D[(ysize - 1) * xsize + i], yvals2D[(ysize - 1) * xsize]))
+              {
+                yinc = 0.0;
+                break;
+              }
+        }
+    }
+
+  return yinc;
+}
+
 static void
 print_xyvals2D(int gridID, int dig)
 {
@@ -170,75 +261,26 @@ print_xyvals2D(int gridID, int dig)
       cdiInqKeyString(gridID, CDI_YAXIS, CDI_KEY_UNITS, yunits, &length);
 
       const auto gridsize = gridInqSize(gridID);
-      Varray<double> xvals2D(gridsize), yvals2D(gridsize);
 
-      gridInqXvals(gridID, xvals2D.data());
-      gridInqYvals(gridID, yvals2D.data());
+      const auto *xvals2D = gridInqXvalsPtr(gridID);
+      const auto *yvals2D = gridInqYvalsPtr(gridID);
 
-      const auto xmm = varrayMinMax(gridsize, xvals2D);
-      const auto ymm = varrayMinMax(gridsize, yvals2D);
+      const auto xmm = varray_min_max(gridsize, xvals2D);
+      const auto ymm = varray_min_max(gridsize, yvals2D);
 
-      double xinc = 0, yinc = 0;
       const auto gridtype = gridInqType(gridID);
-      if (gridtype == GRID_CURVILINEAR)
-        {
-          const auto xsize = gridInqXsize(gridID);
-          const auto ysize = gridInqYsize(gridID);
-          if (xsize > 1)
-            {
-              Varray<double> xvals(xsize);
-              for (size_t i = 0; i < xsize; ++i) xvals[i] = xvals2D[i];
-              xinc = fabs(xvals[xsize - 1] - xvals[0]) / (xsize - 1);
-              for (size_t i = 1; i < xsize; i++)
-                if (fabs(fabs(xvals[i - 1] - xvals[i]) - xinc) > 0.005 * xinc)
-                  {
-                    xinc = 0;
-                    break;
-                  }
-              if (IS_NOT_EQUAL(xinc, 0))
-                {
-                  for (size_t i = 1; i < ysize; i++)
-                    if (IS_NOT_EQUAL(xvals2D[i * xsize], xvals2D[0])
-                        || IS_NOT_EQUAL(xvals2D[(i + 1) * xsize - 1], xvals2D[xsize - 1]))
-                      {
-                        xinc = 0;
-                        break;
-                      }
-                }
-            }
-          if (ysize > 1)
-            {
-              Varray<double> yvals(ysize);
-              for (size_t i = 0; i < ysize; ++i) yvals[i] = yvals2D[i * xsize];
-              yinc = fabs(yvals[ysize - 1] - yvals[0]) / (ysize - 1);
-              for (size_t i = 1; i < ysize; i++)
-                if (fabs(fabs(yvals[i - 1] - yvals[i]) - yinc) > 0.005 * yinc)
-                  {
-                    yinc = 0;
-                    break;
-                  }
-              if (IS_NOT_EQUAL(yinc, 0))
-                {
-                  for (size_t i = 1; i < xsize; i++)
-                    if (IS_NOT_EQUAL(yvals2D[i], yvals2D[0])
-                        || IS_NOT_EQUAL(yvals2D[(ysize - 1) * xsize + i], yvals2D[(ysize - 1) * xsize]))
-                      {
-                        yinc = 0;
-                        break;
-                      }
-                }
-            }
-        }
+      const auto xinc = (gridtype == GRID_CURVILINEAR) ? calc_curvi_xinc(gridID) : 0.0;
+      const auto yinc = (gridtype == GRID_CURVILINEAR) ? calc_curvi_yinc(gridID) : 0.0;
 
       fprintf(stdout, "%33s : %.*g", xname, dig, xmm.min);
       if (gridsize > 1) fprintf(stdout, " to %.*g", dig, xmm.max);
-      if (IS_NOT_EQUAL(xinc, 0)) fprintf(stdout, " by %.*g", dig, xinc);
+      if (IS_NOT_EQUAL(xinc, 0.0)) fprintf(stdout, " by %.*g", dig, xinc);
       fprintf(stdout, " %s", xunits);
       if (gridIsCircular(gridID)) fprintf(stdout, "  circular");
       fprintf(stdout, "\n");
       fprintf(stdout, "%33s : %.*g", yname, dig, ymm.min);
       if (gridsize > 1) fprintf(stdout, " to %.*g", dig, ymm.max);
-      if (IS_NOT_EQUAL(yinc, 0)) fprintf(stdout, " by %.*g", dig, yinc);
+      if (IS_NOT_EQUAL(yinc, 0.0)) fprintf(stdout, " by %.*g", dig, yinc);
       fprintf(stdout, " %s", yunits);
       fprintf(stdout, "\n");
     }
@@ -267,7 +309,7 @@ printGridNumPoints(int gridtype, int gridID, size_t gridsize, size_t xsize, size
 static void
 printGridInfoKernel(int gridID, int index, int lproj)
 {
-  const int dig = Options::CDO_flt_digits;
+  const auto dig = Options::CDO_flt_digits;
   const auto gridtype = gridInqType(gridID);
 
   if (lproj && gridtype != GRID_PROJECTION)
@@ -291,7 +333,6 @@ printGridInfoKernel(int gridID, int index, int lproj)
       || gridtype == GRID_GAUSSIAN || gridtype == GRID_GAUSSIAN_REDUCED)
     {
       if (!lproj)
-
         {
           set_text_color(stdout, GREEN);
           printGridNumPoints(gridtype, gridID, gridsize, xsize, ysize);
@@ -308,11 +349,24 @@ printGridInfoKernel(int gridID, int index, int lproj)
           reset_text_color(stdout);
           fprintf(stdout, " : ");
           set_text_color(stdout, GREEN);
-          fprintf(stdout, "%s\n", gmapname);
+          fprintf(stdout, "%s", gmapname);
+
+          if (strcmp(gmapname, "healpix") == 0)
+            {
+              int nside = -1;
+              cdiInqAttInt(gridID, CDI_GLOBAL, "healpix_nside", 1, &nside);
+              int attlen = CDI_MAX_NAME;
+              char atttxt[CDI_MAX_NAME];
+              const auto status = cdiInqAttTxt(gridID, CDI_GLOBAL, "healpix_order", attlen, atttxt);
+              fprintf(stdout, "  nside=%d", nside);
+              fprintf(stdout, "  order=%s", (status == 0) ? atttxt : "undefined");
+            }
+
+          fprintf(stdout, "\n");
           reset_text_color(stdout);
         }
 
-      if (gridtype != GRID_GAUSSIAN_REDUCED) print_xvals(gridID, dig);
+      print_xvals(gridID, dig);
       print_yvals(gridID, dig);
 
       if (gridInqXbounds(gridID, NULL) || gridInqYbounds(gridID, NULL))
@@ -405,23 +459,29 @@ printGridInfoKernel(int gridID, int index, int lproj)
         }
     }
 
-  unsigned char uuidOfHGrid[CDI_UUID_SIZE] = { 0 };
+  unsigned char uuid[CDI_UUID_SIZE] = { 0 };
   int length = CDI_UUID_SIZE;
-  cdiInqKeyBytes(gridID, CDI_GLOBAL, CDI_KEY_UUID, uuidOfHGrid, &length);
-  if (!cdiUUIDIsNull(uuidOfHGrid))
+  const auto status = cdiInqKeyBytes(gridID, CDI_GLOBAL, CDI_KEY_UUID, uuid, &length);
+  if (status == CDI_NOERR && !cdiUUIDIsNull(uuid))
     {
-      char uuidOfHGridStr[37];
-      cdiUUID2Str(uuidOfHGrid, uuidOfHGridStr);
-      if (uuidOfHGridStr[0] != 0 && strlen(uuidOfHGridStr) == 36)
-        fprintf(stdout, "%33s : %s\n", "uuid", uuidOfHGridStr);
+      char uuidStr[uuidNumHexChars + 1] = { 0 };
+      if (cdiUUID2Str(uuid, uuidStr) == uuidNumHexChars) fprintf(stdout, "%33s : %s\n", "uuid", uuidStr);
+    }
+
+  if (Options::cdoVerbose)
+    {
+      int datatype;
+      cdiInqKeyInt(gridID, CDI_GLOBAL, CDI_KEY_DATATYPE, &datatype);
+      fprintf(stdout, "%33s : %s\n", "datatype", cdi_datatype_to_str(datatype));
+      fprintf(stdout, "%33s : %d\n", "gridID", gridID);
     }
 }
 
 void
-printGridInfo(int vlistID)
+print_grid_info(int vlistID)
 {
   const auto ngrids = vlistNgrids(vlistID);
-  for (int index = 0; index < ngrids; index++)
+  for (int index = 0; index < ngrids; ++index)
     {
       const auto gridID = vlistGrid(vlistID, index);
       printGridInfoKernel(gridID, index, false);
@@ -540,36 +600,31 @@ static void
 printZaxisReferenceInfo(const int zaxisID)
 {
   int number = 0;
-/*  cdiInqKeyInt(zaxisID, CDI_GLOBAL, CDI_KEY_NUMBEROFVGRIDUSED, &number)*/
-  if (number > 0)
+  // cdiInqKeyInt(zaxisID, CDI_GLOBAL, CDI_KEY_NUMBEROFVGRIDUSED, &number)
+  // if (number > 0)
     {
       fprintf(stdout, "%33s : ", "zaxis");
       fprintf(stdout, "number=%d\n", number);
     }
 
-  unsigned char uuidOfVGrid[CDI_UUID_SIZE];
+  unsigned char uuid[CDI_UUID_SIZE] = { 0 };
   int length = CDI_UUID_SIZE;
-  cdiInqKeyBytes(zaxisID, CDI_GLOBAL, CDI_KEY_UUID, uuidOfVGrid, &length);
-  if (!cdiUUIDIsNull(uuidOfVGrid))
+  const auto status = cdiInqKeyBytes(zaxisID, CDI_GLOBAL, CDI_KEY_UUID, uuid, &length);
+  if (status == CDI_NOERR && !cdiUUIDIsNull(uuid))
     {
-      char uuidOfVGridStr[37];
-      cdiUUID2Str(uuidOfVGrid, uuidOfVGridStr);
-      if (uuidOfVGridStr[0] != 0 && strlen(uuidOfVGridStr) == 36)
-        {
-          fprintf(stdout, "%33s : ", "uuid");
-          fprintf(stdout, "%s\n", uuidOfVGridStr);
-        }
+      char uuidStr[uuidNumHexChars + 1] = { 0 };
+      if (cdiUUID2Str(uuid, uuidStr) == uuidNumHexChars) fprintf(stdout, "%33s : %s\n", "uuid", uuidStr);
     }
 }
 
 void
-printZaxisInfo(int vlistID)
+print_zaxis_info(int vlistID)
 {
   const auto dig = Options::CDO_flt_digits;
   char zaxisname[CDI_MAX_NAME], zname[CDI_MAX_NAME], zunits[CDI_MAX_NAME];
 
   const auto nzaxis = vlistNzaxis(vlistID);
-  for (int index = 0; index < nzaxis; index++)
+  for (int index = 0; index < nzaxis; ++index)
     {
       const auto zaxisID = vlistZaxis(vlistID, index);
       const auto zaxistype = zaxisInqType(zaxisID);
@@ -600,7 +655,7 @@ printZaxisInfo(int vlistID)
       reset_text_color(stdout);
       fprintf(stdout, "\n");
 
-      double zinc = 0;
+      double zinc = 0.0;
       if (zaxisInqLevels(zaxisID, NULL)) printZaxisLevelInfo(levelsize, zaxisID, zaxistype, zinc, dig, zname, zunits);
 
       if (zaxisInqLbounds(zaxisID, NULL) && zaxisInqUbounds(zaxisID, NULL))
@@ -611,14 +666,22 @@ printZaxisInfo(int vlistID)
       if (zaxistype == ZAXIS_REFERENCE) printZaxisReferenceInfo(zaxisID);
 
       if (ltype != ltype2 && ltype2 != -1) fprintf(stdout, "%33s : %d\n", "typeOfSecondFixedSurface", ltype2);
+
+      if (Options::cdoVerbose)
+        {
+          int datatype;
+          cdiInqKeyInt(zaxisID, CDI_GLOBAL, CDI_KEY_DATATYPE, &datatype);
+          fprintf(stdout, "%33s : %s\n", "datatype", cdi_datatype_to_str(datatype));
+          fprintf(stdout, "%33s : %d\n", "zaxisID", zaxisID);
+        }
     }
 }
 
 void
-printSubtypeInfo(int vlistID)
+print_subtype_info(int vlistID)
 {
   const auto nsubtypes = vlistNsubtypes(vlistID);
-  for (int index = 0; index < nsubtypes; index++)
+  for (int index = 0; index < nsubtypes; ++index)
     {
       const auto subtypeID = vlistSubtype(vlistID, index);
       const auto subtypesize = subtypeInqSize(subtypeID);
@@ -630,7 +693,7 @@ printSubtypeInfo(int vlistID)
 }
 
 static int
-printDateTime(int ntimeout, const int64_t vdate, const int vtime)
+printDateTime(int ntimeout, const CdiDateTime vDateTime)
 {
   if (ntimeout == 4)
     {
@@ -638,21 +701,22 @@ printDateTime(int ntimeout, const int64_t vdate, const int vtime)
       fprintf(stdout, "\n");
     }
 
-  fprintf(stdout, " %s %s", dateToString(vdate).c_str(), timeToString(vtime).c_str());
+  fprintf(stdout, " %s %s", date_to_string(vDateTime.date).c_str(), time_to_string(vDateTime.time).c_str());
 
   return ++ntimeout;
 }
 
-#define NUM_TIMESTEP 60
-#define MAX_DOTS 80
+constexpr int NumTimestep = 60;
 
 static int
 printDot(int ndotout, int *nfact, int *ncout)
 {
+  constexpr int MaxDots = 80;
+
   // printf("ncout %d %d %d\n",*ncout, (*ncout)%(*nfact), *nfact);
   if ((*ncout) % (*nfact) == 0)
     {
-      if (ndotout == MAX_DOTS)
+      if (ndotout == MaxDots)
         {
           *ncout = 0;
           ndotout = 0;
@@ -671,19 +735,18 @@ printDot(int ndotout, int *nfact, int *ncout)
 }
 
 void
-printTimesteps(CdoStreamID streamID, int taxisID, int verbose)
+print_timesteps(CdoStreamID streamID, int taxisID, int verbose)
 {
   struct datetime
   {
-    int64_t vdate;
-    int vtime;
+    CdiDateTime vDateTime;
     struct datetime *next;
   };
-  struct datetime vdatetime[NUM_TIMESTEP];
+  struct datetime vdatetime[NumTimestep];
   struct datetime *next_vdatetime = vdatetime;
 
-  for (int i = 0; i < NUM_TIMESTEP - 1; ++i) vdatetime[i].next = &vdatetime[i + 1];
-  vdatetime[NUM_TIMESTEP - 1].next = &vdatetime[0];
+  for (int i = 0; i < NumTimestep - 1; ++i) vdatetime[i].next = &vdatetime[i + 1];
+  vdatetime[NumTimestep - 1].next = &vdatetime[0];
 
   int ntimeout = 0;
   int ndotout = 0;
@@ -695,32 +758,29 @@ printTimesteps(CdoStreamID streamID, int taxisID, int verbose)
   DateTimeList dtlist;
   while (true)
     {
-      const auto nrecs = cdoStreamInqTimestep(streamID, tsID);
+      const auto nrecs = cdo_stream_inq_timestep(streamID, tsID);
       if (nrecs == 0) break;
 
-      dtlist.taxisInqTimestep(taxisID, 0);
-      const auto vdate = dtlist.getVdate(0);
-      const auto vtime = dtlist.getVtime(0);
+      dtlist.taxis_inq_timestep(taxisID, 0);
+      const auto vDateTime = dtlist.get_vDateTime(0);
 
-      if (verbose || tsID < NUM_TIMESTEP)
+      if (verbose || tsID < NumTimestep)
         {
-          ntimeout = printDateTime(ntimeout, vdate, vtime);
+          ntimeout = printDateTime(ntimeout, vDateTime);
         }
       else
         {
-          if (tsID == 2 * NUM_TIMESTEP) fprintf(stdout, "\n   ");
-          if (tsID >= 2 * NUM_TIMESTEP) ndotout = printDot(ndotout, &nfact, &ncout);
+          if (tsID == 2 * NumTimestep) fprintf(stdout, "\n   ");
+          if (tsID >= 2 * NumTimestep) ndotout = printDot(ndotout, &nfact, &ncout);
 
-          if (nvdatetime < NUM_TIMESTEP)
+          if (nvdatetime < NumTimestep)
             {
-              vdatetime[nvdatetime].vdate = vdate;
-              vdatetime[nvdatetime].vtime = vtime;
+              vdatetime[nvdatetime].vDateTime = vDateTime;
               nvdatetime++;
             }
           else
             {
-              next_vdatetime->vdate = vdate;
-              next_vdatetime->vtime = vtime;
+              next_vdatetime->vDateTime = vDateTime;
               next_vdatetime = next_vdatetime->next;
             }
         }
@@ -734,7 +794,7 @@ printTimesteps(CdoStreamID streamID, int taxisID, int verbose)
 
       ntimeout = 0;
       int toff = 0;
-      if (tsID > 2 * NUM_TIMESTEP)
+      if (tsID > 2 * NumTimestep)
         {
           toff = tsID % 4;
           if (toff > 0) toff = 4 - toff;
@@ -742,9 +802,8 @@ printTimesteps(CdoStreamID streamID, int taxisID, int verbose)
         }
       for (int i = toff; i < nvdatetime; ++i)
         {
-          const auto vdate = next_vdatetime->vdate;
-          const auto vtime = next_vdatetime->vtime;
-          ntimeout = printDateTime(ntimeout, vdate, vtime);
+          const auto vDateTime = next_vdatetime->vDateTime;
+          ntimeout = printDateTime(ntimeout, vDateTime);
           next_vdatetime = next_vdatetime->next;
         }
     }
