@@ -45,7 +45,7 @@
 
 */
 /*
-  2013-11-08 Uwe Schulzweida: split remapgrid class to src_grid and tgt_grid
+  2013-11-08 Uwe Schulzweida: split remapgrid class to srcGrid and tgtGrid
   2012-01-16 Uwe Schulzweida: alloc grid2_bound_box only for conservative remapping
   2011-01-07 Uwe Schulzweida: Changed remap weights from 2D to 1D array
   2009-05-25 Uwe Schulzweida: Changed restrict data type from double to int
@@ -67,7 +67,8 @@
 static bool remap_gen_weights = true;
 static bool remap_write_remap = false;
 static int remap_num_srch_bins = 180;
-#define DEFAULT_MAX_ITER 100
+
+constexpr size_t DEFAULT_MAX_ITER = 100;
 size_t remap_max_iter = DEFAULT_MAX_ITER;  // Max iteration count for i, j iteration
 
 void
@@ -91,8 +92,8 @@ boundboxFromCorners(size_t size, size_t nc, const Varray<double> &corner_lon, co
 #endif
   for (size_t i = 0; i < size; ++i)
     {
-      size_t i4 = i << 2;  // *4
-      size_t inc = i * nc;
+      const size_t i4 = (i << 2);  // *4
+      const size_t inc = i * nc;
       float clat = corner_lat[inc];
       float clon = corner_lon[inc];
       bound_box[i4 + 0] = clat;
@@ -118,21 +119,19 @@ boundboxFromCenter(bool lonIsCyclic, size_t size, size_t nx, size_t ny, const Va
 #ifdef _OPENMP
 #pragma omp parallel for default(shared) schedule(static)
 #endif
-  for (size_t n = 0; n < size; n++)
+  for (size_t n = 0; n < size; ++n)
     {
-      size_t idx[4];
-      float tmp_lats[4], tmp_lons[4];
-
-      size_t n4 = n << 2;
+      const size_t n4 = (n << 2);
 
       // Find N,S and NE points to this grid point
 
-      size_t j = n / nx;
-      size_t i = n - j * nx;
+      const size_t j = n / nx;
+      const size_t i = n - j * nx;
 
-      size_t ip1 = (i < (nx - 1)) ? i + 1 : lonIsCyclic ? 0 : i;
-      size_t jp1 = (j < (ny - 1)) ? j + 1 : j;
+      const size_t ip1 = (i < (nx - 1)) ? i + 1 : lonIsCyclic ? 0 : i;
+      const size_t jp1 = (j < (ny - 1)) ? j + 1 : j;
 
+      size_t idx[4];
       idx[0] = n;
       idx[1] = j * nx + ip1;    // east
       idx[2] = jp1 * nx + ip1;  // north-east
@@ -140,15 +139,16 @@ boundboxFromCenter(bool lonIsCyclic, size_t size, size_t nx, size_t ny, const Va
 
       // Find N,S and NE lat/lon coords and check bounding box
 
-      for (unsigned k = 0; k < 4; ++k) tmp_lons[k] = center_lon[idx[k]];
-      for (unsigned k = 0; k < 4; ++k) tmp_lats[k] = center_lat[idx[k]];
+      float tmp_lats[4], tmp_lons[4];
+      for (int k = 0; k < 4; ++k) tmp_lons[k] = center_lon[idx[k]];
+      for (int k = 0; k < 4; ++k) tmp_lats[k] = center_lat[idx[k]];
 
       bound_box[n4 + 0] = tmp_lats[0];
       bound_box[n4 + 1] = tmp_lats[0];
       bound_box[n4 + 2] = tmp_lons[0];
       bound_box[n4 + 3] = tmp_lons[0];
 
-      for (unsigned k = 1; k < 4; k++)
+      for (int k = 1; k < 4; ++k)
         {
           if (tmp_lats[k] < bound_box[n4 + 0]) bound_box[n4 + 0] = tmp_lats[k];
           if (tmp_lats[k] > bound_box[n4 + 1]) bound_box[n4 + 1] = tmp_lats[k];
@@ -336,7 +336,7 @@ convert_bounds_reg2d(size_t n, const Varray<double> &boundsIn, Varray<double> &b
 }
 
 static void
-remap_define_reg2d(int gridID, RemapGrid &grid)
+remap_define_reg2d(int gridID, RemapGrid &grid, bool conservMapping, const char *txt)
 {
   const auto nx = grid.dims[0];
   const auto ny = grid.dims[1];
@@ -378,6 +378,7 @@ remap_define_reg2d(int gridID, RemapGrid &grid)
     }
   else
     {
+      if (conservMapping && nx == 1) cdo_abort("Longitude bounds of %s grid missing!", txt);
       grid_gen_corners(nx, grid.reg2d_center_lon.data(), grid.reg2d_corner_lon.data());
     }
 
@@ -390,6 +391,7 @@ remap_define_reg2d(int gridID, RemapGrid &grid)
     }
   else
     {
+      if (conservMapping && ny == 1) cdo_abort("Latitude bounds of %s grid missing!", txt);
       grid_gen_corners(ny, grid.reg2d_center_lat.data(), grid.reg2d_corner_lat.data());
       grid_check_lat_borders_rad(ny + 1, grid.reg2d_corner_lat);
     }
@@ -398,29 +400,30 @@ remap_define_reg2d(int gridID, RemapGrid &grid)
 static void
 remapDefineGrid(RemapMethod mapType, int gridID, RemapGrid &grid, const char *txt)
 {
-  bool lgrid_destroy = false;
+  bool destroyGrid = false;
   int gridID_gme = -1;
 
   const auto gridtype = gridInqType(grid.gridID);
   if (gridtype != GRID_UNSTRUCTURED && gridtype != GRID_CURVILINEAR)
     {
+      constexpr auto withBounds = true;
       if (gridtype == GRID_GME)
         {
-          gridID_gme = gridToUnstructured(grid.gridID, 1);
+          gridID_gme = gridToUnstructured(grid.gridID, withBounds);
           grid.nvgp = gridInqSize(gridID_gme);
           gridID = gridDuplicate(gridID_gme);
           gridCompress(gridID);
           grid.luse_cell_corners = true;
         }
-      else if (gridtype == GRID_GAUSSIAN_REDUCED)
+      else if (gridtype == GRID_GAUSSIAN_REDUCED || (gridtype == GRID_PROJECTION && gridInqProjType(gridID) == CDI_PROJ_HEALPIX))
         {
-          lgrid_destroy = true;
-          gridID = gridToUnstructured(grid.gridID, 1);
+          destroyGrid = true;
+          gridID = gridToUnstructured(grid.gridID, withBounds);
         }
       else if (remap_write_remap || grid.type != RemapGridType::Reg2D)
         {
-          lgrid_destroy = true;
-          gridID = gridToCurvilinear(grid.gridID, 1);
+          destroyGrid = true;
+          gridID = gridToCurvilinear(grid.gridID, withBounds);
         }
     }
 
@@ -428,7 +431,7 @@ remapDefineGrid(RemapMethod mapType, int gridID, RemapGrid &grid, const char *tx
 
   grid.dims[0] = gridInqXsize(gridID);
   grid.dims[1] = gridInqYsize(gridID);
-  if (gridInqType(grid.gridID) != GRID_UNSTRUCTURED)
+  if (gridInqType(grid.gridID) != GRID_UNSTRUCTURED && gridInqType(gridID) != GRID_UNSTRUCTURED)
     {
       if (grid.dims[0] == 0) cdo_abort("%s grid without longitude coordinates!", gridNamePtr(gridInqType(grid.gridID)));
       if (grid.dims[1] == 0) cdo_abort("%s grid without latitude coordinates!", gridNamePtr(gridInqType(grid.gridID)));
@@ -483,7 +486,7 @@ remapDefineGrid(RemapMethod mapType, int gridID, RemapGrid &grid, const char *tx
       cdo_grid_to_radian(gridID, CDI_YAXIS, grid.num_cell_corners * grid.size, grid.cell_corner_lat.data(), "grid corner lat");
     }
 
-  if (lgrid_destroy) gridDestroy(gridID);
+  if (destroyGrid) gridDestroy(gridID);
 
   // Convert longitudes to 0,2pi interval
   check_lon_range(txt, grid.size, grid.cell_center_lon);
@@ -599,30 +602,46 @@ remap_grid_free(RemapGrid &grid)
   if (grid.tmpgridID != -1) gridDestroy(grid.tmpgridID);
 }
 
+static void
+check_for_convex_cells(RemapGrid &tgtGrid)
+{
+  if (tgtGrid.type == RemapGridType::Reg2D) return;
+
+  const auto numCellCorners = tgtGrid.num_cell_corners;
+  if (numCellCorners <= 4) return;
+
+  auto numCells = tgtGrid.size;
+  if (numCells > 1000) numCells = 1000;
+
+  for (size_t i = 0; i < numCells; ++i)
+    {
+    }
+}
+
 void
-remap_search_init(RemapMethod mapType, RemapSearch &search, RemapGrid &src_grid, RemapGrid &tgt_grid)
+remap_search_init(RemapMethod mapType, RemapSearch &search, RemapGrid &srcGrid, RemapGrid &tgtGrid)
 {
   extern PointSearchMethod pointSearchMethod;
   extern CellSearchMethod cellSearchMethod;
 
-  search.srcGrid = &src_grid;
-  search.tgtGrid = &tgt_grid;
+  search.srcGrid = &srcGrid;
+  search.tgtGrid = &tgtGrid;
 
-  search.srcBins.ncells = src_grid.size;
-  search.tgtBins.ncells = tgt_grid.size;
+  search.srcBins.ncells = srcGrid.size;
+  search.tgtBins.ncells = tgtGrid.size;
 
   search.srcBins.nbins = remap_num_srch_bins;
   search.tgtBins.nbins = remap_num_srch_bins;
 
   auto usePointsearch = (mapType == RemapMethod::DISTWGT);
-  if (src_grid.type != RemapGridType::Reg2D && pointSearchMethod != PointSearchMethod::latbins)
+  if (srcGrid.type != RemapGridType::Reg2D && pointSearchMethod != PointSearchMethod::latbins)
     {
       usePointsearch |= (mapType == RemapMethod::BILINEAR);
       usePointsearch |= (mapType == RemapMethod::BICUBIC);
     }
 
   auto useCellsearch = (mapType == RemapMethod::CONSERV)
-                       && (cellSearchMethod == CellSearchMethod::spherepart || src_grid.type == RemapGridType::Reg2D);
+                       && (cellSearchMethod == CellSearchMethod::spherepart || srcGrid.type == RemapGridType::Reg2D);
 
   const char *searchMethodStr = NULL;
   const auto start = Options::cdoVerbose ? cdo_get_wtime() : 0.0;
@@ -630,32 +649,34 @@ remap_search_init(RemapMethod mapType, RemapSearch &search, RemapGrid &src_grid,
   if (usePointsearch)
     {
       searchMethodStr = "Point search";
-      bool xIsCyclic = src_grid.is_cyclic;
-      if (src_grid.type == RemapGridType::Reg2D)
-        grid_point_search_create_reg_2d(search.gps, xIsCyclic, src_grid.dims, src_grid.reg2d_center_lon, src_grid.reg2d_center_lat);
+      const auto xIsCyclic = srcGrid.is_cyclic;
+      if (srcGrid.type == RemapGridType::Reg2D)
+        grid_point_search_create_reg_2d(search.gps, xIsCyclic, srcGrid.dims, srcGrid.reg2d_center_lon, srcGrid.reg2d_center_lat);
       else
-        grid_point_search_create(search.gps, xIsCyclic, src_grid.dims, src_grid.size, src_grid.cell_center_lon,
-                                 src_grid.cell_center_lat);
+        grid_point_search_create(search.gps, xIsCyclic, srcGrid.dims, srcGrid.size, srcGrid.cell_center_lon,
+                                 srcGrid.cell_center_lat);
 
-      if (src_grid.lextrapolate) grid_point_search_extrapolate(search.gps);
+      if (srcGrid.lextrapolate) grid_point_search_extrapolate(search.gps);
     }
   else if (useCellsearch)
     {
       searchMethodStr = "Cell search";
-      if (src_grid.type == RemapGridType::Reg2D)
-        grid_cell_search_create_reg_2d(search.gcs, src_grid.dims, src_grid.reg2d_corner_lon, src_grid.reg2d_corner_lat);
+      if (srcGrid.type == RemapGridType::Reg2D)
+        grid_cell_search_create_reg_2d(search.gcs, srcGrid.dims, srcGrid.reg2d_corner_lon, srcGrid.reg2d_corner_lat);
       else
-        grid_cell_search_create(search.gcs, src_grid.size, src_grid.num_cell_corners, src_grid.cell_corner_lon,
-                                src_grid.cell_corner_lat);
+        grid_cell_search_create(search.gcs, srcGrid.size, srcGrid.num_cell_corners, srcGrid.cell_corner_lon,
+                                srcGrid.cell_corner_lat);
+
+      // check_for_convex_cells(tgtGrid);
     }
-  else if (!(src_grid.type == RemapGridType::Reg2D || tgt_grid.type == RemapGridType::Reg2D))
+  else if (!(srcGrid.type == RemapGridType::Reg2D || tgtGrid.type == RemapGridType::Reg2D))
     {
       searchMethodStr = "Latitude bins";
-      search.srcBins.cell_bound_box.resize(4 * src_grid.size);
-      if (tgt_grid.luse_cell_corners) search.tgtBins.cell_bound_box.resize(4 * tgt_grid.size);
+      search.srcBins.cell_bound_box.resize(4 * srcGrid.size);
+      if (tgtGrid.luse_cell_corners) search.tgtBins.cell_bound_box.resize(4 * tgtGrid.size);
 
-      cell_bounding_boxes(src_grid, &search.srcBins.cell_bound_box[0], REMAP_GRID_BASIS_SRC);
-      cell_bounding_boxes(tgt_grid, &search.tgtBins.cell_bound_box[0], REMAP_GRID_BASIS_TGT);
+      cell_bounding_boxes(srcGrid, &search.srcBins.cell_bound_box[0], REMAP_GRID_BASIS_SRC);
+      cell_bounding_boxes(tgtGrid, &search.tgtBins.cell_bound_box[0], REMAP_GRID_BASIS_TGT);
       // Set up and assign address ranges to search bins in order to further restrict later searches
       calc_lat_bins(search.srcBins);
       if (mapType == RemapMethod::CONSERV_SCRIP || mapType == RemapMethod::CONSERV)
@@ -686,146 +707,151 @@ remap_search_free(RemapSearch &search)
 }
 
 void
-remap_init_grids(RemapMethod mapType, bool lextrapolate, int gridID1, RemapGrid &src_grid, int gridID2, RemapGrid &tgt_grid)
+remap_init_grids(RemapMethod mapType, bool lextrapolate, int gridID1, RemapGrid &srcGrid, int gridID2, RemapGrid &tgtGrid)
 {
-  auto reg2d_src_gridID = gridID1;
-  auto reg2d_tgt_gridID = gridID2;
+  auto reg2d_srcGridID = gridID1;
+  auto reg2d_tgtGridID = gridID2;
 
-  remap_grid_init(src_grid);
-  remap_grid_init(tgt_grid);
+  remap_grid_init(srcGrid);
+  remap_grid_init(tgtGrid);
 
   if (mapType == RemapMethod::BILINEAR || mapType == RemapMethod::BICUBIC || mapType == RemapMethod::DISTWGT
       || mapType == RemapMethod::CONSERV)
     {
-      if (IS_REG2D_GRID(gridID1)) src_grid.type = RemapGridType::Reg2D;
-      // src_grid.type = 0;
+      if (IS_REG2D_GRID(gridID1)) srcGrid.type = RemapGridType::Reg2D;
+      // srcGrid.type = 0;
     }
 
   //#ifdef YAC_CELL_SEARCH
-  // if (IS_REG2D_GRID(gridID2) && mapType == RemapMethod::CONSERV) tgt_grid.type = RemapGridType::Reg2D;
+  // if (IS_REG2D_GRID(gridID2) && mapType == RemapMethod::CONSERV) tgtGrid.type = RemapGridType::Reg2D;
   //#else
-  if (src_grid.type == RemapGridType::Reg2D)
+  if (srcGrid.type == RemapGridType::Reg2D)
     {
-      if (IS_REG2D_GRID(gridID2) && mapType == RemapMethod::CONSERV) tgt_grid.type = RemapGridType::Reg2D;
-      // else src_grid.type = -1;
+      if (IS_REG2D_GRID(gridID2) && mapType == RemapMethod::CONSERV) tgtGrid.type = RemapGridType::Reg2D;
+      // else srcGrid.type = -1;
     }
   //#endif
 
-  if (!remap_gen_weights && IS_REG2D_GRID(gridID2) && tgt_grid.type != RemapGridType::Reg2D)
+  if (!remap_gen_weights && IS_REG2D_GRID(gridID2) && tgtGrid.type != RemapGridType::Reg2D)
     {
-      if (mapType == RemapMethod::DISTWGT) tgt_grid.type = RemapGridType::Reg2D;
-      if (mapType == RemapMethod::BILINEAR && src_grid.type == RemapGridType::Reg2D) tgt_grid.type = RemapGridType::Reg2D;
+      if (mapType == RemapMethod::DISTWGT) tgtGrid.type = RemapGridType::Reg2D;
+      if (mapType == RemapMethod::BILINEAR && srcGrid.type == RemapGridType::Reg2D) tgtGrid.type = RemapGridType::Reg2D;
     }
 
-  src_grid.lextrapolate = lextrapolate;
+  srcGrid.lextrapolate = lextrapolate;
 
   if (mapType == RemapMethod::CONSERV_SCRIP || mapType == RemapMethod::CONSERV)
     {
-      if (src_grid.type != RemapGridType::Reg2D)
+      if (srcGrid.type != RemapGridType::Reg2D)
         {
-          src_grid.luse_cell_corners = true;
-          src_grid.lneed_cell_corners = true;
+          srcGrid.luse_cell_corners = true;
+          srcGrid.lneed_cell_corners = true;
         }
 
-      if (tgt_grid.type != RemapGridType::Reg2D)
+      if (tgtGrid.type != RemapGridType::Reg2D)
         {
-          tgt_grid.luse_cell_corners = true;
-          tgt_grid.lneed_cell_corners = true;
+          tgtGrid.luse_cell_corners = true;
+          tgtGrid.lneed_cell_corners = true;
         }
     }
 
-  src_grid.gridID = gridID1;
-  tgt_grid.gridID = gridID2;
+  srcGrid.gridID = gridID1;
+  tgtGrid.gridID = gridID2;
 
   if (gridInqType(gridID1) == GRID_UNSTRUCTURED && !gridHasCoordinates(gridID1))
     {
       const auto reference = dereferenceGrid(gridID1);
-      if (reference.isValid) src_grid.gridID = gridID1 = reference.gridID;
+      if (reference.isValid) srcGrid.gridID = gridID1 = reference.gridID;
       if (reference.notFound) cdo_abort("Reference to source grid not found!");
     }
 
   if (gridInqType(gridID2) == GRID_UNSTRUCTURED && !gridHasCoordinates(gridID2))
     {
       const auto reference = dereferenceGrid(gridID2);
-      if (reference.isValid) tgt_grid.gridID = gridID2 = reference.gridID;
+      if (reference.isValid) tgtGrid.gridID = gridID2 = reference.gridID;
       if (reference.notFound) cdo_abort("Reference to target grid not found!");
     }
 
-  const auto sgridID = src_grid.gridID;
+  const auto sgridID = srcGrid.gridID;
   if (gridInqSize(sgridID) > 1 && gridProjIsSupported(sgridID))
     {
-      bool lbounds = true;
-      src_grid.gridID = gridID1 = gridToCurvilinear(src_grid.gridID, lbounds);
-      src_grid.tmpgridID = src_grid.gridID;
+      const bool withBounds = srcGrid.lneed_cell_corners;
+      if (gridInqProjType(sgridID) == CDI_PROJ_HEALPIX)
+        gridID1 = gridToUnstructured(srcGrid.gridID, withBounds);
+      else
+        gridID1 = gridToCurvilinear(srcGrid.gridID, withBounds);
+      srcGrid.gridID = gridID1;
+      srcGrid.tmpgridID = srcGrid.gridID;
     }
 
-  // if (src_grid.type != RemapGridType::Reg2D)
-  remapDefineGrid(mapType, gridID1, src_grid, "Source");
-  remapDefineGrid(mapType, gridID2, tgt_grid, "Target");
+  // if (srcGrid.type != RemapGridType::Reg2D)
+  remapDefineGrid(mapType, gridID1, srcGrid, "Source");
+  remapDefineGrid(mapType, gridID2, tgtGrid, "Target");
 
-  if (src_grid.type == RemapGridType::Reg2D || tgt_grid.type == RemapGridType::Reg2D)
+  if (srcGrid.type == RemapGridType::Reg2D || tgtGrid.type == RemapGridType::Reg2D)
     {
-      if (src_grid.type == RemapGridType::Reg2D) remap_define_reg2d(reg2d_src_gridID, src_grid);
-      if (tgt_grid.type == RemapGridType::Reg2D) remap_define_reg2d(reg2d_tgt_gridID, tgt_grid);
+      const auto conservMapping = (mapType == RemapMethod::CONSERV);
+      if (srcGrid.type == RemapGridType::Reg2D) remap_define_reg2d(reg2d_srcGridID, srcGrid, conservMapping, "source");
+      if (tgtGrid.type == RemapGridType::Reg2D) remap_define_reg2d(reg2d_tgtGridID, tgtGrid, conservMapping, "target");
     }
 }
 
 /*****************************************************************************/
 
-template <typename T>
+template <typename T1, typename T2>
 static void
-remap_stat(int remapOrder, RemapGrid &src_grid, RemapGrid &tgt_grid, RemapVars &rv, const Varray<T> &array1,
-           const Varray<T> &array2, T missval)
+remap_stat(int remapOrder, RemapGrid &srcGrid, RemapGrid &tgtGrid, RemapVars &rv, const Varray<T1> &array1,
+           const Varray<T2> &array2, double missval)
 {
-  if (remapOrder == 2)
-    cdo_print("Second order mapping from grid1 to grid2:");
-  else
-    cdo_print("First order mapping from grid1 to grid2:");
+  const T1 mv1 = missval;
+  const T2 mv2 = missval;
+
+  cdo_print("%s order mapping from grid1 to grid2:", (remapOrder == 2) ? "Second" : "First");
   cdo_print("----------------------------------------------");
 
-  auto mmm = varray_min_max_mean_mv(src_grid.size, array1, missval);
+  auto mmm = varray_min_max_mean_mv(srcGrid.size, array1, mv1);
   cdo_print("  Grid1 min,mean,max: %g %g %g", mmm.min, mmm.mean, mmm.max);
 
-  mmm = varray_min_max_mean_mv(tgt_grid.size, array2, missval);
+  mmm = varray_min_max_mean_mv(tgtGrid.size, array2, mv2);
   cdo_print("  Grid2 min,mean,max: %g %g %g", mmm.min, mmm.mean, mmm.max);
 
   // Conservation Test
 
-  if (src_grid.cell_area.size())
+  if (srcGrid.cell_area.size())
     {
       cdo_print("  Conservation:");
-      double sum = 0;
-      for (size_t n = 0; n < src_grid.size; ++n)
-        if (!DBL_IS_EQUAL(array1[n], missval)) sum += array1[n] * src_grid.cell_area[n] * src_grid.cell_frac[n];
+      double sum = 0.0;
+      for (size_t n = 0; n < srcGrid.size; ++n)
+        if (!DBL_IS_EQUAL(array1[n], mv1)) sum += array1[n] * srcGrid.cell_area[n] * srcGrid.cell_frac[n];
       cdo_print("  Grid1 Integral = %g", sum);
 
       sum = 0;
-      for (size_t n = 0; n < tgt_grid.size; ++n)
-        if (!DBL_IS_EQUAL(array2[n], missval)) sum += array2[n] * tgt_grid.cell_area[n] * tgt_grid.cell_frac[n];
+      for (size_t n = 0; n < tgtGrid.size; ++n)
+        if (!DBL_IS_EQUAL(array2[n], mv2)) sum += array2[n] * tgtGrid.cell_area[n] * tgtGrid.cell_frac[n];
       cdo_print("  Grid2 Integral = %g", sum);
       /*
-      for ( n = 0; n < src_grid.size; n++ )
-       fprintf(stderr, "1 %d %g %g %g\n", n, array1[n], src_grid.cell_area[n],
-      src_grid.cell_frac[n]); for ( n = 0; n < tgt_grid.size; n++ )
-        fprintf(stderr, "2 %d %g %g %g\n", n, array2[n], tgt_grid.cell_area[n],
-      tgt_grid.cell_frac[n]);
+      for ( n = 0; n < srcGrid.size; n++ )
+       fprintf(stderr, "1 %d %g %g %g\n", n, array1[n], srcGrid.cell_area[n],
+      srcGrid.cell_frac[n]); for ( n = 0; n < tgtGrid.size; n++ )
+        fprintf(stderr, "2 %d %g %g %g\n", n, array2[n], tgtGrid.cell_area[n],
+      tgtGrid.cell_frac[n]);
       */
     }
 
   cdo_print("  Number of weights %zu", rv.num_wts);
   cdo_print("  Number of sparse matrix entries %zu", rv.num_links);
-  cdo_print("  Total number of dest cells %zu", tgt_grid.size);
+  cdo_print("  Total number of dest cells %zu", tgtGrid.size);
 
-  std::vector<size_t> tgt_count(tgt_grid.size, 0);
+  std::vector<size_t> tgt_count(tgtGrid.size, 0);
 
 #ifdef HAVE_OPENMP4
 #pragma omp simd
 #endif
-  for (size_t n = 0; n < rv.num_links; ++n) tgt_count[rv.tgt_cell_add[n]]++;
+  for (size_t n = 0; n < rv.num_links; ++n) tgt_count[rv.tgtCellIndices[n]]++;
 
   size_t imin = SIZE_MAX;
   size_t imax = 0;
-  for (size_t n = 0; n < tgt_grid.size; ++n)
+  for (size_t n = 0; n < tgtGrid.size; ++n)
     {
       if (tgt_count[n] > 0)
         {
@@ -836,7 +862,7 @@ remap_stat(int remapOrder, RemapGrid &src_grid, RemapGrid &tgt_grid, RemapVars &
 
   size_t idiff = (imax - imin) / 10 + 1;
   size_t icount = 0;
-  for (size_t i = 0; i < tgt_grid.size; ++i)
+  for (size_t i = 0; i < tgtGrid.size; ++i)
     if (tgt_count[i] > 0) icount++;
 
   cdo_print("  Number of cells participating in remap %zu", icount);
@@ -850,7 +876,7 @@ remap_stat(int remapOrder, RemapGrid &src_grid, RemapGrid &tgt_grid, RemapVars &
       for (size_t n = 0; n < 10; ++n)
         {
           icount = 0;
-          for (size_t i = 0; i < tgt_grid.size; ++i)
+          for (size_t i = 0; i < tgtGrid.size; ++i)
             if (tgt_count[i] >= imin && tgt_count[i] < imax) icount++;
 
           if (icount) cdo_print("  Num of rows with entries between %zu - %zu  %zu", imin, imax - 1, icount);
@@ -864,12 +890,16 @@ remap_stat(int remapOrder, RemapGrid &src_grid, RemapGrid &tgt_grid, RemapVars &
 }
 
 void
-remap_stat(int remapOrder, RemapGrid &src_grid, RemapGrid &tgt_grid, RemapVars &rv, const Field &field1, const Field &field2)
+remap_stat(int remapOrder, RemapGrid &srcGrid, RemapGrid &tgtGrid, RemapVars &rv, const Field &field1, const Field &field2)
 {
-  if (field1.memType == MemType::Float)
-    remap_stat(remapOrder, src_grid, tgt_grid, rv, field1.vec_f, field2.vec_f, (float) field1.missval);
+  if (memtype_is_float_float(field1.memType, field2.memType))
+    remap_stat(remapOrder, srcGrid, tgtGrid, rv, field1.vec_f, field2.vec_f, field1.missval);
+  else if (memtype_is_float_double(field1.memType, field2.memType))
+    remap_stat(remapOrder, srcGrid, tgtGrid, rv, field1.vec_f, field2.vec_d, field1.missval);
+  else if (memtype_is_double_float(field1.memType, field2.memType))
+    remap_stat(remapOrder, srcGrid, tgtGrid, rv, field1.vec_d, field2.vec_f, field1.missval);
   else
-    remap_stat(remapOrder, src_grid, tgt_grid, rv, field1.vec_d, field2.vec_d, field1.missval);
+    remap_stat(remapOrder, srcGrid, tgtGrid, rv, field1.vec_d, field2.vec_d, field1.missval);
 }
 
 /*****************************************************************************/
@@ -880,14 +910,14 @@ remap_gradients(RemapGrid &grid, const Varray<short> &mask, const Varray<T> &arr
 {
   if (grid.rank != 2) cdo_abort("Internal problem (remap_gradients), grid rank = %d!", grid.rank);
 
-  auto grid_size = grid.size;
-  auto nx = grid.dims[0];
-  auto ny = grid.dims[1];
+  const auto gridSize = grid.size;
+  const auto nx = grid.dims[0];
+  const auto ny = grid.dims[1];
 
 #ifdef _OPENMP
 #pragma omp parallel for default(shared)
 #endif
-  for (size_t n = 0; n < grid_size; ++n)
+  for (size_t n = 0; n < gridSize; ++n)
     {
       if (mask[n])
         {
@@ -1039,7 +1069,7 @@ remap_gradients(RemapGrid &grid, const Varray<short> &mask, const Varray<T> &arr
           gradients.grad_latlon[n] = 0.0;
         }
     }
-} /* remap_gradients */
+} // remap_gradients
 
 // Explicit instantiation
 template void remap_gradients(RemapGrid &grid, const Varray<short> &mask, const Varray<float> &array, RemapGradients &gradients);
@@ -1048,12 +1078,12 @@ template void remap_gradients(RemapGrid &grid, const Varray<short> &mask, const
 void
 remap_gradients(RemapGrid &grid, const Field &field, RemapGradients &gradients)
 {
-  auto grid_size = grid.size;
-  Varray<short> mask(grid_size);
+  const auto gridSize = grid.size;
+  Varray<short> mask(gridSize);
 #ifdef _OPENMP
 #pragma omp parallel for default(shared) schedule(static)
 #endif
-  for (size_t i = 0; i < grid_size; ++i) mask[i] = (grid.mask[i] > 0);
+  for (size_t i = 0; i < gridSize; ++i) mask[i] = (grid.mask[i] > 0);
 
   if (field.memType == MemType::Float)
     remap_gradients(grid, mask, field.vec_f, gradients);
@@ -1064,10 +1094,10 @@ remap_gradients(RemapGrid &grid, const Field &field, RemapGradients &gradients)
 /*****************************************************************************/
 
 void
-remap_check_area(size_t grid_size, double *cell_area, const char *name)
+remap_check_area(size_t gridSize, double *cell_area, const char *name)
 {
-  for (size_t n = 0; n < grid_size; ++n)
+  for (size_t n = 0; n < gridSize; ++n)
     {
-      if (cell_area[n] < -.01) cdo_print("%s grid area error: %zu %g", name, n, cell_area[n]);
+      if (cell_area[n] < -0.01) cdo_print("%s grid area error: %zu %g", name, n, cell_area[n]);
     }
 }
