@@ -50,7 +50,7 @@ template <typename T>
 MinMax
 varray_min_max_mv(const size_t len, const T *array, const T missval)
 {
-  auto minmax_mv = [](const auto a, const auto mv_a, auto &vmin, auto &vmax, auto &nvals, auto is_EQ) {
+  auto f_minmax_mv = [](const auto a, const auto mv_a, auto &vmin, auto &vmax, auto &nvals, auto is_EQ) {
     if (!is_EQ(a, mv_a))
       {
         vmin = min_value(vmin, a);
@@ -64,9 +64,9 @@ varray_min_max_mv(const size_t len, const T *array, const T missval)
 
   size_t nvals = 0;
   if (std::isnan(missval))
-    for (size_t i = 0; i < len; ++i) minmax_mv(array[i], missval, vmin, vmax, nvals, dbl_is_equal);
+    for (size_t i = 0; i < len; ++i) f_minmax_mv(array[i], missval, vmin, vmax, nvals, dbl_is_equal);
   else
-    for (size_t i = 0; i < len; ++i) minmax_mv(array[i], missval, vmin, vmax, nvals, is_equal);
+    for (size_t i = 0; i < len; ++i) f_minmax_mv(array[i], missval, vmin, vmax, nvals, is_equal);
 
   return MinMax(vmin, vmax, nvals);
 }
@@ -90,24 +90,24 @@ template <typename T>
 MinMaxSum
 varray_min_max_sum(const size_t len, const Varray<T> &v, MinMaxSum mms)
 {
-  auto rmin = mms.min;
-  auto rmax = mms.max;
-  auto rsum = mms.sum;
+  auto f_minmaxsum = [](const auto val, auto &vmin, auto &vmax, auto &vsum) {
+    vmin = min_value(vmin, val);
+    vmax = max_value(vmax, val);
+    vsum += val;
+  };
+
+  auto vmin = mms.min;
+  auto vmax = mms.max;
+  auto vsum = mms.sum;
 
 #ifndef __ICC  // wrong result with icc19
 #ifdef HAVE_OPENMP4
-#pragma omp simd reduction(min : rmin) reduction(max : rmax) reduction(+ : rsum)
+#pragma omp parallel for simd if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(min : vmin) reduction(max : vmax) reduction(+ : vsum)
 #endif
 #endif
-  for (size_t i = 0; i < len; ++i)
-    {
-      const double val = v[i];
-      rmin = min_value(rmin, val);
-      rmax = max_value(rmax, val);
-      rsum += val;
-    }
+  for (size_t i = 0; i < len; ++i) f_minmaxsum((double)v[i], vmin, vmax, vsum);
 
-  return MinMaxSum(rmin, rmax, rsum, len);
+  return MinMaxSum(vmin, vmax, vsum, len);
 }
 
 // Explicit instantiation
@@ -118,7 +118,7 @@ template <typename T>
 MinMaxSum
 varray_min_max_sum_mv(const size_t len, const Varray<T> &v, const T missval, MinMaxSum mms)
 {
-  auto minmaxsum_mv = [](const auto val, const auto mv, auto &vmin, auto &vmax, auto &vsum, auto &nvals, auto is_EQ) {
+  auto f_minmaxsum_mv = [](const auto val, const auto mv, auto &vmin, auto &vmax, auto &vsum, auto &nvals, auto is_EQ) {
     if (!is_EQ(val, mv))
       {
         vmin = min_value(vmin, val);
@@ -137,19 +137,19 @@ varray_min_max_sum_mv(const size_t len, const Varray<T> &v, const T missval, Min
     {
 #ifndef __ICC  // wrong result with icc19
 #ifdef HAVE_OPENMP4
-#pragma omp simd reduction(min : vmin) reduction(max : vmax) reduction(+ : vsum) reduction(+ : nvals)
+#pragma omp parallel for simd if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(min : vmin) reduction(max : vmax) reduction(+ : vsum,nvals)
 #endif
 #endif
-      for (size_t i = 0; i < len; ++i) minmaxsum_mv((double)v[i], missval, vmin, vmax, vsum, nvals, dbl_is_equal);
+      for (size_t i = 0; i < len; ++i) f_minmaxsum_mv((double)v[i], missval, vmin, vmax, vsum, nvals, dbl_is_equal);
     }
   else
     {
 #ifndef __ICC  // wrong result with icc19
 #ifdef HAVE_OPENMP4
-#pragma omp simd reduction(min : vmin) reduction(max : vmax) reduction(+ : vsum) reduction(+ : nvals)
+#pragma omp parallel for simd if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(min : vmin) reduction(max : vmax) reduction(+ : vsum,nvals)
 #endif
 #endif
-      for (size_t i = 0; i < len; ++i) minmaxsum_mv((double)v[i], missval, vmin, vmax, vsum, nvals, is_equal);
+      for (size_t i = 0; i < len; ++i) f_minmaxsum_mv((double)v[i], missval, vmin, vmax, vsum, nvals, is_equal);
     }
 
   if (nvals == 0 && IS_EQUAL(vmin, std::numeric_limits<double>::max())) vmin = missval;
@@ -167,7 +167,7 @@ MinMaxMean
 varray_min_max_mean(const size_t len, const Varray<T> &v)
 {
   auto mms = varray_min_max_sum(len, v, MinMaxSum());
-  const auto rmean = len != 0 ? mms.sum / static_cast<double>(len) : 0.0;
+  const auto rmean = (len != 0) ? mms.sum / static_cast<double>(len) : 0.0;
   return MinMaxMean(mms.min, mms.max, rmean, len);
 }
 
@@ -180,7 +180,7 @@ MinMaxMean
 varray_min_max_mean_mv(const size_t len, const Varray<T> &v, const T missval)
 {
   auto mms = varray_min_max_sum_mv(len, v, missval, MinMaxSum());
-  const auto rmean = mms.n != 0 ? mms.sum / static_cast<double>(mms.n) : missval;
+  const auto rmean = (mms.n != 0) ? mms.sum / static_cast<double>(mms.n) : missval;
   return MinMaxMean(mms.min, mms.max, rmean, mms.n);
 }
 
@@ -236,12 +236,12 @@ array_add_array_mv(const size_t len, double *array1, const double *array2, const
 {
   if (std::isnan(missval))
     {
-      for (size_t i = 0; i < len; i++)
+      for (size_t i = 0; i < len; ++i)
         if (!DBL_IS_EQUAL(array2[i], missval)) array1[i] = DBL_IS_EQUAL(array1[i], missval) ? array2[i] : array1[i] + array2[i];
     }
   else
     {
-      for (size_t i = 0; i < len; i++)
+      for (size_t i = 0; i < len; ++i)
         if (IS_NOT_EQUAL(array2[i], missval)) array1[i] = IS_EQUAL(array1[i], missval) ? array2[i] : array1[i] + array2[i];
     }
 }
@@ -307,7 +307,7 @@ varray_min_max(const size_t len, const T *array)
 
 #ifndef __ICC  // wrong result with icc19
 #ifdef HAVE_OPENMP4
-#pragma omp simd reduction(min : vmin) reduction(max : vmax)
+#pragma omp parallel for simd if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(min : vmin) reduction(max : vmax)
 #endif
 #endif
   for (size_t i = 0; i < len; ++i)
@@ -344,7 +344,7 @@ varray_min_max(const Varray<T> &v)
   const auto len = v.size();
 #ifndef __ICC  // wrong result with icc19
 #ifdef HAVE_OPENMP4
-#pragma omp simd reduction(min : vmin) reduction(max : vmax)
+#pragma omp parallel for simd if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(min : vmin) reduction(max : vmax)
 #endif
 #endif
   for (size_t i = 0; i < len; ++i)
@@ -370,8 +370,10 @@ varray_min(const size_t len, const Varray<T> &v)
 
   auto vmin = v[0];
 
-  for (size_t i = 0; i < len; ++i)
-    vmin = min_value(vmin, v[i]);
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for simd if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(min : vmin)
+#endif
+  for (size_t i = 0; i < len; ++i) vmin = min_value(vmin, v[i]);
 
   return vmin;
 }
@@ -390,8 +392,10 @@ varray_max(const size_t len, const Varray<T> &v)
 
   auto vmax = v[0];
 
-  for (size_t i = 0; i < len; ++i)
-    vmax = max_value(vmax, v[i]);
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for simd if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(max : vmax)
+#endif
+  for (size_t i = 0; i < len; ++i) vmax = max_value(vmax, v[i]);
 
   return vmax;
 }
@@ -411,6 +415,9 @@ varray_range(const size_t len, const Varray<T> &v)
   auto vmin = v[0];
   auto vmax = v[0];
 
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for simd if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(min : vmin) reduction(max : vmax)
+#endif
   for (size_t i = 0; i < len; ++i)
     {
       vmin = min_value(vmin, v[i]);
@@ -428,17 +435,36 @@ template <typename T>
 T
 varray_min_mv(const size_t len, const Varray<T> &v, const T missval)
 {
+  auto f_min_mv = [](const auto a, const auto mv_a, auto &vmin, auto is_EQ) {
+    if (!is_EQ(a, mv_a)) vmin = min_value(vmin, a);
+  };
+
   assert(len > 0);
   assert(v.size() > 0);
   assert(len <= v.size());
 
   T vmin = std::numeric_limits<T>::max();
 
-  for (size_t i = 0; i < len; ++i)
-    if (!DBL_IS_EQUAL(v[i], missval))
-      vmin = min_value(vmin, v[i]);
+  if (std::isnan(missval))
+    {
+#ifndef __ICC  // internal error with icc22: lambda not supported
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(min : vmin)
+#endif
+#endif
+      for (size_t i = 0; i < len; ++i) f_min_mv(v[i], missval, vmin, dbl_is_equal);
+    }
+  else
+    {
+#ifndef __ICC  // internal error with icc22: lambda not supported
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(min : vmin)
+#endif
+#endif
+      for (size_t i = 0; i < len; ++i) f_min_mv(v[i], missval, vmin, is_equal);
+    }
 
-  if (IS_EQUAL(vmin, std::numeric_limits<T>::max())) vmin = missval;
+  if (is_equal(vmin, std::numeric_limits<T>::max())) vmin = missval;
 
   return vmin;
 }
@@ -451,17 +477,36 @@ template <typename T>
 T
 varray_max_mv(const size_t len, const Varray<T> &v, const T missval)
 {
+  auto f_max_mv = [](const auto a, const auto mv_a, auto &vmax, auto is_EQ) {
+    if (!is_EQ(a, mv_a)) vmax = max_value(vmax, a);
+  };
+
   assert(len > 0);
   assert(v.size() > 0);
   assert(len <= v.size());
 
   T vmax = -std::numeric_limits<T>::max();
 
-  for (size_t i = 0; i < len; ++i)
-    if (!DBL_IS_EQUAL(v[i], missval))
-      vmax = max_value(vmax, v[i]);
+  if (std::isnan(missval))
+    {
+#ifndef __ICC  // internal error with icc22: lambda not supported
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(max : vmax)
+#endif
+#endif
+      for (size_t i = 0; i < len; ++i) f_max_mv(v[i], missval, vmax, dbl_is_equal);
+    }
+  else
+    {
+#ifndef __ICC  // internal error with icc22: lambda not supported
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(max : vmax)
+#endif
+#endif
+      for (size_t i = 0; i < len; ++i) f_max_mv(v[i], missval, vmax, is_equal);
+    }
 
-  if (IS_EQUAL(vmax, -std::numeric_limits<T>::max())) vmax = missval;
+  if (is_equal(vmax, -std::numeric_limits<T>::max())) vmax = missval;
 
   return vmax;
 }
@@ -474,6 +519,14 @@ template <typename T>
 T
 varray_range_mv(const size_t len, const Varray<T> &v, const T missval)
 {
+  auto f_minmax_mv = [](const auto a, const auto mv_a, auto &vmin, auto &vmax, auto is_EQ) {
+    if (!is_EQ(a, mv_a))
+      {
+        vmin = min_value(vmin, a);
+        vmax = max_value(vmax, a);
+      }
+  };
+
   assert(len > 0);
   assert(v.size() > 0);
   assert(len <= v.size());
@@ -481,20 +534,41 @@ varray_range_mv(const size_t len, const Varray<T> &v, const T missval)
   T vmin = std::numeric_limits<T>::max();
   T vmax = -std::numeric_limits<T>::max();
 
-  for (size_t i = 0; i < len; ++i)
-    if (!DBL_IS_EQUAL(v[i], missval))
-      {
-        vmin = min_value(vmin, v[i]);
-        vmax = max_value(vmax, v[i]);
-      }
+  if (std::isnan(missval))
+    {
+#ifndef __ICC  // internal error with icc22: lambda not supported
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(min : vmin) reduction(max : vmax)
+#endif
+#endif
+      for (size_t i = 0; i < len; ++i) f_minmax_mv(v[i], missval, vmin, vmax, dbl_is_equal);
+    }
+  else
+    {
+#ifndef __ICC  // internal error with icc22: lambda not supported
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(min : vmin) reduction(max : vmax)
+#endif
+#endif
+      for (size_t i = 0; i < len; ++i) f_minmax_mv(v[i], missval, vmin, vmax, is_equal);
+    }
 
-  return (IS_EQUAL(vmin, std::numeric_limits<T>::max()) && IS_EQUAL(vmax, -std::numeric_limits<T>::max())) ? missval : vmax - vmin;
+  return (is_equal(vmin, std::numeric_limits<T>::max()) && is_equal(vmax, -std::numeric_limits<T>::max())) ? missval : vmax - vmin;
 }
 
 // Explicit instantiation
 template float varray_range_mv(const size_t len, const Varray<float> &v, const float missval);
 template double varray_range_mv(const size_t len, const Varray<double> &v, const double missval);
 
+double
+array_sum(const size_t len, const double *array)
+{
+  double sum = 0.0;
+  for (size_t i = 0; i < len; ++i) sum += array[i];
+
+  return sum;
+}
+
 template <typename T>
 double
 varray_sum(const size_t len, const Varray<T> &v)
@@ -504,6 +578,9 @@ varray_sum(const size_t len, const Varray<T> &v)
   assert(len <= v.size());
 
   double sum = 0.0;
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(+ : sum)
+#endif
   for (size_t i = 0; i < len; ++i) sum += v[i];
 
   return sum;
@@ -517,6 +594,14 @@ template <typename T>
 double
 varray_sum_mv(const size_t len, const Varray<T> &v, const T missval)
 {
+  auto f_sum_mv = [](const auto a, const auto mv_a, auto &sum, auto &nvals, auto is_EQ) {
+    if (!is_EQ(a, mv_a))
+      {
+        sum += a;
+        nvals++;
+      }
+  };
+
   assert(len > 0);
   assert(v.size() > 0);
   assert(len <= v.size());
@@ -526,21 +611,21 @@ varray_sum_mv(const size_t len, const Varray<T> &v, const T missval)
 
   if (std::isnan(missval))
     {
-      for (size_t i = 0; i < len; ++i)
-        if (!DBL_IS_EQUAL(v[i], missval))
-          {
-            sum += v[i];
-            nvals++;
-          }
+#ifndef __ICC  // internal error with icc22: lambda not supported
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(+ : sum,nvals)
+#endif
+#endif
+      for (size_t i = 0; i < len; ++i) f_sum_mv(v[i], missval, sum, nvals, dbl_is_equal);
     }
   else
     {
-      for (size_t i = 0; i < len; ++i)
-        if (IS_NOT_EQUAL(v[i], missval))
-          {
-            sum += v[i];
-            nvals++;
-          }
+#ifndef __ICC  // internal error with icc22: lambda not supported
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(+ : sum,nvals)
+#endif
+#endif
+      for (size_t i = 0; i < len; ++i) f_sum_mv(v[i], missval, sum, nvals, is_equal);
     }
 
   if (!nvals) sum = missval;
@@ -598,6 +683,11 @@ template <typename T>
 double
 varray_weighted_mean(const size_t len, const Varray<T> &v, const Varray<double> &w, const T missval)
 {
+  auto f_weighted_mean = [](const auto aw, const auto a, auto &sum, auto &sumw) {
+    sum += aw * a;
+    sumw += aw;
+  };
+
   assert(len > 0);
   assert(v.size() > 0);
   assert(len <= v.size());
@@ -605,13 +695,14 @@ varray_weighted_mean(const size_t len, const Varray<T> &v, const Varray<double>
 
   double sum = 0.0, sumw = 0.0;
 
-  for (size_t i = 0; i < len; ++i)
-    {
-      sum += w[i] * v[i];
-      sumw += w[i];
-    }
+#ifndef __ICC  // internal error with icc22: lambda not supported
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(+ : sum,sumw)
+#endif
+#endif
+  for (size_t i = 0; i < len; ++i) f_weighted_mean(w[i], v[i], sum, sumw);
 
-  return IS_EQUAL(sumw, 0.) ? missval : sum / sumw;
+  return is_equal(sumw, 0.0) ? missval : sum / sumw;
 }
 
 // Explicit instantiation
@@ -622,6 +713,14 @@ template <typename T>
 double
 varray_weighted_mean_mv(const size_t len, const Varray<T> &v, const Varray<double> &w, const T missval)
 {
+  auto f_weighted_mean_mv = [](const auto aw, const auto a, const auto mv_a, auto &sum, auto &sumw, auto is_EQ) {
+    if (!is_EQ(a, mv_a) && !is_EQ(aw, mv_a))
+      {
+        sum += aw * a;
+        sumw += aw;
+      }
+  };
+
   assert(len > 0);
   assert(v.size() > 0);
   assert(len <= v.size());
@@ -630,12 +729,24 @@ varray_weighted_mean_mv(const size_t len, const Varray<T> &v, const Varray<doubl
   const double missval1 = missval, missval2 = missval;
   double sum = 0.0, sumw = 0.0;
 
-  for (size_t i = 0; i < len; ++i)
-    if (!DBL_IS_EQUAL(v[i], missval1) && !DBL_IS_EQUAL(w[i], missval1))
-      {
-        sum += w[i] * v[i];
-        sumw += w[i];
-      }
+  if (std::isnan(missval))
+    {
+#ifndef __ICC  // internal error with icc22: lambda not supported
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(+ : sum,sumw)
+#endif
+#endif
+      for (size_t i = 0; i < len; ++i) f_weighted_mean_mv(w[i], v[i], missval1, sum, sumw, dbl_is_equal);
+    }
+  else
+    {
+#ifndef __ICC  // internal error with icc22: lambda not supported
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(+ : sum,sumw)
+#endif
+#endif
+      for (size_t i = 0; i < len; ++i) f_weighted_mean_mv(w[i], v[i], missval1, sum, sumw, is_equal);
+    }
 
   return DIVMN(sum, sumw);
 }
@@ -696,58 +807,83 @@ template double varray_weighted_avg_mv(const size_t len, const Varray<double> &v
 
 template <typename T>
 static void
-varrayPrevarsum0(size_t len, const Varray<T> &v, double &rsum, double &rsumw)
+varray_prevarsum0(size_t len, const Varray<T> &v, double &rsum, double &rsumw)
 {
   rsum = 0.0;
-  for (size_t i = 0; i < len; i++)
-    {
-      rsum += v[i];
-    }
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(+ : rsum)
+#endif
+  for (size_t i = 0; i < len; ++i) rsum += v[i];
   rsumw = len;
 }
 
 template <typename T>
 static void
-varrayPrevarsum0MV(size_t len, const Varray<T> &v, double missval, double &rsum, double &rsumw)
+varray_prevarsum0_mv(size_t len, const Varray<T> &v, double missval, double &rsum, double &rsumw)
 {
-  rsum = rsumw = 0.0;
-  for (size_t i = 0; i < len; i++)
-    if (!DBL_IS_EQUAL(v[i], missval))
+  auto f_prevarsum0_mv = [](const auto a, const auto mv_a, auto &sum, auto &sumw) {
+    if (!dbl_is_equal(a, mv_a))
       {
-        rsum += v[i];
-        rsumw += 1.0;
+        sum += a;
+        sumw += 1.0;
       }
+  };
+
+  rsum = rsumw = 0.0;
+
+#ifndef __ICC  // internal error with icc22: lambda not supported
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(+ : rsum,rsumw)
+#endif
+#endif
+  for (size_t i = 0; i < len; ++i) f_prevarsum0_mv(v[i], missval, rsum, rsumw);
 }
 
 template <typename T>
 static void
-varrayPrevarsum(size_t len, const Varray<T> &v, double &rsum, double &rsumw, double &rsumq, double &rsumwq)
+varray_prevarsum(size_t len, const Varray<T> &v, double &rsum, double &rsumw, double &rsumq, double &rsumwq)
 {
+  auto f_prevarsum = [](const auto a, auto &sum, auto &sumq) {
+    sum += a;
+    sumq += a * a;
+  };
+
   rsum = rsumq = 0.0;
-  for (size_t i = 0; i < len; i++)
-    {
-      const double vd = v[i];
-      rsum += vd;
-      rsumq += vd * vd;
-    }
+
+#ifndef __ICC  // internal error with icc22: lambda not supported
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(+ : rsum,rsumq)
+#endif
+#endif
+  for (size_t i = 0; i < len; ++i) f_prevarsum((double)v[i], rsum, rsumq);
+
   rsumw = len;
   rsumwq = len;
 }
 
 template <typename T>
 static void
-varrayPrevarsumMV(size_t len, const Varray<T> &v, T missval, double &rsum, double &rsumw, double &rsumq, double &rsumwq)
+varray_prevarsum_mv(size_t len, const Varray<T> &v, T missval, double &rsum, double &rsumw, double &rsumq, double &rsumwq)
 {
-  rsum = rsumq = rsumw = rsumwq = 0.0;
-  for (size_t i = 0; i < len; i++)
-    if (!DBL_IS_EQUAL(v[i], missval))
+  auto f_prevarsum = [](const auto a, const auto mv_a, auto &sum, auto &sumq, auto &sumw, auto &sumwq) {
+    if (!dbl_is_equal(a, mv_a))
       {
-        const double vd = v[i];
-        rsum += vd;
-        rsumq += vd * vd;
-        rsumw += 1.0;
-        rsumwq += 1.0;
+        const double ad = (double)a;
+        sum += ad;
+        sumq += ad * ad;
+        sumw += 1.0;
+        sumwq += 1.0;
       }
+  };
+
+  rsum = rsumq = rsumw = rsumwq = 0.0;
+
+#ifndef __ICC  // internal error with icc22: lambda not supported
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(+ : rsum,rsumq,rsumw,rsumwq)
+#endif
+#endif
+  for (size_t i = 0; i < len; ++i) f_prevarsum(v[i], missval, rsum, rsumq, rsumw, rsumwq);
 }
 
 template <typename T>
@@ -756,9 +892,9 @@ varray_var(size_t len, const Varray<T> &v, size_t nmiss, T missval)
 {
   double rsum = 0.0, rsumw = 0.0, rsumq = 0.0, rsumwq = 0.0;
   if (nmiss > 0)
-    varrayPrevarsumMV(len, v, missval, rsum, rsumw, rsumq, rsumwq);
+    varray_prevarsum_mv(len, v, missval, rsum, rsumw, rsumq, rsumwq);
   else
-    varrayPrevarsum(len, v, rsum, rsumw, rsumq, rsumwq);
+    varray_prevarsum(len, v, rsum, rsumw, rsumq, rsumwq);
 
   auto rvar = IS_NOT_EQUAL(rsumw, 0.0) ? (rsumq * rsumw - rsum * rsum) / (rsumw * rsumw) : missval;
   if (rvar < 0.0 && rvar > -1.e-5) rvar = 0.0;
@@ -776,9 +912,9 @@ varray_var_1(size_t len, const Varray<T> &v, size_t nmiss, T missval)
 {
   double rsum = 0.0, rsumw = 0.0, rsumq = 0.0, rsumwq = 0.0;
   if (nmiss > 0)
-    varrayPrevarsumMV(len, v, missval, rsum, rsumw, rsumq, rsumwq);
+    varray_prevarsum_mv(len, v, missval, rsum, rsumw, rsumq, rsumwq);
   else
-    varrayPrevarsum(len, v, rsum, rsumw, rsumq, rsumwq);
+    varray_prevarsum(len, v, rsum, rsumw, rsumq, rsumwq);
 
   auto rvar = (rsumw * rsumw > rsumwq) ? (rsumq * rsumw - rsum * rsum) / (rsumw * rsumw - rsumwq) : missval;
   if (rvar < 0.0 && rvar > -1.e-5) rvar = 0.0;
@@ -792,35 +928,49 @@ template double varray_var_1(const size_t len, const Varray<double> &v, size_t n
 
 template <typename T>
 static void
-varrayWeightedPrevarsum(size_t len, const Varray<T> &v, const Varray<double> &w, double &rsum, double &rsumw, double &rsumq,
-                        double &rsumwq)
+varray_weighted_prevarsum(size_t len, const Varray<T> &v, const Varray<double> &w, double &rsum, double &rsumw, double &rsumq,
+                          double &rsumwq)
 {
+  auto f_weighted_prevarsum = [](const auto aw, const auto a, auto &sum, auto &sumq, auto &sumw, auto &sumwq) {
+    sum += aw * a;
+    sumq += aw * a * a;
+    sumw += aw;
+    sumwq += aw * aw;
+  };
+
   rsum = rsumq = rsumw = rsumwq = 0.0;
-  for (size_t i = 0; i < len; i++)
-    {
-      const double vd = v[i];
-      rsum += w[i] * vd;
-      rsumq += w[i] * vd * vd;
-      rsumw += w[i];
-      rsumwq += w[i] * w[i];
-    }
+
+#ifndef __ICC  // internal error with icc22: lambda not supported
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(+ : rsum,rsumq,rsumw,rsumwq)
+#endif
+#endif
+  for (size_t i = 0; i < len; ++i) f_weighted_prevarsum(w[i], (double)v[i], rsum, rsumq, rsumw, rsumwq);
 }
 
 template <typename T>
 static void
-varrayWeightedPrevarsumMV(size_t len, const Varray<T> &v, const Varray<double> &w, double missval, double &rsum, double &rsumw,
-                          double &rsumq, double &rsumwq)
+varray_weighted_prevarsum_mv(size_t len, const Varray<T> &v, const Varray<double> &w, double missval, double &rsum, double &rsumw,
+                             double &rsumq, double &rsumwq)
 {
-  rsum = rsumq = rsumw = rsumwq = 0.0;
-  for (size_t i = 0; i < len; i++)
-    if (!DBL_IS_EQUAL(v[i], missval) && !DBL_IS_EQUAL(w[i], missval))
+  auto f_weighted_prevarsum_mv = [](const auto aw, const auto a, const auto mv_a, auto &sum, auto &sumq, auto &sumw, auto &sumwq) {
+    if (!dbl_is_equal(a, mv_a) && !dbl_is_equal(aw, mv_a))
       {
-        const double vd = v[i];
-        rsum += w[i] * vd;
-        rsumq += w[i] * vd * vd;
-        rsumw += w[i];
-        rsumwq += w[i] * w[i];
+        sum += aw * a;
+        sumq += aw * a * a;
+        sumw += aw;
+        sumwq += aw * aw;
       }
+  };
+
+  rsum = rsumq = rsumw = rsumwq = 0.0;
+
+#ifndef __ICC  // internal error with icc22: lambda not supported
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(+ : rsum,rsumq,rsumw,rsumwq)
+#endif
+#endif
+  for (size_t i = 0; i < len; ++i) f_weighted_prevarsum_mv(w[i], (double)v[i], missval, rsum, rsumq, rsumw, rsumwq);
 }
 
 template <typename T>
@@ -829,9 +979,9 @@ varray_weighted_var(size_t len, const Varray<T> &v, const Varray<double> &w, siz
 {
   double rsum = 0.0, rsumw = 0.0, rsumq = 0.0, rsumwq = 0.0;
   if (nmiss > 0)
-    varrayWeightedPrevarsumMV(len, v, w, missval, rsum, rsumw, rsumq, rsumwq);
+    varray_weighted_prevarsum_mv(len, v, w, missval, rsum, rsumw, rsumq, rsumwq);
   else
-    varrayWeightedPrevarsum(len, v, w, rsum, rsumw, rsumq, rsumwq);
+    varray_weighted_prevarsum(len, v, w, rsum, rsumw, rsumq, rsumwq);
 
   auto rvar = IS_NOT_EQUAL(rsumw, 0) ? (rsumq * rsumw - rsum * rsum) / (rsumw * rsumw) : missval;
   if (rvar < 0.0 && rvar > -1.e-5) rvar = 0.0;
@@ -851,9 +1001,9 @@ varray_weighted_var_1(size_t len, const Varray<T> &v, const Varray<double> &w, s
 {
   double rsum = 0.0, rsumw = 0.0, rsumq = 0.0, rsumwq = 0.0;
   if (nmiss > 0)
-    varrayWeightedPrevarsumMV(len, v, w, missval, rsum, rsumw, rsumq, rsumwq);
+    varray_weighted_prevarsum_mv(len, v, w, missval, rsum, rsumw, rsumq, rsumwq);
   else
-    varrayWeightedPrevarsum(len, v, w, rsum, rsumw, rsumq, rsumwq);
+    varray_weighted_prevarsum(len, v, w, rsum, rsumw, rsumq, rsumwq);
 
   auto rvar = (rsumw * rsumw > rsumwq) ? (rsumq * rsumw - rsum * rsum) / (rsumw * rsumw - rsumwq) : missval;
   if (rvar < 0.0 && rvar > -1.e-5) rvar = 0.0;
@@ -869,35 +1019,47 @@ template double varray_weighted_var_1(const size_t len, const Varray<double> &v,
 
 template <typename T>
 static void
-varrayPrekurtsum(size_t len, const Varray<T> &v, const double mean, double &rsum3w, double &rsum4w, double &rsum2diff,
-                 double &rsum4diff)
+varray_prekurtsum(size_t len, const Varray<T> &v, const double mean, double &rsum3w, double &rsum2diff, double &rsum4diff)
 {
+  auto f_prekurtsum = [](const auto vdiff, auto &sum2diff, auto &sum4diff) {
+    sum2diff += vdiff * vdiff;
+    sum4diff += vdiff * vdiff * vdiff * vdiff;
+  };
+
   rsum2diff = rsum4diff = 0.0;
-  for (size_t i = 0; i < len; i++)
-    {
-      const double vdiff = v[i] - mean;
-      rsum2diff += vdiff * vdiff;
-      rsum4diff += vdiff * vdiff * vdiff * vdiff;
-    }
+
+#ifndef __ICC  // internal error with icc22: lambda not supported
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(+ : rsum2diff,rsum4diff)
+#endif
+#endif
+for (size_t i = 0; i < len; ++i) f_prekurtsum(v[i] - mean, rsum2diff, rsum4diff);
+
   rsum3w = len;
-  rsum4w = len;
 }
 
 template <typename T>
 static void
-varrayPrekurtsumMV(size_t len, const Varray<T> &v, T missval, const double mean, double &rsum3w, double &rsum4w, double &rsum2diff,
-                   double &rsum4diff)
+varray_prekurtsum_mv(size_t len, const Varray<T> &v, T missval, const double mean, double &rsum3w, double &rsum2diff, double &rsum4diff)
 {
-  rsum3w = rsum4w = rsum2diff = rsum4diff = 0.0;
-  for (size_t i = 0; i < len; i++)
-    if (!DBL_IS_EQUAL(v[i], missval))
+  auto f_preskewsum_mv = [](const auto a, const auto mv_a, const auto meanval, auto &sum2diff, auto &sum4diff, auto &sum3w) {
+    if (!dbl_is_equal(a, mv_a))
       {
-        const double vdiff = v[i] - mean;
-        rsum2diff += vdiff * vdiff;
-        rsum4diff += vdiff * vdiff * vdiff * vdiff;
-        rsum3w += 1;
-        rsum4w += 1;
+        const double vdiff = a - meanval;
+        sum2diff += vdiff * vdiff;
+        sum4diff += vdiff * vdiff * vdiff * vdiff;
+        sum3w += 1;
       }
+  };
+
+  rsum3w = rsum2diff = rsum4diff = 0.0;
+
+#ifndef __ICC  // internal error with icc22: lambda not supported
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(+ : rsum2diff,rsum4diff,rsum3w)
+#endif
+#endif
+  for (size_t i = 0; i < len; ++i) f_preskewsum_mv(v[i], missval, mean, rsum2diff, rsum4diff, rsum3w);
 }
 
 template <typename T>
@@ -905,22 +1067,21 @@ double
 varray_kurt(size_t len, const Varray<T> &v, size_t nmiss, T missval)
 {
   double rsum3w;  // 3rd moment variables
-  double rsum4w;  // 4th moment variables
   double rsum2diff, rsum4diff;
   double rsum, rsumw;
 
   if (nmiss > 0)
     {
-      varrayPrevarsum0MV(len, v, missval, rsum, rsumw);
-      varrayPrekurtsumMV(len, v, missval, (rsum / rsumw), rsum3w, rsum4w, rsum2diff, rsum4diff);
+      varray_prevarsum0_mv(len, v, missval, rsum, rsumw);
+      varray_prekurtsum_mv(len, v, missval, (rsum / rsumw), rsum3w, rsum2diff, rsum4diff);
     }
   else
     {
-      varrayPrevarsum0(len, v, rsum, rsumw);
-      varrayPrekurtsum(len, v, (rsum / rsumw), rsum3w, rsum4w, rsum2diff, rsum4diff);
+      varray_prevarsum0(len, v, rsum, rsumw);
+      varray_prekurtsum(len, v, (rsum / rsumw), rsum3w, rsum2diff, rsum4diff);
     }
 
-  if (IS_EQUAL(rsum3w, 0.0) || IS_EQUAL(rsum2diff, 0.0)) return missval;
+  if (is_equal(rsum3w, 0.0) || is_equal(rsum2diff, 0.0)) return missval;
 
   auto rkurt = ((rsum4diff / rsum3w) / std::pow(rsum2diff / rsum3w, 2)) - 3.0;
   if (rkurt < 0.0 && rkurt > -1.e-5) rkurt = 0.0;
@@ -934,36 +1095,48 @@ template double varray_kurt(const size_t len, const Varray<double> &v, size_t nm
 
 template <typename T>
 static void
-varrayPreskewsum(size_t len, const Varray<T> &v, const double mean, double &rsum3w, double &rsum4w, double &rsum3diff,
-                 double &rsum2diff)
+varray_preskewsum(size_t len, const Varray<T> &v, const double mean, double &rsum3w, double &rsum3diff, double &rsum2diff)
 {
+  auto f_preskewsum = [](const auto vdiff, auto &sum3diff, auto &sum2diff) {
+    sum3diff += vdiff * vdiff * vdiff;
+    sum2diff += vdiff * vdiff;
+  };
+
   rsum2diff = 0.0;
   rsum3diff = 0.0;
-  for (size_t i = 0; i < len; i++)
-    {
-      const double vdiff = v[i] - mean;
-      rsum3diff += vdiff * vdiff * vdiff;
-      rsum2diff += vdiff * vdiff;
-    }
+
+#ifndef __ICC  // internal error with icc22: lambda not supported
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(+ : rsum2diff,rsum3diff)
+#endif
+#endif
+  for (size_t i = 0; i < len; ++i) f_preskewsum(v[i] - mean, rsum3diff, rsum2diff);
+
   rsum3w = len;
-  rsum4w = len;
 }
 
 template <typename T>
 static void
-varrayPreskewsumMV(size_t len, const Varray<T> &v, T missval, const double mean, double &rsum3w, double &rsum4w, double &rsum3diff,
-                   double &rsum2diff)
+varray_preskewsum_mv(size_t len, const Varray<T> &v, T missval, const double mean, double &rsum3w, double &rsum3diff, double &rsum2diff)
 {
-  rsum3w = rsum4w = rsum3diff = rsum2diff = 0.0;
-  for (size_t i = 0; i < len; i++)
-    if (!DBL_IS_EQUAL(v[i], missval))
+  auto f_preskewsum_mv = [](const auto a, const auto mv_a, const auto meanval, auto &sum3diff, auto &sum2diff, auto &sum3w) {
+    if (!dbl_is_equal(a, mv_a))
       {
-        const double vdiff = v[i] - mean;
-        rsum3diff += vdiff * vdiff * vdiff;
-        rsum2diff += vdiff * vdiff;
-        rsum3w += 1;
-        rsum4w += 1;
+        const double vdiff = a - meanval;
+        sum3diff += vdiff * vdiff * vdiff;
+        sum2diff += vdiff * vdiff;
+        sum3w += 1;
       }
+  };
+
+  rsum3w = rsum3diff = rsum2diff = 0.0;
+
+#ifndef __ICC  // internal error with icc22: lambda not supported
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static) reduction(+ : rsum2diff,rsum3diff,rsum3w)
+#endif
+#endif
+  for (size_t i = 0; i < len; ++i) f_preskewsum_mv(v[i], missval, mean, rsum3diff, rsum2diff, rsum3w);
 }
 
 template <typename T>
@@ -971,22 +1144,21 @@ double
 varray_skew(size_t len, const Varray<T> &v, size_t nmiss, T missval)
 {
   double rsum3w;  // 3rd moment variables
-  double rsum4w;  // 4th moment variables
   double rsum3diff, rsum2diff;
   double rsum, rsumw;
 
   if (nmiss > 0)
     {
-      varrayPrevarsum0MV(len, v, missval, rsum, rsumw);
-      varrayPreskewsumMV(len, v, missval, (rsum / rsumw), rsum3w, rsum4w, rsum3diff, rsum2diff);
+      varray_prevarsum0_mv(len, v, missval, rsum, rsumw);
+      varray_preskewsum_mv(len, v, missval, (rsum / rsumw), rsum3w, rsum3diff, rsum2diff);
     }
   else
     {
-      varrayPrevarsum0(len, v, rsum, rsumw);
-      varrayPreskewsum(len, v, (rsum / rsumw), rsum3w, rsum4w, rsum3diff, rsum2diff);
+      varray_prevarsum0(len, v, rsum, rsumw);
+      varray_preskewsum(len, v, (rsum / rsumw), rsum3w, rsum3diff, rsum2diff);
     }
 
-  if (IS_EQUAL(rsum3w, 0.0) || IS_EQUAL(rsum3w, 1.0) || IS_EQUAL(rsum2diff, 0.0)) return missval;
+  if (is_equal(rsum3w, 0.0) || is_equal(rsum3w, 1.0) || is_equal(rsum2diff, 0.0)) return missval;
 
   auto rskew = (rsum3diff / rsum3w) / std::pow((rsum2diff) / (rsum3w - 1.0), 1.5);
   if (rskew < 0.0 && rskew > -1.e-5) rskew = 0.0;
